@@ -1,5 +1,5 @@
 /***************************************************************************
-                          utilities.cpp  -  description
+                          adif.cpp  -  description
                              -------------------
     begin                : jun 2015
     copyright            : (C) 2015 by Jaime Robles
@@ -25,6 +25,7 @@
  *****************************************************************************/
 //#include "global.h"
 #include "adif.h"
+#include "callsign.h"
 
 Adif::Adif(const QString &_parentName)
 {
@@ -212,7 +213,7 @@ void Adif::setARRLSect()
         "ME", "MB", "MAR", "MDC", "MI", "MN", "MS", "MO", "MT",
         "NE", "NV", "NH", "NM", "NLI", "NL", "NC", "ND", "NTX",
         "NFL", "NNJ", "NNY", "NT", "NWT", "OH", "OK", "ON",
-        "ONE", "ONN", "ONS", "ORG", "OR", "PAC", "PR", "QC",
+        "ONE", "ONN", "ONS", "ORG", "OR", "PAC", "PE", "PR", "QC",
         "RI", "SV", "SDG", "SF", "SJV", "SB", "SCV", "SK", "SC", "SD",
         "STX", "SFL", "SNJ", "TN", "VI", "UT", "VT", "VA",
         "WCF", "WTX", "WV", "WMA", "WNY", "WPA", "WWA", "WI", "WY"};
@@ -231,6 +232,18 @@ void Adif::setSponsorsList()
     sponsorsList = psponsorsList;
 }
 
+bool Adif::isValidMode (const QString &_s)
+{
+    return modes.contains(_s);
+}
+
+void Adif::setModes(const QStringList &_modes)
+{ // TODO: Add here the list/table of modes to feed DB creation and/or to prevent depending on external sources
+  // from this class
+    modes.clear();
+    modes << _modes;
+}
+
 bool Adif::isValidFreq(const QString &_b)
 {
     //qDebug() << Q_FUNC_INFO << ": freq: " << _b;
@@ -252,7 +265,7 @@ bool Adif::isValidFreq(const QString &_b)
 
 bool Adif::isValidPower(const QString &_b)
 {
-    return (_b.toDouble()>0);
+    return (_b.toDouble()>0.0);
 }
 
 QString Adif::getADIFBoolFromBool(const bool _b)
@@ -285,7 +298,7 @@ bool Adif::isValidDXCC(const QString &_b)
 
 bool Adif::isValidAge(const QString &_b)
 {
-    return ((_b.toInt()>=0) && (_b.toInt()<=120));
+    return ((_b.toInt()>0) && (_b.toInt()<=120));
 }
 
 bool Adif::isValidAnt_EL(const QString &_b)
@@ -308,6 +321,11 @@ bool Adif::isValidDistance(const QString &_b)
     return (_b.toDouble()>0);
 }
 
+bool Adif::isValidAltitude(const QString &_b)
+{
+    return (_b.toDouble()>10000);
+}
+
 bool Adif::isValidIOTA_islandID(const QString &_b)
 {
     return ((_b.toInt()>=1) && (_b.toInt()<=90));
@@ -368,6 +386,48 @@ bool Adif::isValidQSO_COMPLETE(const QString &_s)
     return ((_s == "Y") || (_s == "N") || (_s == "NIL") || (_s == "?"));
 }
 
+QString Adif::getQSO_COMPLETEFromDB(const QString &_s)
+{// Returns the ADIF QSO_COMPLETE
+    //1=Y, 2=N, 3=NIL, 4=?
+    //qDebug() << Q_FUNC_INFO << ": " << _s;
+    int i = _s.toInt();
+    switch (i)
+    {
+    case 2:
+    {
+        return "N";
+    }
+    case 3:
+    {
+        return "NIL";
+    }
+    case 4:
+    {
+        return "?";
+    }
+    default:
+    {
+        return "Y";
+    }
+    }
+}
+
+bool Adif::isValidPOTA(const QString &_s)
+{
+    if (_s.length()<1)
+        return false;
+    return true;
+}
+
+bool Adif::isValidWWFF_Ref(const QString &_s)
+{
+    if (_s.length()<1)
+        return false;
+    return true;
+}
+
+
+
 /*
 bool Utilities::isValidComment(const QString &_b)
 {
@@ -636,14 +696,29 @@ QString Adif::getADIFField(const QString &_fieldName, const QString &_data)
         //qDebug() << Q_FUNC_INFO << " - No valid ADIF: " << _fieldName;
         return QString();
     }
+    if (fieldN == "DISTANCE" )
+        if (_data.toDouble() <= 0.0)
+            return QString();
     return QString ("<%1:%2>%3 ").arg(fieldN).arg(_data.length ()).arg(_data);
 }
 
 bool Adif::isValidCall(const QString &_c)
 {
-    if (_c.length ()>=3)
-        return true;
-    return false;
+    Callsign _callsign(_c);
+    return _callsign.isValid();
+    //if (_c.length ()>=3)
+    //    return true;
+    //return false;
+}
+
+bool Adif::isValidQSLRCVD(const QString &_s, bool _importing)
+{    // Y, I, or V) (V on import only)
+    return ((_s == "Y") || (_s == "I") || ((_s == "V") && _importing));
+}
+
+bool Adif::isValidQSLSENT(const QString &_s)
+{// Y, Q, or I
+    return ((_s == "Y") || (_s == "Q") || (_s == "I"));
 }
 
 void Adif::logEvent(const QString &_func, const QString &_msg,  DebugLogLevel _level)
