@@ -37,6 +37,7 @@
 #include <QString>
 #include <QtDebug>
 #include <QStringList>
+
 //#include "locator.h"
 #include "klogdefinitions.h"
 
@@ -56,10 +57,10 @@ public:
     bool isValidITUz(const QString &_b);            // 1-90
     bool isValidDXCC(const QString &_b);            // 0-522
     bool isValidAge(const QString &_b);             // 0-120
+    bool isValidDistance(const QString &_b);        //>0.0
     bool isValidAnt_EL(const QString &_b);          //>=0-360
     bool isValidAnt_AZ(const QString &_b);          //>=-90-90
     bool isValidA_Index(const QString &_b);         //0-400
-    bool isValidDistance(const QString &_b);        //>0
     bool isValidIOTA_islandID(const QString &_b);   //1-99999999
     bool isValidNRBursts(const QString &_b);        //>0
     bool isValidPings(const QString &_b);            //>0
@@ -70,12 +71,20 @@ public:
     bool isValidUKSMG(const QString &_b);            //>0
     bool isValidTenTen(const QString &_b);            //>0
     bool isValidLogId(const QString &_b);            //>0
+    bool isValidAltitude (const QString &_s);       // > 10000 (10000 is a default value in KLog)
     bool isValidAntPath(const QString &_s);
-    bool isValidQSO_COMPLETE(const QString &_s);    // "Y", "N", "NIL", "?"
+    bool isValidMode (const QString &_s);
+    bool isValidQSO_COMPLETE(const QString &_s);        // "Y", "N", "NIL", "?"
+    QString getQSO_COMPLETEFromDB(const QString &_s);    // Translates the DB value into an ADIF value
+    bool isValidPOTA(const QString &_s);            // TODO
+    bool isValidWWFF_Ref(const QString &_s);        // TODO
+    bool isValidQSLRCVD(const QString &_s, bool _importing=true);         // Y, I, or V) (V on import only)
+    bool isValidQSLSENT(const QString &_s);         // Y, Q, or I
 
     void setLogLevel(DebugLogLevel _l);
     QString getADIFField(const QString &_fieldName, const QString &_data);
     QString getADIFBoolFromBool(const bool _b);             // Will produce the ADIF format if a bool is received
+    void setModes(const QStringList &_modes);            //TODO: Do not depend on external source to fill
 
 signals:
     void debugLog (QString _func, QString _msg, DebugLogLevel _level);
@@ -87,16 +96,16 @@ private:
     void setContinents();
     void setSponsorsList();
 
+
     bool isValidCall(const QString &_c);
 
     QString parentName;
     DebugLogLevel logLevel;
-    QHash<QString, QString> ADIFHash; // Name, type
-
-    QStringList ARRL_sects, continents, sponsorsList;
+    QHash<QString, QString> ADIFHash;   // Name, type
+    QStringList notZeroFields;          // Numeral ADIF fields where having a Zero makes no sense
 
+    QStringList ARRL_sects, continents, sponsorsList, modes;
 };
 
 #endif // ADIF_H
 
-
