@@ -40,7 +40,6 @@ StatsCQZPerYearBarChartWidget::StatsCQZPerYearBarChartWidget(DataProxy_SQLite *d
 
 void StatsCQZPerYearBarChartWidget::createUI()
 {
-
     chartView->setRenderHint(QPainter::Antialiasing);
 
     QVBoxLayout *graphLayout = new QVBoxLayout;
@@ -50,7 +49,7 @@ void StatsCQZPerYearBarChartWidget::createUI()
 
 StatsCQZPerYearBarChartWidget::~StatsCQZPerYearBarChartWidget()
 {
-    delete(dataProxy);
+    //delete(dataProxy);
 }
 
 void StatsCQZPerYearBarChartWidget::prepareChart(const int _log)
