@@ -1,5 +1,5 @@
-#ifndef CHARTS_KLOG_STATSDXCCSONSATSWIDGET_H
-#define CHARTS_KLOG_STATSDXCCSONSATSWIDGET_H
+#ifndef KLOG_CHARTS_STATSDXCCSONSATSWIDGET_H
+#define KLOG_CHARTS_STATSDXCCSONSATSWIDGET_H
 /***************************************************************************
                           statsdxccsonsatswidget.h  -  description
                              -------------------
@@ -39,12 +39,12 @@
 class StatsDXCCOnSatsWidget : public StatsGeneralChartWidget
 {
     Q_OBJECT
+
 public:
     StatsDXCCOnSatsWidget(DataProxy_SQLite *dp, QWidget *parent = nullptr);
     ~StatsDXCCOnSatsWidget();
     void prepareChart(const int _log=-1) override;
 
-
 signals:
 
 private slots:
@@ -58,6 +58,5 @@ private:
     QCheckBox *confirmedOnlyCheckBox, *onlyLEOSatCheckBox;
     QLabel *numberLabel;
     int log;
-
 };
 #endif // STATSGRIDSONSATSWIDGET_H
