@@ -48,7 +48,7 @@ StatsGridsOnSatsWidget::StatsGridsOnSatsWidget(DataProxy_SQLite *dp, QWidget *pa
 StatsGridsOnSatsWidget::~StatsGridsOnSatsWidget()
 {
     delete(util);
-    delete(dataProxy);
+   //delete(dataProxy);
 }
 
 void StatsGridsOnSatsWidget::createUI()
@@ -119,7 +119,6 @@ void StatsGridsOnSatsWidget::prepareChart(const int _log)
     grids.clear();
     if (_qsos.length()>0)
     {
-
         for (int i = 0; i<_qsos.length(); i++)
         {
             bool confirmed = false;
