@@ -30,6 +30,7 @@
 #include <QStringList>
 #include <QObject>
 #include <QSqlQuery>
+#include "global.h"
 #include "database.h"
 #include "qso.h"
 #include "utilities.h"
@@ -50,7 +51,6 @@ class DataProxy_SQLite : public QObject
     Q_OBJECT
 
 public:
-
     DataProxy_SQLite(const QString &_parentFunction, const QString &_softVersion="0.0");
     ~DataProxy_SQLite();
     void setLogLevel (const DebugLogLevel _l);
@@ -68,10 +68,10 @@ public:
     int getIdFromBandName(const QString& _bandName);
     int getSubModeIdFromSubMode(const QString &_subModeName);
     int getModeIdFromSubModeId(const int _sm);
-    void setCallValidation(const bool _v);
+
     QStringList getFields();
-    QStringList getBands();
-    QStringList getModes();
+    //KLOG_DEPRECATED QStringList getBands();
+    QStringList getModes(); // Returns the list of submodes
     QStringList sortBandNamesBottonUp(const QStringList _qs);
     QStringList getBandIDs();
     QStringList getModesIDs();
@@ -89,10 +89,11 @@ public:
     //QString getNameFromSubMode (const QString &_sm); // DEPRECATED
     bool isModeDeprecated (const QString &_sm);
 
-    QString getFreqFromBandId(const int _id);
+    Frequency getFreqFromBandId(const int _id);
     int getBandIdFromFreq(const double _n);
     QString getBandNameFromFreq(const double _n);
 
+
     double getLowLimitBandFromBandName(const QString &_sm);
     double getLowLimitBandFromBandId(const int _sm);
     double getUpperLimitBandFromBandName(const QString &_sm);
@@ -110,15 +111,15 @@ public:
                           const QDateTime &_datetime, const QDateTime &_datetime_off, const double txpower,
                           const int _dxcc, const int _logNumber, bool _sendQSL = true);
 
-    int addQSOFromLoTW(const QString &_call, const QDateTime _datetime, const QString &_mode, const QString &_band, const double _freq, const QDate _qslrdate, const QString &_stationcallsign, const int _logn);
-    int addQSO(QSO &_qso);
-    int addQSOQuery(const QSqlQuery &_q);
+    //int addQSO(QSO &_qso);
+    //int addQSOQuery(const QSqlQuery &_q);
 
     bool deleteQSO(const int _qsoId);
     int isWorkedB4(const QString &_qrz, const int _currentLog);
-    QList<int> isThisQSODuplicated(const QString &_callingFunc, const QString &_qrz, const QDateTime &_dateTime, const int _band, const int _mode, const int _secs);
+    //QList<int> isThisQSODuplicated(const QString &_callingFunc, const QString &_qrz, const QDateTime &_dateTime, const int _band, const int _mode, const int _secs);
+    QList<int> isThisQSODuplicated (const QSO &_qso, const int _secs);
     int getDuplicatedQSOId(const QString &_qrz, const QDateTime &_datetime, const int _band, const int _mode);
-    bool isDXCCConfirmed(const int _dxcc, const int _currentLog);
+    //bool isDXCCConfirmed(const int _dxcc, const int _currentLog);
     bool isQSLReceived(const int _qsoId);
     bool isQSLLoTWReceived(const int _qsoId);
     bool isQSOConfirmed(const int _qsoId, const bool _checkPaper, const bool _checkLoTW);
@@ -148,19 +149,9 @@ public:
 
     QString getCallFromId(const int _qsoId);
     QStringList getClubLogRealTimeFromId(const int _qsoId);
-    // Complete with previous
-    QString getNameFromQRZ(const QString &_call);
-    QString getQTHFromQRZ(const QString &_call);
-    QString getLocatorFromQRZ(const QString &_call);
-    QString getLocatorFromId (const int _id);
-    QString getIOTAFromQRZ(const QString &_call);
-    QString getQSLViaFromQRZ(const QString &_call);
-    // /Complete with previous
 
     QStringList getFilteredLocators(const QString &_band, const QString &_mode, const QString &_prop, const QString &_sat, bool _confirmed = false);
-
-    bool updateAwardDXCC();
-    bool updateAwardWAZ();
+    //bool updateAwardWAZ();
     // QRZ.com
     bool QRZCOMModifyFullLog(const int _currentLog); // Mark all the log as modified to be sent to QRZ.com
      bool QRZCOMSentQSOs(const QList<int> &_qsos); // Mark as uploaded
@@ -210,13 +201,14 @@ public:
     QString getEntityNameFromId(const int _n);
     int getEntityIdFromName(const QString &_e);
     QString getEntityMainPrefix(const int _entityN);
-    QStringList getEntiNameISOAndPrefixFromId(const int _dxcc);
+    QMap<EntityData, int> getAllEntiNameISOAndPrefix();
+
     int getEntityIdFromMainPrefix(const QString &_e);
     bool isNewCQz(int _c);
     bool isNewEntity(int _e);
     double getLongitudeFromEntity(const int _e);
     double getLatitudeFromEntity(const int _e);
-    int getDXCCFromPrefix(const QString &_p);
+    //KLOG_DEPRECATED int getDXCCFromPrefix(const QString &_p);           // TODO: Replace by int World::getPrefixId(const QString &_prefix)
     QString getEntityPrefixes(const int _enti);
     QStringList getLongPrefixes();
     QStringList getSpecialCallsigns();
@@ -225,7 +217,7 @@ public:
     QStringList getEntitiesIds();
     int getHowManyEntities();
     int getMaxEntityID(bool limit = true);      // limit = true implies that it will only shouw ARRL valid DXCC (i.e. will not count Sicily)
-
+    QList<int> getListOfDXCCIds();              // Returns the list of valid DXCC id
     QStringList getOperatingYears(const int _currentLog);
     void compressDB();
     bool unMarkAllQSO();            // Unmarks all the marked QSO
@@ -294,7 +286,7 @@ public:
 
     //QStringList getValidCatOptions(const int _currentCat, const int _lowerCa);
 
-    bool fillEmptyDXCCInTheLog();
+    //bool fillEmptyDXCCInTheLog();
 
     int getNumberOfManagedLogs();
     QStringList getListOfManagedLogs();
@@ -309,17 +301,21 @@ public:
     bool addNewLog (const QStringList _qs);
     bool doesThisLogExist(const int _log);
 
-    bool updateISONames(); // Update the entities ISO 3166names for the flags
+    bool updateISONames();                          // Update the entities ISO 3166names for the flags
     QString getISOName(const int _n);
-    bool setDXCCAwardStatus(const int _qsoId);
-    bool setWAZAwardStatus(const int _qsoId);
+    bool addPrimarySubdivisions();                  // Add the primary subdivisions to the BD
+    //bool setDXCCAwardStatus(const int _qsoId);
+    KLOG_DEPRECATED bool setWAZAwardStatus(const int _qsoId);
 
     //bool addRegionalAward(RegionalAward _regionalAward);
     bool addDXCCEntitySubdivision(const QString &_name, const QString &_short, const QString &_pref, const QString &_group, const int _regId, const int _dxcc, const int _cq, const int _itu, const QDate &_startDate, const QDate &_endDate, const bool _deleted);
+    QList<PrimarySubdivision> getPrimarySubDivisions(const int _entity, const QString &_pref);      // Get the Primary subdivisions for an entity
 
     //void getFoundInLog(const QString &_txt, const int _log=-1);
-    QString getADIFQSO(const int _qsoId, ExportMode _em = ModeADIF);
-    QString getADIFFromQSOQuery(QSqlQuery query, ExportMode _em = ModeADIF, bool _justMarked = false, bool _onlyRequested = false, int _logN = -1);
+    //KLOG_DEPRECATED QString getADIFQSO(const int _qsoId, ExportMode _em = ModeADIF);
+    QString getADIFValueFromRec(QSqlRecord _rec, const QString &_fieldName);   // To refactor the getADIFFromQSOQuery function
+    QString getADIFFromQSOQuery(QSqlRecord _rec, ExportMode _em = ModeADIF, bool _justMarked = false, bool _onlyRequested = false, int _logN = -1);
+    //QString getADIFFromQSOQuery2(QSqlRecord _rec, ExportMode _em = ModeADIF, bool _justMarked = false, bool _onlyRequested = false, int _logN = -1);
 
     bool showInvalidCallMessage(const QString &_call);
 
@@ -336,10 +332,14 @@ private:
     bool dbCreated;
     DataBase *db;
     QStringList sortBandIdBottonUp(const QStringList _qs);
-    double getFreqFromRange(QString _fr, int _pair = 0); //May even receive: 145.900-146.00 and should return the mid in the range (145.950)
+    double getFreqFromRange(QString _fr, int _pair = 0);            //May even receive: 145.900-146.00 and should return the mid in the range (145.950)
     QStringList getColumnNamesFromTable(const QString &_tableName);
-
-    int getPrefixId(const QString &_qrz);
+    QString getStringQueryStationCallSign (const QString &_a);      // Creates part of a query regarding the station_call field
+    QString getStringQueryMyGrid (const QString &_a);               // Creates part of a query regarding the my_gridsquare field
+    QString getStringQueryLogNumber (const int _a);                 // Creates part of a query regarding the lognumber field
+    //KLOG_DEPRECATED int getPrefixId(const QString &_qrz);           // TODO: Replace by int World::getPrefixId(const QString &_prefix)
+                               // Refactored from fillEmptyDXCCInTheLog
+    //bool updateDXCCAndContinent(const int _id, const int _dxcc, const QString &_cont); // Refactored from fillEmptyDXCCInTheLog
     //QString changeSlashAndFindPrefix(const QString &_qrz);
     void logEvent(const QString &_func, const QString &_msg, DebugLogLevel _level);
     QSO *qso;
@@ -355,7 +355,6 @@ signals:
     void qsoFound(const QStringList _qs); // Each: QString with format: Fieldname:value
     void queryError(QString functionFailed, QString errorCodeS, QString nativeError, QString failedQuery); // To alert about any failed query execution
     void debugLog (QString _func, QString _msg, DebugLogLevel _level);
-
 };
 
 #endif //DATAPROXY_SQLITE_H
