@@ -42,12 +42,14 @@ class DXCCStatusWidget : public QWidget
 {
     Q_OBJECT
 public:
-    explicit DXCCStatusWidget(DataProxy_SQLite *dp, const QString &_parentFunction, QWidget *parent = nullptr);
+    explicit DXCCStatusWidget(Awards *awards, QWidget *parent = nullptr);
+    //explicit DXCCStatusWidget(DataProxy_SQLite *dp, const QString &_parentFunction, Awards &awards, QWidget *parent = nullptr);
     ~DXCCStatusWidget();
 
     void update();
     //void awardsUpdated();
-    void setBands(const QString &_callingFunc, const QStringList &_ent, const bool _creating = false); // Receives the list of bandIDs
+    void setBands(const QString &_callingFunc, const QStringList &_listOfNewBands, const bool _creating = false); // Receives the list of bandIDs
+    void setColors (const QColor &_newOne, const QColor &_needed, const QColor &_worked, const QColor &_confirmed, const QColor &_default);
     void setCurrentLog(const int _logN);
     void setMyLocator(const QString &_loc);
     void refresh();
@@ -57,7 +59,7 @@ signals:
     void showQsos(QList<int> _qsos);
     void fillInQSOSignal();
     void debugLog (QString _func, QString _msg, DebugLogLevel _level);
-    //void updateAwards();
+    void updateAwards();
 
 public slots:
     //void slotSearchLineEditTextChanged();
@@ -72,33 +74,38 @@ private slots:
 
 private:
     void createUI();
+    void updateDXCCViewHeaders();               // Updaqtes the header, just for readability
+    QStringList filterValidBands(const QStringList &sortedBands);    // Removes a string if not a valid band
+    void fillData();                            // Calls all the functions to clean the table & fill the data
+    void resetDXCCView();                       // deletes the entities and bands from the table
+    void handleDXCCStatusUpdateFailure();       // Shows a message when there is a problem in update()
+    void processEntities();                     // Processes the Entities in update();
+    QList<int> getBandIds();                    // Return the list of bands
+    QIcon getFlagIcon(const QString _isoName);  // Returns the flag icon
     void setDefaultBands();
     void addEntity(const QList<int> &_ent); // DXCC id, bandid, bandid, ...
-    void addEntity2(const QStringList &_ent); // DXCC id, bandid, bandid, ...
 //    void showMenuRightButtonFromLogCreateActions();
 //    void righButtonFromLogMenu(const int trow);
 
-
     QTableWidget *dxccView;
-    Awards *awards;
+    Awards *awards;         // Reference to the Awards instance
     World *world;
     DataProxy_SQLite *dataProxy;
     Locator *locator;
 
+
     QHeaderView *hv, *hh;
     //QLineEdit *searchLineEdit;
     QPushButton *refreshButton;
     //QCheckBox *showAllLogsButton;
 
-
     int numberOfColumns; // Columns will be number Of Bands + 2 (Id + Name)
-    QStringList bandNames, validBands;
+    QStringList bandNames;//, validBands;
     int logNumber, tempLog; // log in use in the log / log to be used in the widget
     QString loc; // The locator of the user.
 
     QAction *showDXCCWikipediaAct;
     int currentLog;
-
 };
 
 #endif // DXCCSTATUSWIDGET_H
