@@ -75,10 +75,8 @@ eLogClubLog::~eLogClubLog()
         currentQSO = -1;
     }
 
-
     if (result == QNetworkReply::NoError)
     {
-
         text = "ClubLog: " + prepareToTranslate(sdata);
           //qDebug()<< sdata;
           //qDebug()<< Q_FUNC_INFO << " - NO ERROR";
@@ -89,8 +87,6 @@ eLogClubLog::~eLogClubLog()
             qsos.clear();
             return;
         }
-
-
     }
     else if (result == QNetworkReply::HostNotFoundError)
     {
@@ -155,7 +151,6 @@ eLogClubLog::~eLogClubLog()
     //emit done();
     //emit signalFileUploaded(result, qsos);
     emit showMessage(text);
-
 }
 
 void eLogClubLog::slotFileUploadFinished(QNetworkReply *data)
@@ -169,10 +164,8 @@ void eLogClubLog::slotFileUploadFinished(QNetworkReply *data)
 
     QString text;
 
-
     if (result == QNetworkReply::NoError)
     {
-
         text = "ClubLog: " + prepareToTranslate(sdata);
              //qDebug()<< "eLogClubLog::slotFileUploadFinished - Result = NoError = " << QString::number(result) ;
              //qDebug()<< sdata;
@@ -209,24 +202,8 @@ void eLogClubLog::slotErrorManagement(QNetworkReply::NetworkError networkError)
 {
          //qDebug()<< "eLogClubLog::slotErrorManagement: " << QString::number(networkError);
     result = networkError;
-
-    /*if (result == QNetworkReply::NoError)
-    {
-    }
-    else
-    if (result == QNetworkReply::HostNotFoundError)
-    {
-              //qDebug()<< "eLogClubLog::slotErrorManagement: Host not found";
-    }
-    else
-    {
-              //qDebug()<< "eLogClubLog::slotErrorManagement: ERROR!";
-    }
-    */
-    //actionError(result);
 }
 
-
 int eLogClubLog::sendQSO(QStringList _qso)
 {
       //qDebug() << "eLogClubLog::sendQSO: " << email << "/" << pass << "/" << api ;
@@ -265,7 +242,6 @@ int eLogClubLog::sendQSO(QStringList _qso)
     uploadingFile = false;
     return sendDataParams(tempCall, params, true);
     //return sendData(tempCall, qso);
-
 }
 /*
 int eLogClubLog::deleteQSOid(const int _qsoId)
@@ -333,13 +309,11 @@ int eLogClubLog::sendDataParams(const QString &_clublogCall, const QUrlQuery &_p
         params.addQueryItem("api",api);
     }
 
-
     postData = params.query(QUrl::FullyEncoded).toUtf8();
 
     QNetworkRequest request(serviceUrl);
     request.setHeader(QNetworkRequest::ContentTypeHeader, "application/x-www-form-urlencoded");
 
-
     //qDebug() << Q_FUNC_INFO << ": " << postData;
     manager->post(request, postData);
     //qDebug()<< Q_FUNC_INFO << ":  - END";
@@ -433,8 +407,8 @@ NOTES
     qso.clear();
     aux1 = _q.at(0);
       //qDebug()<< "eLogClubLog::getClubLogAdif: Date: " << _q.at(0) ;
-    if (QDate::fromString(aux1, "yyyyMMdd").isValid()){
-
+    if (QDate::fromString(aux1, "yyyyMMdd").isValid())
+    {
         qso = "<QSO_DATE:" + QString::number(aux1.length()) + ">" +  aux1  +  " ";
     }
     else
@@ -478,7 +452,6 @@ NOTES
         qso = qso + "<FREQ:" + QString::number((_q.at(9)).length()) + ">" + _q.at(9) + " ";
     }
 
-
        //qDebug()<< "eLogClubLog::getClubLogAdif: 90" ;
     qso = qso + "<QSL_RCVD:" + QString::number((_q.at(10)).length()) + ">" + _q.at(10) + " ";
        //qDebug()<< "eLogClubLog::getClubLogAdif: 100" ;
@@ -491,7 +464,6 @@ NOTES
         qso = qso + "<DXCC:" + QString::number((_q.at(13)).length()) + ">" + _q.at(13) + " ";
     }
 
-
        //qDebug()<< "eLogClubLog::getClubLogAdif: 130'" ;
     if ((_q.at(14)).toInt()> 0)
     {
@@ -516,8 +488,6 @@ void eLogClubLog::setDefaultCallsign(const QString &_defaultStationCallsign)
     stationCallsign = _defaultStationCallsign;
 }
 
-
-
 int eLogClubLog::deleteQSO(QStringList _qso)
 {
       //qDebug()<< "eLogClubLog::deleteQSO: length = " << QString::number(_qso.length());
@@ -543,7 +513,6 @@ int eLogClubLog::deleteQSO(QStringList _qso)
         tempCall = stationCallsign;
     }
 
-
     dxcall = _qso.at(5);
     QDateTime dateTime;
     dateTime.setDate(QDate::fromString(_qso.at(1), "yyyyMMdd"));
@@ -578,9 +547,7 @@ int eLogClubLog::deleteQSO(QStringList _qso)
     //params.addQueryItem("adif",qso);
     uploadingFile = false;
     return sendDataParams(tempCall, params, false);
-
     //return sendData(qso);
-
 }
 
 QString eLogClubLog::prepareToTranslate(const QString &_m)
@@ -721,7 +688,6 @@ void eLogClubLog::sendLogFile(const QString &_file, QList<int> _qso, bool _overw
     if (file->open(QIODevice::ReadOnly))        /* Flawfinder: ignore */
     {
          blob = file->readAll();
-
     }
     else
     {
