@@ -29,6 +29,7 @@
 #include <QUrl>
 #include <QNetworkRequest>
 #include <QFile>
+#include "callsign.h"
 //#include <QDebug>
 
 eLogQrzLog::eLogQrzLog(DataProxy_SQLite *dp, const QString &_parentFunction, const QString &_klogVersion)
@@ -57,8 +58,8 @@ eLogQrzLog::eLogQrzLog(DataProxy_SQLite *dp, const QString &_parentFunction, con
     uploadingFile = false;
     logged = false;
     util = new Utilities(Q_FUNC_INFO);
-    util->setLongPrefixes(dataProxy->getLongPrefixes());
-    util->setSpecialCalls(dataProxy->getSpecialCallsigns());
+    //util->setLongPrefixes(dataProxy->getLongPrefixes());
+    //util->setSpecialCalls(dataProxy->getSpecialCallsigns());
    // serviceUrl = QUrl("https://xmldata.qrz.com/xml/current/");
     //serviceUrl = QUrl("https://xmldata.qrz.com/xml/1.31/ ");
    //qDebug()<< "eLogQrzLog::eLogQrzLog - END" ;
@@ -93,7 +94,6 @@ void eLogQrzLog::setLogBookKey(const QString &_key)
 
 void eLogQrzLog::parseNetworkError(QNetworkReply::NetworkError _error)
 {
-
     showDebugLog (Q_FUNC_INFO, "Start: " + QString::number(_error));
     QString text;
     switch (_error) {
@@ -163,7 +163,7 @@ void eLogQrzLog::slotManagerLogFinished(QNetworkReply *data)
 void eLogQrzLog::parseXMLAnswer(QXmlStreamReader &xml)
 {
     //qDebug() << Q_FUNC_INFO << xml.text();
-    showDebugLog (Q_FUNC_INFO, "Start: " + xml.text());
+    showDebugLog (Q_FUNC_INFO, QString("Start: ").append(xml.text()));
     QString tdata = QString();
 
     while (!xml.atEnd())
@@ -501,7 +501,6 @@ void eLogQrzLog::slotManagerFinished(QNetworkReply *data)
     emit showMessage(text);
     showDebugLog (Q_FUNC_INFO, "Text: " + text);
     showDebugLog (Q_FUNC_INFO, "END");
-
 }
 
 void eLogQrzLog::downloadProgress(qint64 received, qint64 total) {
@@ -581,7 +580,8 @@ void eLogQrzLog::checkQRZ(const QString &_qrz)
 {
     //qDebug() << Q_FUNC_INFO << ": " + _qrz;
     showDebugLog (Q_FUNC_INFO, "Start: " + _qrz);
-    if (!util->isValidCall(_qrz))
+    Callsign callsign(_qrz);
+    if (!callsign.isValid())
     {
         //qDebug()<< "eLogQrzLog::checkQRZ: CALL not valid" ;
         showDebugLog (Q_FUNC_INFO, "CALL not valid");
@@ -641,7 +641,12 @@ int eLogQrzLog::sendQSO(const int _qsoID)
     // Received an ID, obtains the ADIF fo QRZ.com from dataProxy and sends it t QRZ.com
     //qDebug() << "eLogQrzLog::sendQSO: "  << QString::number(_qsoID);
     showDebugLog (Q_FUNC_INFO, "Start: " + QString::number(_qsoID));
-    QString adifQSO = dataProxy->getADIFQSO(_qsoID, ModeEQSL);
+    QSO qso;
+    qso.fromDB(_qsoID);
+    if (!qso.isComplete())
+        return -1;
+    //QString adifQSO = dataProxy->getADIFQSO(_qsoID, ModeEQSL);
+    QString adifQSO =  qso.getADIF();
 
     //qDebug()<< "eLogQrzLog::sendQSO: (ADIF) :" << adifQSO;
     //qDebug()<< "eLogQrzLog::sendQSO: (KEY) :" << logbookkey;
@@ -737,7 +742,6 @@ void eLogQrzLog::login()
     //}
     //qDebug()<< "eLogQrzLog::login - END" ;
     showDebugLog (Q_FUNC_INFO, "END");
-
 }
 
 int eLogQrzLog::sendDataParams(const QUrlQuery &_params)
@@ -774,7 +778,6 @@ void eLogQrzLog::setUser(const QString &_user)
 
 void eLogQrzLog::setPassword(const QString &_pass)
 {
-
     showDebugLog (Q_FUNC_INFO, "Start: " + _pass);
     pass = _pass;
     showDebugLog (Q_FUNC_INFO, "END");
