@@ -35,26 +35,26 @@ FileAwardManager::FileAwardManager(DataProxy_SQLite *dp, const QString &_parentF
 }
 FileAwardManager::~FileAwardManager()
 {
-    delete(dataProxy);
+   //delete(dataProxy);
     delete(util);
     delete(world);
 }
 
 bool FileAwardManager::importNewAwardFile()
 {
-    //qDebug() << "FileAwardManager::importNewAwardFile" ;
+    //qDebug() << Q_FUNC_INFO << " -  " ;
     QString fileName = QFileDialog::getOpenFileName(nullptr, tr("Open Award file"), util->getHomeDir(), tr("Award files (*.awa)"));
-    //qDebug() << "FileAwardManager::importNewAwardFile - file: " << fileName ;
+    //qDebug() << Q_FUNC_INFO << " -   - file: " << fileName ;
     QFile file( fileName );
     if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) /* Flawfinder: ignore */
     {
-        //qDebug() << "FileAwardManager::importNewAwardFile File not found" << fileName;
+        //qDebug() << Q_FUNC_INFO << " -   File not found" << fileName;
         showError(tr("Award file not opened"), tr("KLog was not able to read the award file"), QString(tr("It was not possible to open the file %1 for reading.") ).arg(fileName));
         return false;
     }
     else
     {
-        //qDebug() << "FileAwardManager::importNewAwardFile File opened";
+        //qDebug() << Q_FUNC_INFO << " -   File opened";
     }
 
     QString line = QString();
@@ -78,10 +78,10 @@ bool FileAwardManager::importNewAwardFile()
 
     while ( !file.atEnd() )
     { // KLog first read the full file, to detect potential format errors and counting the number of references
-        //qDebug() << "FileAwardManager::importNewAwardFile: First read, counting and looking for errors: " << line;
+        //qDebug() << Q_FUNC_INFO << " -  : First read, counting and looking for errors: " << line;
 
         line = file.readLine().trimmed().toUpper();
-        //qDebug() << "FileAwardManager::importNewAwardFile: " << line;
+        //qDebug() << Q_FUNC_INFO << " -  : " << line;
         number = number + line.count("EOR>");
         if ((line.count("<EOH>")>0) )
         {
@@ -89,7 +89,7 @@ bool FileAwardManager::importNewAwardFile()
         }
         //qDebug() << " //FileAwardManager::importNewAwardFile in the while, end of loop" ;
     }
-    //qDebug() << "FileAwardManager::importNewAwardFile: While finished " ;
+    //qDebug() << Q_FUNC_INFO << " -  : While finished " ;
     if (!hasEOH)
     {
         showError(tr("AWA wrong format"), tr("The AWA file does not have the right format"), QString(tr("AWA file does not have an <EOH> field") ));
@@ -117,7 +117,7 @@ bool FileAwardManager::importNewAwardFile()
 
             foreach (aux, fields)
             {
-                //qDebug() << "FileAwardManager::importNewAwardFile: Reading header: " << aux;
+                //qDebug() << Q_FUNC_INFO << " -  : Reading header: " << aux;
                 aux = aux.trimmed();
                 aux = "<" + aux;
                 QStringList adifField;
@@ -145,12 +145,10 @@ bool FileAwardManager::importNewAwardFile()
                     {
                         //regionalAward->addRegionalAwardName(adifField.at(1));
                     }
-
                     else
                     {
-                        //qDebug() << "FileAwardManager::importNewAwardFile: Invalid AWA field found HEADER" << adifField.at(0);
+                        //qDebug() << Q_FUNC_INFO << " -  : Invalid AWA field found HEADER" << adifField.at(0);
                     }
-
                 }
                 aux.clear();
             }
@@ -158,7 +156,7 @@ bool FileAwardManager::importNewAwardFile()
         else
         { // NOT in EOH
             // Read line, MODIFY AWARD
-            //qDebug() << "FileAwardManager::importNewAwardFile: Parsing : " << line;
+            //qDebug() << Q_FUNC_INFO << " -  : Parsing : " << line;
             foreach (aux, fields)
             {
                 aux = aux.trimmed();
@@ -166,10 +164,10 @@ bool FileAwardManager::importNewAwardFile()
                 QStringList adifField;
                 adifField.clear();
                 adifField << util->getValidADIFFieldAndData(aux);
-                //qDebug() << "FileAwardManager::importNewAwardFile: Length: " << QString::number(adifField.count());
+                //qDebug() << Q_FUNC_INFO << " -  : Length: " << QString::number(adifField.count());
                 if (adifField.count()==2)
                 {
-                    //qDebug() << "FileAwardManager::importNewAwardFile: Parsing : (" << adifField.at(0) << "/" << adifField.at(1) << ")";
+                    //qDebug() << Q_FUNC_INFO << " -  : Parsing : (" << adifField.at(0) << "/" << adifField.at(1) << ")";
                     if (adifField.at(0) == "SUBDIV_REFNUMBER" )
                     {
                         sub_regionalID = adifField.at(1).toInt();
@@ -204,7 +202,7 @@ bool FileAwardManager::importNewAwardFile()
                     }
                     else if (adifField.at(0) == "EOR")
                     {// END OF REGISTRY
-                        //qDebug() << "FileAwardManager::importNewAwardFile: EOR FOUND!\nLet's add the reference.";
+                        //qDebug() << Q_FUNC_INFO << " -  : EOR FOUND!\nLet's add the reference.";
                         QStringList _subDiv;
                         dataProxy->addDXCCEntitySubdivision(sub_name, sub_shortname, sub_prefix, sub_regionalGroup,
                                                             sub_regionalID, sub_dxcc, sub_cqz, sub_ituz, sub_startDate, sub_endDate, sub_deleted);
@@ -222,12 +220,12 @@ bool FileAwardManager::importNewAwardFile()
                     }
                  else
                 {
-                    //qDebug() << "FileAwardManager::importNewAwardFile: Invalid AWA field found in BODY" << adifField.at(0);
+                    //qDebug() << Q_FUNC_INFO << " -  : Invalid AWA field found in BODY" << adifField.at(0);
                 }
-            }}
+            }
+            }
         }
     }
-
     return false;
 }
 
