@@ -69,10 +69,9 @@ public:
     ~FileManager();
     void init();
     //bool readAdif(const QString& tfileName, const int logN);
-    bool adifReadLog(const QString& tfileName, const int logN);
-    bool adifReadLog2(const QString& tfileName, const int logN);
-    QList<int> adifLoTWReadLog2(const QString& fileName, const int logN);
-    QList<int> adifLoTWReadLog(const QString& tfileName, const int logN);
+    //bool adifReadLog(const QString& tfileName, const int logN);
+    int adifReadLog2(const QString& tfileName, QString _stationCallsign = QString(), int logN = -1);
+    int adifLoTWReadLog2(const QString& fileName, const int logN);
     //QList<int> adifLoTWLogExport(const QString& _fileName, const QString &_callsign, const QDate &_startDate, const QDate &_endDate, const int _logN);
     //QList<int> (const QString& _fileName, const QString &_callsign, const QDate &_startDate, const QDate &_endDate, const int _logN, const bool LoTWOnly);
 
@@ -90,10 +89,8 @@ public:
     void setStationCallSign(const QString& _st);
     void setDuplicatedQSOSlot (const int _secs);
     void setSendQSLByDefault (const bool _send);
-    void setCallValidation (const bool _b);
 
 private:
-
     bool adifLogExportToFile(const QString& _fileName, const int _logN, bool justMarked, bool _qslRequested, bool _lotw);
     //bool cabrilloLogExportToFile(const QString& _fileName, const int logNconst);
     //bool cabrilloLogExportCQWWToFile(const QString& _fileName, const int logNconst);
@@ -114,7 +111,7 @@ private:
 
     //QString checkAndFixASCIIinADIF(_data);
 
-    bool processQsoReadingADIF(const QStringList &_line, const int logNumber);//, const bool _keepLogsInFile);
+    //bool processQsoReadingADIF(const QStringList &_line, const int logNumber);//, const bool _keepLogsInFile);
     void queryPreparation(const int _logN);
 
     bool checkADIFValidFormat(const QStringList &_qs);
@@ -122,7 +119,7 @@ private:
     QStringList readAdifField (const QString &_field);
     // void writeAdifField(const QString &_field, const QString &_data); // It should possibly receive also the QTextStream
 
-    void writeQuery(QSqlQuery query, QTextStream &out, const ExportMode _em, const bool _justMarked, const bool _onlyRequested, const int _logN);
+    void writeQuery(QSqlRecord &rec, QTextStream &out, const ExportMode _em, const bool _justMarked, const bool _onlyRequested, const int _logN);
     void writeADIFHeader(QTextStream &out, const ExportMode _em, const int _numberOfQsos);
 
 
@@ -138,7 +135,6 @@ private:
 
     bool rstTXDefault, rstRXDefault; // If true and a log is not including RST, 59 is automatically added
 
-
     //bool printQs(const QString &_q, const QStringList _line);
     bool printQs(const QStringList &_line);
     //int confirmed;
@@ -170,6 +166,5 @@ private:
 signals:
     void addQSOToList(QStringList _qso);
     void queryError(QString _functionFailed, QString errorCodeS, QString nativeError, QString failedQuery); // To alert about any failed query execution
-
 };
 #endif // FILEMANAGER_H
