@@ -300,12 +300,11 @@ void InfoWidget::createUI()
 #endif
 
     setLayout(mainLayout);
-
 }
 
 void InfoWidget::clearBandLabels()
 {
-    QString defaultColorName = (awards->getDefaultColor()).name();
+    QString defaultColorName = (awards->getDefaultColor()).name(QColor::HexRgb);
     bandLabel1->setStyleSheet("* { background-color: " + defaultColorName + "; }");
     bandLabel2->setStyleSheet("* { background-color: " + defaultColorName + "; }");
     bandLabel3->setStyleSheet("* { background-color: " + defaultColorName + "; }");
@@ -340,7 +339,7 @@ void InfoWidget::clear()
     clearInfoFromLocators();
 }
 
-void InfoWidget::setColors (const QString &_newOne, const QString &_needed, const QString &_worked, const QString &_confirmed, const QString &_default)
+void InfoWidget::setColors (const QColor &_newOne, const QColor &_needed, const QColor &_worked, const QColor &_confirmed, const QColor &_default)
 {
     awards->setColors (_newOne, _needed, _worked, _confirmed, _default);
     clearBandLabels();
@@ -369,41 +368,46 @@ void InfoWidget::setImperialSystem (const  bool _imp)
     }
 }
 
-QString InfoWidget::getStyleColorToLabelFromBand(const QString &_b, const QString &_q)
+QString InfoWidget::getStyleColorToLabelFromBand(const int _bandId, const int _entityId)
 { // Receives band name, Entity number (as a String)
-   //qDebug() << "InfoWidget::getStyleColorToLabelFromBand: " << _b << "/" << _q;
-   QStringList _qs;
-    _qs.clear();
+   //qDebug() << Q_FUNC_INFO << ": " << _b << "/" << _q;
+    EntityStatus _entityStatus;
+    _entityStatus.dxcc  = _entityId;
+    _entityStatus.bandId    = _bandId;
+    _entityStatus.modeId    = -1;
+    _entityStatus.logId       = currentLog;
 
-    _qs << _q << QString::number(dataProxy->getIdFromBandName(_b)) << QString::number(-1) << QString::number(currentLog);
     //TODO: Check if we can know the mode and replace the -1
-    //qDebug() << "InfoWidget::getStyleColorToLabelFromBand (Band/background-color): " << _b << (awards->getQRZDXStatusColor(_qs)).name() ;
-    return "* { background-color: " + (awards->getQRZDXStatusColor(_qs)).name() + "; }";
+    //qDebug() << Q_FUNC_INFO << ": (Band/background-color): " << _b << (awards->getQRZDXStatusColor(_qs)).name(QColor::HexRgb) ;
+    return "* { background-color: " + (awards->getQRZDXStatusColor(_entityStatus)).name(QColor::HexRgb) + "; }";
 }
 
 
 //void InfoWidget::showInfo(const int _entity, const int _bandid, const int _modeid, const int _log)
 void InfoWidget::showInfo(const int _entity)
 { // Default values of _modeid & _log = -1
-    //qDebug() << "InfoWidget::showInfo: " << QString::number(_entity);
+    //qDebug() << Q_FUNC_INFO << " - Start";
+    //qDebug() << Q_FUNC_INFO << ": " << QString::number(_entity);
     //QColor getQRZDXStatusColor(const QStringList _qs); // Receives Entity, band, mode & log
     if (_entity <1)
     {
-      clearBandLabels();
+        //qDebug() << Q_FUNC_INFO << ": entity <1";
+        clearBandLabels();
     }
 
-    bandLabel1->setStyleSheet(getStyleColorToLabelFromBand(bandLabel1->text(), QString::number(_entity)));
-    bandLabel2->setStyleSheet(getStyleColorToLabelFromBand(bandLabel2->text(), QString::number(_entity)));
-    bandLabel3->setStyleSheet(getStyleColorToLabelFromBand(bandLabel3->text(), QString::number(_entity)));
-    bandLabel4->setStyleSheet(getStyleColorToLabelFromBand(bandLabel4->text(), QString::number(_entity)));
-    bandLabel5->setStyleSheet(getStyleColorToLabelFromBand(bandLabel5->text(), QString::number(_entity)));
-    bandLabel6->setStyleSheet(getStyleColorToLabelFromBand(bandLabel6->text(), QString::number(_entity)));
-    bandLabel7->setStyleSheet(getStyleColorToLabelFromBand(bandLabel7->text(), QString::number(_entity)));
-    bandLabel8->setStyleSheet(getStyleColorToLabelFromBand(bandLabel8->text(), QString::number(_entity)));
-    bandLabel9->setStyleSheet(getStyleColorToLabelFromBand(bandLabel9->text(), QString::number(_entity)));
-    bandLabel10->setStyleSheet(getStyleColorToLabelFromBand(bandLabel10->text(), QString::number(_entity)));
-    bandLabel11->setStyleSheet(getStyleColorToLabelFromBand(bandLabel11->text(), QString::number(_entity)));
-    bandLabel12->setStyleSheet(getStyleColorToLabelFromBand(bandLabel12->text(), QString::number(_entity)));
+    bandLabel1->setStyleSheet(getStyleColorToLabelFromBand(dataProxy->getIdFromBandName(bandLabel1->text()), _entity));
+    bandLabel2->setStyleSheet(getStyleColorToLabelFromBand(dataProxy->getIdFromBandName(bandLabel2->text()), _entity));
+    bandLabel3->setStyleSheet(getStyleColorToLabelFromBand(dataProxy->getIdFromBandName(bandLabel3->text()), _entity));
+    bandLabel4->setStyleSheet(getStyleColorToLabelFromBand(dataProxy->getIdFromBandName(bandLabel4->text()), _entity));
+    bandLabel5->setStyleSheet(getStyleColorToLabelFromBand(dataProxy->getIdFromBandName(bandLabel5->text()), _entity));
+    bandLabel6->setStyleSheet(getStyleColorToLabelFromBand(dataProxy->getIdFromBandName(bandLabel6->text()), _entity));
+    bandLabel7->setStyleSheet(getStyleColorToLabelFromBand(dataProxy->getIdFromBandName(bandLabel7->text()), _entity));
+    bandLabel8->setStyleSheet(getStyleColorToLabelFromBand(dataProxy->getIdFromBandName(bandLabel8->text()), _entity));
+    bandLabel9->setStyleSheet(getStyleColorToLabelFromBand(dataProxy->getIdFromBandName(bandLabel9->text()), _entity));
+    bandLabel10->setStyleSheet(getStyleColorToLabelFromBand(dataProxy->getIdFromBandName(bandLabel10->text()), _entity));
+    bandLabel11->setStyleSheet(getStyleColorToLabelFromBand(dataProxy->getIdFromBandName(bandLabel11->text()), _entity));
+    bandLabel12->setStyleSheet(getStyleColorToLabelFromBand(dataProxy->getIdFromBandName(bandLabel12->text()), _entity));
+    //qDebug() << Q_FUNC_INFO << " - END";
 }
 
 void InfoWidget::showEntityInfo(const int _enti, int _cq, int _itu)
@@ -472,7 +476,6 @@ void InfoWidget::showEntityInfo(const int _enti, int _cq, int _itu)
             ituzLabel->setText("0");
         }
     }
-
 }
 
 
@@ -484,7 +487,6 @@ void InfoWidget::showDistanceAndBearing(const QString &_locLocal, const QString
 
     if ( locator->isValidLocator(lloc)  )
     {
-
         if ( locator->isValidLocator(ldx)  )
         {
             dxLocator = ldx;
