@@ -30,6 +30,7 @@
 //
 #include <QWidget>
 #include <QtWidgets>
+#include "../qso.h"
 
 class MainWindowInputComment : public QWidget
 {
@@ -44,12 +45,13 @@ public:
     void clear(bool _full = false); //full= false leaves the "keep this data"; full = true clears everything
     void setKeep(const bool _b);
     bool getKeep();
+    QSO getQSOData(QSO _qso);
+    void setQSOData(const QSO &_qso);
 
 private:
     QString comment;
     QLineEdit *commentLineEdit;
     QCheckBox *keepThisDataForNextQSOQCheckbox;
-
 };
 
 #endif // MAINWINDOWINPUTCOMMENT_H
