@@ -33,17 +33,20 @@
 #include <QWidget>
 #include "../dataproxy_sqlite.h"
 #include "../utilities.h"
+#include "../qso.h"
 
 class MainWindowInputEQSL : public QWidget
 {
     Q_OBJECT
+
 public:
     explicit MainWindowInputEQSL(DataProxy_SQLite *dp, QWidget *parent = nullptr);
     ~MainWindowInputEQSL();
 
     //void setData(const QString &_comment);
     //QString getComment();
-
+    QSO getQSOData(QSO _qso);
+    void setQSOData(const QSO &_qso);
     void clear();
 
     QString getQRZCOMStatus();
@@ -76,7 +79,6 @@ public:
 
     void setQueueSentByDefault(const bool _b);
 
-
 signals:
 
 private slots:
@@ -100,7 +102,6 @@ private:
 
     QStringList qslSentStatusList, qslRcvdStatusList, clubLogStatusList;
     bool queueSentByDefault;
-
 };
 
 #endif // MAINWINDOWINPUTEQSL_H
