@@ -26,6 +26,8 @@
 
 
 #include "mainwindowinputothers.h"
+#include "../adif.h"
+#include "../callsign.h"
 
 MainWindowInputOthers::MainWindowInputOthers(DataProxy_SQLite *dp, QWidget *parent) :
     QWidget(parent)
@@ -33,26 +35,33 @@ MainWindowInputOthers::MainWindowInputOthers(DataProxy_SQLite *dp, QWidget *pare
        //qDebug() << Q_FUNC_INFO;
     logLevel = None;
     dataProxy = dp;
+    world = new World(dataProxy,Q_FUNC_INFO);
 
     util = new Utilities(Q_FUNC_INFO);
+    //util->setLongPrefixes(dataProxy->getLongPrefixes());
+    //util->setSpecialCalls(dataProxy->getSpecialCallsigns());
 
     //QLabel *entityPrimLabel, *entitySecLabel, *iotaAwardLabel, *entityNameLabel, *propModeLabel;
-    iotaContinentComboBox = new QComboBox();
-    entityPrimDivComboBox = new QComboBox();
-    entitySecDivComboBox = new QComboBox();
-    entityNameComboBox = new QComboBox();
-    propModeComboBox = new QComboBox();
-    iotaNumberLineEdit = new QLineEdit();
-    keepPropCheckBox = new QCheckBox();
-    userDefinedADIFComboBox = new QComboBox();
-    userDefinedADIFValueLineEdit = new QLineEdit();
+    iotaContinentComboBox           = new QComboBox();
+    entityPrimDivComboBox           = new QComboBox();
+    entitySecDivComboBox            = new QComboBox();
+    entityNameComboBox              = new QComboBox();
+    propModeComboBox                = new QComboBox();
+    iotaNumberLineEdit              = new QLineEdit();
+    keepPropCheckBox                = new QCheckBox();
+    showAllCheckBox                 = new QCheckBox();
+    userDefinedADIFComboBox         = new QComboBox();
+    userDefinedADIFValueLineEdit    = new QLineEdit();
 
     // TODO: I should find the way to connect the SAT tabwidget's signal to set the propmode in this widget
     //       Now it is done though the mainwindow but I should avoid depending on that class for that, if possible
     //connect(satTabWidget, SIGNAL(setPropModeSat(QString)), this, SLOT(slotSetPropMode(QString)) ) ;
-    connect(propModeComboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(slotPropModeComboBoxChanged() ) ) ;
-    connect(userDefinedADIFComboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(slotUSerDefinedADIFComboBoxChanged() ) ) ;
-    connect(userDefinedADIFValueLineEdit, SIGNAL(textChanged(QString)), this, SLOT(slotSetCurrentUSerData() ) );
+    connect(entityNameComboBox,             SIGNAL(currentIndexChanged(int)),   this, SLOT(slotEntityNameComboBoxChanged() ) ) ;
+    connect(propModeComboBox,               SIGNAL(currentIndexChanged(int)),   this, SLOT(slotPropModeComboBoxChanged() ) ) ;
+    connect(userDefinedADIFComboBox,        SIGNAL(currentIndexChanged(int)),   this, SLOT(slotUSerDefinedADIFComboBoxChanged() ) ) ;
+    connect(userDefinedADIFValueLineEdit,   SIGNAL(textChanged(QString)),       this, SLOT(slotSetCurrentUserData() ) );
+    connect(entityPrimDivComboBox,          SIGNAL(currentIndexChanged(int)),   this, SLOT(slotPrimarySubdivisionsComboBoxChanged()) )  ;
+    connect(showAllCheckBox,                SIGNAL(stateChanged(int)),          this, SLOT(slotShowAllCheckBoxChanged() ) ) ;
 
     createUI();
     setInitialADIFValues ();
@@ -65,9 +74,46 @@ MainWindowInputOthers::~MainWindowInputOthers()
     delete(util);
 }
 
+QSO MainWindowInputOthers::getQSOData(QSO _qso)
+{
+    QSO qso = _qso;
+
+    qso.setDXCC(getEntity());
+    qso.setState(getState());
+    //qso.setCounty()           //TODO: Related to entitySecDivComboBox when implemented
+    qso.setIOTA(getIOTA());
+    qso.setPropMode(getPropModeFromComboBox());
+    qso.setSOTA_REF(getSOTA());
+    qso.setAge(getAge());
+    qso.setDistance(getDistance());
+    qso.setSIG(getSIG());
+    qso.setSIG_INFO(getSIG_INFO());
+    qso.setVUCCGrids(getVUCCGrids());
+    qso.setWWFF_Ref(getWWFF_Ref());
+    qso.setPOTA_Ref(getPOTA_REF());
+    return qso;
+}
+
+void MainWindowInputOthers::setQSOData(const QSO &_qso)
+{
+    QSO qso(_qso);
+    setEntity(qso.getDXCC());
+    setPropMode(qso.getPropMode(), false);
+    setSOTA(qso.getSOTA_REF());
+    setAge(qso.getAge());
+    setDistance(qso.getDistance());
+    setVUCCGrids(qso.getVUCCGrids());
+    setPOTA_REF(qso.getPOTA_Ref());
+    setSIG(qso.getSIG());
+    setSIG_INFO(qso.getSIG_INFO());
+    setWWFF_Ref(qso.getWWFF_Ref());
+    setIOTA(qso.getIOTA());
+    setState(qso.getState());
+}
+
 void MainWindowInputOthers::createUI()
 {
-      //qDebug() << Q_FUNC_INFO ;
+   //qDebug() << Q_FUNC_INFO ;
     logEvent (Q_FUNC_INFO, "Start", Debug);
 
     entitiesList.clear();
@@ -75,19 +121,26 @@ void MainWindowInputOthers::createUI()
     adifValidTypes.clear();
     autoUpdating = false;
 
-    sota_ref = QString();
-    distance = 0;
-    age = 0;
+    sota_ref    = QString();
+    distance    = 0;
+    age         = 0;
+    currentInt  = 0;
+    currentPref = QString();
+    pota_ref    = QString();
+    sig         = QString();
+    sig_info    = QString();
+    wwff_ref    = QString();
+    darkMode    = false;
 
     palRed.setColor(QPalette::Text, Qt::red);
     palBlack.setColor(QPalette::Text, Qt::black);
     palWhite.setColor(QPalette::Text, Qt::white);
 
     QLabel *entityPrimLabel = new QLabel(tr("Primary Div"));
-    QLabel *entitySecLabel = new QLabel(tr("Secondary Div"));
-    QLabel *iotaAwardLabel = new QLabel(tr("IOTA"));
+    QLabel *entitySecLabel  = new QLabel(tr("Secondary Div"));
+    QLabel *iotaAwardLabel  = new QLabel(tr("IOTA"));
     QLabel *entityNameLabel = new QLabel(tr("Entity"));
-    QLabel *propModeLabel = new QLabel(tr("Propagation mode"));
+    QLabel *propModeLabel   = new QLabel(tr("Propagation mode"));
     QLabel *userSelectLabel = new QLabel(tr("Others"));
 
     entityPrimLabel->setAlignment(Qt::AlignVCenter| Qt::AlignRight);
@@ -98,6 +151,7 @@ void MainWindowInputOthers::createUI()
     userSelectLabel->setAlignment(Qt::AlignVCenter| Qt::AlignRight);
 
     keepPropCheckBox->setText(tr("Keep propagation mode"));
+    showAllCheckBox->setText(tr("Show All"));
 
     entityPrimDivComboBox->setToolTip(tr("Select the primary division for this QSO."));
     entitySecDivComboBox->setToolTip(tr("Select the secondary division for this QSO."));
@@ -106,57 +160,66 @@ void MainWindowInputOthers::createUI()
     iotaContinentComboBox->setToolTip(tr("Select the IOTA continent for this QSO."));
     iotaNumberLineEdit->setToolTip(tr("Select the IOTA reference number for this QSO."));
     keepPropCheckBox->setToolTip(tr("Keeps the same propagation mode for next QSO."));
+    showAllCheckBox->setToolTip(tr("Show all subdivisions for the current DXCC Entity."));
 
     userDefinedADIFComboBox->setToolTip(tr("Select the appropriate ADIF field for this QSO."));
     userDefinedADIFValueLineEdit->setToolTip (tr("Value for the selected ADIF field."));
 
-    entityPrimDivComboBox->setEnabled(false);
+    entityPrimDivComboBox->setEnabled(true);
     entitySecDivComboBox->setEnabled(false);
     entityNameComboBox->setEnabled(true);
     propModeComboBox->setEnabled(true);
     keepPropCheckBox->setEnabled(true);
+    showAllCheckBox->setEnabled(true);
 
     QHBoxLayout *keepLayout = new QHBoxLayout;
     keepLayout->addWidget(propModeComboBox);
     //keepLayout->addWidget(keepPropCheckBox);
     keepLayout->setSizeConstraint(QLayout::SetFixedSize);
 
+
     QGridLayout *tabLayout = new QGridLayout;
     tabLayout->addWidget(entityNameLabel, 0, 0);
     tabLayout->addWidget(entityNameComboBox, 0, 1, 1, 2);
     tabLayout->addWidget(entityPrimLabel, 1, 0);
     tabLayout->addWidget(entityPrimDivComboBox, 1, 1, 1, 2);
+    tabLayout->addWidget(showAllCheckBox, 1, 3);
     tabLayout->addWidget(entitySecLabel, 2, 0);
     tabLayout->addWidget(entitySecDivComboBox, 2, 1, 1, 2);
     tabLayout->addWidget(iotaAwardLabel, 3, 0);
     tabLayout->addWidget(iotaContinentComboBox, 3, 1);
     tabLayout->addWidget(iotaNumberLineEdit, 3, 2);
     tabLayout->addWidget(propModeLabel, 4, 0);
+    tabLayout->addWidget(propModeComboBox, 4, 1, 1, 2);
     tabLayout->addLayout(keepLayout, 4, 1, 1, 2);
-    tabLayout->addWidget(entityPrimLabel, 1, 0);
-    tabLayout->addWidget(entityPrimDivComboBox, 1, 1, 1, 2);
+
     tabLayout->addWidget(userSelectLabel, 5, 0);
     tabLayout->addWidget(userDefinedADIFComboBox, 5, 1);
     tabLayout->addWidget(userDefinedADIFValueLineEdit, 5, 2);
     tabLayout->addWidget(keepPropCheckBox, 6, 2);
     //tabLayout->setSizeConstraint(QLayout::SetFixedSize);
     setLayout(tabLayout);
-
+    entitiesList.clear();
+    entitiesList.append( dataProxy->getEntitiesNames());
     if (entitiesList.size()>1)
     {
         entitiesList.prepend("00-" + tr("Not Identified") + " (000)");
         entityNameComboBox->addItems(entitiesList);
     }
+   //qDebug() << Q_FUNC_INFO << ": Trying to add PropModes";
     propModeList = dataProxy->getPropModeList();
     if (propModeList.size()>1)
     {
+       //qDebug() << Q_FUNC_INFO << ": Adding PropModes";
         propModeList.prepend("00 - " + tr("Not - Not Identified"));
         propModeComboBox->addItems(propModeList);
     }
 
+
     iotaContinentComboBox->addItems(dataProxy->getContinentShortNames());
     iotaNumberLineEdit->setInputMask("000");
     iotaNumberLineEdit->setText("000");
+    readDarkMode();
     logEvent (Q_FUNC_INFO, "END", Debug);
 
     //qDebug() << Q_FUNC_INFO << ": (" << QString::number(this->size ().width ()) << "/" << QString::number(this->size ().height ()) << ")" ;
@@ -168,13 +231,25 @@ void MainWindowInputOthers::clear(bool _full)
     logEvent (Q_FUNC_INFO, "Start", Debug);
     entityNameComboBox->setCurrentIndex(0);
     userDefinedADIFComboBox->setCurrentIndex (0);
-    userDefinedADIFValueLineEdit->clear ();
-    sota_ref = QString();
-    distance = 0.0;
-    age = 0;
+    entityPrimDivComboBox->clear();
+    entityPrimDivComboBox->addItem("00-" + tr("None Identified") + " (000)");
 
-    iotaContinentComboBox->setCurrentIndex(0);
-    iotaNumberLineEdit->setText("000");
+    userDefinedADIFValueLineEdit->clear ();
+
+    sota_ref    = QString();
+    currentPref = QString();
+    currentInt  = 0;
+    distance    = 0.0;
+    age         = 0;
+    vucc_grids  = QString();
+    pota_ref    = QString();
+    sig         = QString();
+    sig_info    = QString();
+    wwff_ref    = QString();
+
+    clearIOTA();
+    //iotaContinentComboBox->setCurrentIndex(0);
+    //iotaNumberLineEdit->setText("000");
     if ((!keepPropCheckBox->isChecked()) || _full)
     {
       //qDebug() << Q_FUNC_INFO << ": Clear the proModeComboBox";
@@ -203,30 +278,7 @@ void MainWindowInputOthers::setEntitiesList(const QStringList _qs)
     logEvent (Q_FUNC_INFO, "END", Debug);
 }
 
-void MainWindowInputOthers::setEntity(const int _ent)
-{// Select the appropriate entity in the ComboBox
-       //qDebug() << Q_FUNC_INFO << ": " << QString::number(_ent);
-    logEvent (Q_FUNC_INFO, "Start", Debug);
-    if (_ent<=0)
-    {
-        entityNameComboBox->setCurrentIndex(0);
-        logEvent (Q_FUNC_INFO, "END-1", Debug);
-        return;
-    }
-    QString aux = QString();
-    aux = QString::number(_ent);
-    if (_ent > 1000)
-    {
-        aux = (QString::number(_ent)).right(3);
-    }
 
-    int indexC = entityNameComboBox->findText("(" + aux + ")", Qt::MatchEndsWith);
-
-    //qDebug() << "MainWindow::selectCorrectEntity: " << pref << "/" << QString::number(indexC);
-    entityNameComboBox->setCurrentIndex(indexC);
-    setIOTAContinentFromEntity(_ent);
-    logEvent (Q_FUNC_INFO, "END", Debug);
-}
 
 int MainWindowInputOthers::getEntity()
 {
@@ -256,18 +308,18 @@ QString MainWindowInputOthers::getEntityPrefix()
 
 void MainWindowInputOthers::setPropMode(const QString &_qs, bool _keep)
 {
-    //qDebug() << Q_FUNC_INFO << ": " << _qs << "/ Keep: " << util->boolToQString(_keep);
+   //qDebug() << Q_FUNC_INFO << ": " << _qs << "/ Keep: " << util->boolToQString(_keep);
     logEvent (Q_FUNC_INFO, "Start", Debug);
     autoUpdating = true;
     if(( propModeComboBox->findText(_qs+" -", Qt::MatchContains))>0)
     {
-        //qDebug() << Q_FUNC_INFO << " PropMode found" ;
+       //qDebug() << Q_FUNC_INFO << " PropMode found" ;
         propModeComboBox->setCurrentIndex( propModeComboBox->findText(_qs+" -", Qt::MatchContains));
         keepPropCheckBox->setChecked(_keep);
     }
     else
     {
-        //qDebug() << Q_FUNC_INFO << " PropMode NOT found" ;
+       //qDebug() << Q_FUNC_INFO << " PropMode NOT found" ;
         propModeComboBox->setCurrentIndex(0);
         keepPropCheckBox->setChecked(false);
     }
@@ -279,22 +331,21 @@ QString MainWindowInputOthers::getPropModeFromComboBox()
 {
     //logEvent (Q_FUNC_INFO, "Start", Debug);
 
-    //qDebug() << Q_FUNC_INFO << ": " << propModeComboBox->currentText();
+   //qDebug() << Q_FUNC_INFO << ": " << propModeComboBox->currentText();
     QString _pm = (((propModeComboBox->currentText()).split('-')).at(1)).simplified();
-    //qDebug() << Q_FUNC_INFO << ": - 10" ;
+   //qDebug() << Q_FUNC_INFO << ": - 10" ;
     QString _n = (((propModeComboBox->currentText()).split('-')).at(0)).simplified();
-    //qDebug() << Q_FUNC_INFO << ": - 11: " << _n ;
+   //qDebug() << Q_FUNC_INFO << ": - 11: " << _n ;
 
     if (_n == "00")
     {
-        //qDebug() << Q_FUNC_INFO << ": - 12" ;
+       //qDebug() << Q_FUNC_INFO << ": - 12" ;
         logEvent (Q_FUNC_INFO, "END-1", Debug);
-        //qDebug() << Q_FUNC_INFO << ": - 13" ;
         return QString();
     }
-    //qDebug() << Q_FUNC_INFO << ": - 14" ;
+   //qDebug() << Q_FUNC_INFO << ": - 14" ;
     logEvent (Q_FUNC_INFO, "END", Debug);
-    //qDebug() << Q_FUNC_INFO << ": " << _pm ;
+   //qDebug() << Q_FUNC_INFO << ": " << _pm ;
     return _pm;
 }
 
@@ -313,6 +364,26 @@ bool MainWindowInputOthers::isSATPropagation()
     }
 }
 
+void MainWindowInputOthers::setPaletteIOTA(const bool _ok)
+{
+    //qDebug() << Q_FUNC_INFO << " - Start";
+    if (_ok)
+    {
+        if (darkMode)
+        {
+            iotaNumberLineEdit->setPalette (palWhite);
+        }
+        else
+        {
+            iotaNumberLineEdit->setPalette (palBlack);
+        }
+    }
+    else
+    {
+        iotaNumberLineEdit->setPalette (palRed);
+    }
+}
+
 
 void MainWindowInputOthers::clearIOTA()
 {
@@ -320,33 +391,44 @@ void MainWindowInputOthers::clearIOTA()
     iotaContinentComboBox->setCurrentIndex(0);
     iotaNumberLineEdit->setText("000");
     logEvent (Q_FUNC_INFO, "END", Debug);
-    //iotaNumberLineEdit->setPalette(palBlack);
+    setPaletteIOTA(true);    //To avoid that 000 is considered wrong
+}
+
+void MainWindowInputOthers::setDarkMode (const bool _dm)
+{
+    darkMode = _dm;
+
+    if (darkMode)
+    {
+       //qDebug() << Q_FUNC_INFO << " - True";
+        iotaNumberLineEdit->setPalette(palWhite);
+        userDefinedADIFValueLineEdit->setPalette(palWhite);
+        iotaNumberLineEdit->setPalette(palWhite);
+    }
+    else
+    {
+       //qDebug() << Q_FUNC_INFO << " - False";
+        iotaNumberLineEdit->setPalette(palBlack);
+        userDefinedADIFValueLineEdit->setPalette(palBlack);
+        iotaNumberLineEdit->setPalette(palBlack);
+    }
 }
 
 bool MainWindowInputOthers::isIOTAModified()
 {
     logEvent (Q_FUNC_INFO, "Start", Debug);
-    if ((iotaContinentComboBox->currentIndex()>0) || (iotaNumberLineEdit->text()).toInt()>0)
-    {
-        logEvent (Q_FUNC_INFO, "END-True", Debug);
-        return true;
-    }
-    else
-    {
-        logEvent (Q_FUNC_INFO, "END-False", Debug);
-        return false;
-    }
+    return ((iotaContinentComboBox->currentIndex()>0) || (iotaNumberLineEdit->text()).toInt()>0);
 }
 
 void MainWindowInputOthers::setIOTA(const QString &_qs)
 {//TODO: Seems to be better to send the color info like in: (it is much more flexible as I can send any color!)
-
     //void MainWindowInputQSL::setQSLVia(const QString &_qs, QColor qColor)
       //qDebug() << "MainWindow::setIOTA: " << _qs;
     logEvent (Q_FUNC_INFO, "Start", Debug);
     if ( (checkIfValidIOTA(_qs)).length() !=6 )
     {
-        iotaNumberLineEdit->setPalette(palRed);
+        if (iotaNumberLineEdit->text() !=  "000")
+            iotaNumberLineEdit->setPalette(palRed);
         logEvent (Q_FUNC_INFO, "END-1", Debug);
         return;
     }
@@ -356,7 +438,7 @@ void MainWindowInputOthers::setIOTA(const QString &_qs)
           //qDebug() << Q_FUNC_INFO << ": IOTA " << _qs;
         iotaContinentComboBox->setCurrentIndex( iotaContinentComboBox->findText(values.at(0) ) );
         iotaNumberLineEdit->setText(values.at(1));
-        if (getDarkMode())
+        if (darkMode)
         {
             iotaNumberLineEdit->setPalette(palWhite);
         }
@@ -374,14 +456,6 @@ QString MainWindowInputOthers::getIOTA()
     return (checkIfValidIOTA(iotaContinentComboBox->currentText() + "-" + iotaNumberLineEdit->text()));
 }
 
-
-void MainWindowInputOthers::setIOTAContinentFromEntity(const int _n)
-{
-      //qDebug() << "MainWindow::setIOTAContinentFromEntity:" << QString::number(_n);
-    logEvent (Q_FUNC_INFO, "Start-END", Debug);
-    setIOTAContinent(dataProxy->getContinentShortNameFromEntity(_n)) ;
-}
-
 void MainWindowInputOthers::setIOTAContinent(const QString &_qs)
 {
     logEvent (Q_FUNC_INFO, "Start", Debug);
@@ -415,61 +489,30 @@ Returns a valid format IOTA if possible and "" in other cases.
 ************************************/
       //qDebug() << Q_FUNC_INFO << ": " << _tiota;
     logEvent (Q_FUNC_INFO, "Start-END", Debug);
-    QString _continent;
-    QString _number;
-
-    if (_tiota.count("-") == 1)
+    if (_tiota.count("-") != 1)
     {
-        QStringList _values = _tiota.split("-", QT_SKIP);
-        _continent = _values.at(0);
-        _number = _values.at(1);
-    }
-    else
-    {
-        logEvent (Q_FUNC_INFO, "END-1", Debug);
+        logEvent (Q_FUNC_INFO, "END - Wrong format", Debug);
         return "";
     }
-      //qDebug() << Q_FUNC_INFO << ": (cont) " << _continent;
-      //qDebug() << Q_FUNC_INFO << ": (numb): " << _number;
 
-    // Check if continent is valid
+    QStringList values = _tiota.split("-", QT_SKIP);
+    QString continent = values.at(0);
+    QString number = values.at(1);
 
-    if (dataProxy->isValidContinentShortName(_continent))
-    {
-        if ( (_number.toInt() >0 ) && ((_number.toInt()) < 1000 ))
-        {
-            if ((_number.length()) == 3)
-            {
-                logEvent (Q_FUNC_INFO, "END-1", Debug);
-                return _continent + "-" + _number ;
-            }
-            else if ((_number.length()) == 2)
-            {
-                logEvent (Q_FUNC_INFO, "END-2", Debug);
-                return _continent + "-0" + QString::number((_number).toInt());
-            }
-            else if ((_number.length()) == 1)
-            {
-                logEvent (Q_FUNC_INFO, "END-3", Debug);
-                return _continent + "-00" + QString::number((_number).toInt());
-            }
-            else
-            {
-                logEvent (Q_FUNC_INFO, "END-4", Debug);
-                return "";
-            }
-        }
-        else
-        {
-            logEvent (Q_FUNC_INFO, "END-5", Debug);
-            return "";
-        }
+    if (!dataProxy->isValidContinentShortName(continent)) {
+        logEvent (Q_FUNC_INFO, "END - Wrong continent", Debug);
+        return "";
     }
-    else
-    {
-        logEvent (Q_FUNC_INFO, "END", Debug);
-        return QString();
+
+    bool isNumberValid;
+    int numberInt = number.toInt(&isNumberValid);
+
+    if (!isNumberValid || numberInt <= 0 || numberInt >= 1000) {
+        logEvent (Q_FUNC_INFO, "END - Wrong number", Debug);
+        return "";
     }
+    logEvent (Q_FUNC_INFO, "END", Debug);
+    return QString("%1-%2").arg(continent).arg(numberInt, 3, 10, QChar('0'));
 }
 
 void MainWindowInputOthers::slotPropModeComboBoxChanged()
@@ -500,6 +543,87 @@ bool MainWindowInputOthers::getKeep()
     return keepPropCheckBox->isChecked ();
 }
 
+bool MainWindowInputOthers::setPOTA_REF(const QString &_op)
+{
+    //qDebug() << Q_FUNC_INFO << ": " << _op;
+    logEvent (Q_FUNC_INFO, "Start", Debug);
+    Adif adif(Q_FUNC_INFO);
+    if (!adif.isValidPOTA(_op))
+        return false;
+    pota_ref = _op;
+    slotUSerDefinedADIFComboBoxChanged();
+    logEvent (Q_FUNC_INFO, "END", Debug);
+    return true;
+}
+
+QString MainWindowInputOthers::getPOTA_REF()
+{
+    //qDebug() << Q_FUNC_INFO;
+    logEvent (Q_FUNC_INFO, "Start-END", Debug);
+    return pota_ref;
+}
+
+bool MainWindowInputOthers::setSIG(const QString &_op)
+{
+    //qDebug() << Q_FUNC_INFO << ": " << _op;
+    logEvent (Q_FUNC_INFO, "Start", Debug);
+    Adif adif(Q_FUNC_INFO);
+    if (_op.length()<=0)
+        return false;
+    sig = _op;
+    slotUSerDefinedADIFComboBoxChanged();
+    logEvent (Q_FUNC_INFO, "END", Debug);
+    return true;
+}
+
+QString MainWindowInputOthers::getSIG()
+{
+    //qDebug() << Q_FUNC_INFO;
+    logEvent (Q_FUNC_INFO, "Start-END", Debug);
+    return sig;
+}
+
+bool MainWindowInputOthers::setSIG_INFO(const QString &_op)
+{
+    //qDebug() << Q_FUNC_INFO << ": " << _op;
+    logEvent (Q_FUNC_INFO, "Start", Debug);
+    Adif adif(Q_FUNC_INFO);
+    if (_op.length()<=0)
+        return false;
+    sig_info = _op;
+    slotUSerDefinedADIFComboBoxChanged();
+    logEvent (Q_FUNC_INFO, "END", Debug);
+    return true;
+}
+
+QString MainWindowInputOthers::getSIG_INFO()
+{
+    //qDebug() << Q_FUNC_INFO;
+    logEvent (Q_FUNC_INFO, "Start-END", Debug);
+    return sig_info;
+}
+
+
+bool MainWindowInputOthers::setWWFF_Ref(const QString &_op)
+{
+    //qDebug() << Q_FUNC_INFO << ": " << _op;
+    logEvent (Q_FUNC_INFO, "Start", Debug);
+    Adif adif(Q_FUNC_INFO);
+    if (!adif.isValidWWFF_Ref(_op))
+        return false;
+    wwff_ref = _op;
+    slotUSerDefinedADIFComboBoxChanged();
+    logEvent (Q_FUNC_INFO, "END", Debug);
+    return true;
+}
+
+QString MainWindowInputOthers::getWWFF_Ref()
+{
+    //qDebug() << Q_FUNC_INFO;
+    logEvent (Q_FUNC_INFO, "Start-END", Debug);
+    return wwff_ref;
+}
+
 bool MainWindowInputOthers::setUserADIFTypeComboBox(const QString &_value)
 {
     logEvent (Q_FUNC_INFO, "Start", Debug);
@@ -511,6 +635,30 @@ bool MainWindowInputOthers::setUserADIFTypeComboBox(const QString &_value)
     {
         userDefinedADIFComboBox->setCurrentIndex (1);
     }
+    else if (_value == "DISTANCE")
+    {
+        userDefinedADIFComboBox->setCurrentIndex (2);
+    }
+    else if (_value == "POTA_REF")
+    {
+        userDefinedADIFComboBox->setCurrentIndex (3);
+    }
+    else if (_value == "SIG")
+    {
+        userDefinedADIFComboBox->setCurrentIndex (4);
+    }
+    else if (_value == "SIG_INFO")
+    {
+        userDefinedADIFComboBox->setCurrentIndex (5);
+    }
+    else if (_value == "VUCC_GRIDS")
+    {
+        userDefinedADIFComboBox->setCurrentIndex (6);
+    }
+    else if (_value == "WWFF_REF")
+    {
+        userDefinedADIFComboBox->setCurrentIndex (7);
+    }
     else
     {
         logEvent (Q_FUNC_INFO, "END-1", Debug);
@@ -536,10 +684,22 @@ QString MainWindowInputOthers::getUserADIFTypeComboBox()
         return "AGE";
     case 3:
         logEvent (Q_FUNC_INFO, "END-3", Debug);
-        return "VUCC_GRIDS";
+        return "DISTANCE";
     case 4:
         logEvent (Q_FUNC_INFO, "END-4", Debug);
-        return "DISTANCE";
+        return "POTA_REF";
+    case 5:
+        logEvent (Q_FUNC_INFO, "END-5", Debug);
+        return "SIG";
+    case 6:
+        logEvent (Q_FUNC_INFO, "END-6", Debug);
+        return "SIG_INFO";
+    case 7:
+        logEvent (Q_FUNC_INFO, "END-7", Debug);
+        return "VUCC_GRIDS";
+    case 8:
+        logEvent (Q_FUNC_INFO, "END-8", Debug);
+        return "WWFF_REF";
     default:
         logEvent (Q_FUNC_INFO, "END", Debug);
         return QString();
@@ -562,14 +722,201 @@ QString MainWindowInputOthers::getUserADIFValue()
 bool MainWindowInputOthers::setInitialADIFValues()
 {
     logEvent (Q_FUNC_INFO, "END-", Debug);
-    adifValidTypes << "01-" + tr("SOTA Ref") << "02-" + tr ("Age") << "03-" + tr ("VUCC grids")
-                   << "04-" + tr("Distance");
+    adifValidTypes  << "01-"    + tr("SOTA Ref")    << "02-" + tr ("Age")
+                   << "03-"     + tr("Distance")    << "04-" + tr("POTA Ref")
+                   << "05-"     + tr("SIG")         << "06-" + tr("SIG Info")
+                   << "07-"     + tr ("VUCC grids") << "08-" + tr("WWFF Ref");
+
     userDefinedADIFComboBox->clear ();
     userDefinedADIFComboBox->addItems (adifValidTypes);
     logEvent (Q_FUNC_INFO, "END", Debug);
     return true;
 }
 
+bool MainWindowInputOthers::setState(const QString &_op)
+{ // Sets a subdivision/State
+   //qDebug() << Q_FUNC_INFO << ": " << _op;
+    if (_op.length()<1)
+        return false;
+
+    int indexC = entityPrimDivComboBox->findText(QString("%1-").arg(_op), Qt::MatchStartsWith);
+
+   //qDebug() << Q_FUNC_INFO << _op << "/" << QString::number(indexC) << " / (6): "  << entityPrimDivComboBox->itemText(6);
+    if (indexC<0)
+        return false;
+
+    entityPrimDivComboBox->setCurrentIndex(indexC);
+    return true;
+}
+
+QString MainWindowInputOthers::getState()
+{// Reads the subdivision. It return just the shortname/code for the subdivision/State
+   //qDebug() << Q_FUNC_INFO << ": " << ((entityPrimDivComboBox->currentText()).split("-")).at(0);
+
+    QString aux = entityPrimDivComboBox->currentText();
+    if ((aux.startsWith("00-")) && (aux.endsWith("(000)")) )
+        return QString();
+
+    return ((entityPrimDivComboBox->currentText()).split("-")).at(0);
+}
+
+void MainWindowInputOthers::updatePrimarySubdivisionsComboBox(QList<PrimarySubdivision> _subdivisions)
+{
+    //qDebug() << Q_FUNC_INFO << " - count: " << QString::number(_subdivisions.count());
+    entityPrimDivComboBox->clear();
+    if (_subdivisions.isEmpty())
+        return;
+
+    QStringList listOfSubdivisions;
+    listOfSubdivisions.clear();
+    QStringList names;
+    names.clear();
+
+
+    foreach (PrimarySubdivision ps, _subdivisions)
+    {
+
+        QString subdivision = ps.shortName + "-" + ps.name;
+        if (!listOfSubdivisions.contains(subdivision))
+            listOfSubdivisions.append(subdivision);
+        //qDebug() << Q_FUNC_INFO << ": Subdivision added: " << subdivision;
+    }
+    if (listOfSubdivisions.isEmpty())
+        return;
+
+    listOfSubdivisions.sort();
+    listOfSubdivisions.removeDuplicates();
+    listOfSubdivisions.prepend("00-" + tr("Not selected") + " (000)");
+
+    entityPrimDivComboBox->addItems(listOfSubdivisions);
+    if (listOfSubdivisions.length() == 2)
+        entityPrimDivComboBox->setCurrentIndex(1);
+    //qDebug() << Q_FUNC_INFO << " - END";
+}
+
+void MainWindowInputOthers::setEntity(const int _entity)
+{// Select the appropriate entity in the ComboBox
+  //qDebug() << Q_FUNC_INFO << ": " << QString::number(_entity);
+    logEvent (Q_FUNC_INFO, "Start", Debug);
+  //qDebug() << Q_FUNC_INFO << " - 10" ;
+
+    if (_entity<=0)
+    {
+      //qDebug() << Q_FUNC_INFO << " - 11" ;
+        entityNameComboBox->setCurrentIndex(0);
+        logEvent (Q_FUNC_INFO, "END-1", Debug);
+        return;
+    }
+  //qDebug() << Q_FUNC_INFO << " - 20" ;
+    currentInt = _entity;
+    QString aux = QString::number(_entity);
+    if (_entity > 1000)
+    {
+      //qDebug() << Q_FUNC_INFO << " - 30" ;
+        aux = (QString::number(_entity)).right(3);
+    }
+  //qDebug() << Q_FUNC_INFO << " - 40" ;
+
+    int indexC = entityNameComboBox->findText("(" + aux + ")", Qt::MatchEndsWith);
+    if (indexC != -1)
+    {
+        entityNameComboBox->setCurrentIndex(indexC);
+    }
+    else
+    {
+      //qDebug() << Q_FUNC_INFO << " - Unable to find entity in the ComboBox";
+    }
+
+
+    setIOTAContinent(dataProxy->getContinentShortNameFromEntity(_entity)) ;
+    //qDebug() << Q_FUNC_INFO << " - 100" ;
+    logEvent (Q_FUNC_INFO, "END", Debug);
+}
+
+void MainWindowInputOthers::setEntityAndPrefix(const int _entity, const QString &_qrz)
+{
+    //qDebug() << Q_FUNC_INFO << " - Start: " << QString::number(_entity) << "/" << _qrz;
+    if (_entity<=0)
+    {
+      //qDebug() << Q_FUNC_INFO << " -  10";
+        entityNameComboBox->setCurrentIndex(0);
+        logEvent (Q_FUNC_INFO, "END-1", Debug);
+        return;
+    }
+
+  //qDebug() << Q_FUNC_INFO << " - 15";
+    setEntity(_entity);
+
+    Callsign callsign(_qrz);
+    if (callsign.isValid() || callsign.isValidPrefix())
+        currentPref = callsign.getHostFullPrefix();
+
+    QString prefixFromEntityNumber  = world->getEntityMainPrefix(_entity);        // The main prefix of the entity.
+    QString hostFullPrefix          = callsign.getHostFullPrefix();               // The default is that showAll is not checked. Main prefix+ the area
+    QString hostPrefix              = callsign.getHostPrefix();                   // The default is that showAll is not checked
+
+
+    Callsign entityCall(prefixFromEntityNumber);    // To check if the prefixFromEntity is the main or not (EA->main, AM-> nor main, it should be EA)
+    QString prefixForSubdivision = prefixFromEntityNumber;    
+
+     // Construct hostFullPrefix if hostPrefix is not the main prefix.
+    if (hostPrefix != prefixFromEntityNumber)
+    {
+        hostFullPrefix = prefixFromEntityNumber + QString::number(callsign.getHostAreaNumber());
+    }
+
+  //qDebug() << Q_FUNC_INFO << " -  20";
+  //qDebug() << Q_FUNC_INFO << "hostFullPrefix:             " << hostFullPrefix;
+  //qDebug() << Q_FUNC_INFO << "hostPrefix:                 " << hostPrefix;
+  //qDebug() << Q_FUNC_INFO << "prefixFromEntityNumber:     " << prefixFromEntityNumber;
+
+
+    if ((hostFullPrefix.isEmpty()) && (hostPrefix.isEmpty()))
+        return;
+
+    //qDebug() << Q_FUNC_INFO << " -  40";
+    QList<PrimarySubdivision> primarySubdivisions;
+    primarySubdivisions.clear();
+
+    if (showAllCheckBox->isChecked())
+    {
+        primarySubdivisions.append(dataProxy->getPrimarySubDivisions(currentInt, QString()));
+    }
+    else
+    {
+        primarySubdivisions.append(dataProxy->getPrimarySubDivisions(currentInt, hostFullPrefix));
+        currentPref = hostFullPrefix;
+        if (primarySubdivisions.isEmpty())
+        {
+            //qDebug() << Q_FUNC_INFO << " -  50";
+            //qDebug() << Q_FUNC_INFO << " - primarySubdivisions is empty with hostPrefix, running for the main prefix";
+            primarySubdivisions.append(dataProxy->getPrimarySubDivisions(currentInt, hostPrefix));
+            currentPref = hostPrefix;
+            if (primarySubdivisions.isEmpty())
+            {
+                //qDebug() << Q_FUNC_INFO << " -  55";
+                //qDebug() << Q_FUNC_INFO << " - primarySubdivisions is empty with mainprefix, running just with the entity";
+                primarySubdivisions.append(dataProxy->getPrimarySubDivisions(currentInt, QString()));
+                currentPref = QString();
+            }
+            //qDebug() << Q_FUNC_INFO << " -  59";
+        }
+    }
+
+
+    //qDebug() << Q_FUNC_INFO << " - 60";
+    //qDebug() << Q_FUNC_INFO << " - count: " << QString::number(primarySubdivisions.count());
+    if (primarySubdivisions.isEmpty())
+    {
+        entityPrimDivComboBox->clear();
+        return;
+    }
+
+    //qDebug() << Q_FUNC_INFO << " - 70 ";
+    updatePrimarySubdivisionsComboBox(primarySubdivisions);
+    //qDebug() << Q_FUNC_INFO << " - END";
+}
+
 void MainWindowInputOthers::slotUSerDefinedADIFComboBoxChanged()
 {
     //qDebug() << Q_FUNC_INFO << ": " << getUserADIFTypeComboBox ();
@@ -594,6 +941,22 @@ void MainWindowInputOthers::slotUSerDefinedADIFComboBoxChanged()
     {
         userDefinedADIFValueLineEdit->setText (QString::number(distance));
     }
+    else if (currentTag == "POTA_REF")
+    {
+        userDefinedADIFValueLineEdit->setText (pota_ref);
+    }
+    else if (currentTag == "SIG")
+    {
+        userDefinedADIFValueLineEdit->setText (sig);
+    }
+    else if (currentTag == "SIG_INFO")
+    {
+        userDefinedADIFValueLineEdit->setText (sig_info);
+    }
+    else if (currentTag == "WWFF_REF")
+    {
+        userDefinedADIFValueLineEdit->setText (wwff_ref);
+    }
 }
 
 bool MainWindowInputOthers::setVUCCGrids(const QString &_op)
@@ -647,7 +1010,7 @@ QString MainWindowInputOthers::getVUCCGrids()
 void MainWindowInputOthers::setColorsForUserDefinedADIFValueLineEdit()
 {
     logEvent (Q_FUNC_INFO, "Start", Debug);
-    if (getDarkMode())
+    if (darkMode)
     {
         userDefinedADIFValueLineEdit->setPalette(palWhite);
     }
@@ -658,7 +1021,6 @@ void MainWindowInputOthers::setColorsForUserDefinedADIFValueLineEdit()
     logEvent (Q_FUNC_INFO, "END", Debug);
 }
 
-
 bool MainWindowInputOthers::setSOTA(const QString &_op)
 {
     //qDebug() << Q_FUNC_INFO << ": " << _op;
@@ -708,7 +1070,7 @@ double MainWindowInputOthers::getDistance()
     return distance;
 }
 
-void MainWindowInputOthers::slotSetCurrentUSerData()
+void MainWindowInputOthers::slotSetCurrentUserData()
 {
     logEvent (Q_FUNC_INFO, "Start", Debug);
     QString currentTag = getUserADIFTypeComboBox ();
@@ -729,15 +1091,61 @@ void MainWindowInputOthers::slotSetCurrentUSerData()
     else if (currentTag == "DISTANCE")
     {
         distance = userDefinedADIFValueLineEdit->text().toDouble();
-        //userDefinedADIFValueLineEdit->setText (QString::number(distance));
+    }
+    if (currentTag == "POTA_REF")
+    {    
+        pota_ref = userDefinedADIFValueLineEdit->text();
+    }
+    if (currentTag == "SIG")
+    {
+        sig = userDefinedADIFValueLineEdit->text();
+        //setSIG(userDefinedADIFValueLineEdit->text());
+        //sig = userDefinedADIFValueLineEdit->text();
+    }
+    if (currentTag == "SIG_INFO")
+    {
+        sig_info = userDefinedADIFValueLineEdit->text();
+    }
+    if (currentTag == "WWFF_REF")
+    {
+        //wwff_ref = userDefinedADIFValueLineEdit->text();
+        wwff_ref = userDefinedADIFValueLineEdit->text();
+        //setWWFF_Ref(userDefinedADIFValueLineEdit->text());
     }
     logEvent (Q_FUNC_INFO, "END", Debug);
 }
 
-bool MainWindowInputOthers::getDarkMode()
+
+void MainWindowInputOthers::slotPrimarySubdivisionsComboBoxChanged()
 {
-    logEvent (Q_FUNC_INFO, "Start-END", Debug);
-    return ( iotaNumberLineEdit->palette().color (QPalette::Base) == "#646464");
+    logEvent (Q_FUNC_INFO, "Start", Debug);
+   //qDebug() << Q_FUNC_INFO << entityPrimDivComboBox->currentText();
+
+    logEvent (Q_FUNC_INFO, "END", Debug);
+}
+
+void MainWindowInputOthers::slotShowAllCheckBoxChanged()
+{
+    setEntityAndPrefix(currentInt, currentPref);
+}
+
+void MainWindowInputOthers::slotEntityNameComboBoxChanged()
+{
+    //qDebug() << Q_FUNC_INFO << entityNameComboBox->currentText();
+    QString prefix = ((entityNameComboBox->currentText()).split("-")).at(0);
+    //qDebug() << Q_FUNC_INFO << " - " << prefix;
+    int entity = world->getQRZARRLId(prefix);
+    setEntityAndPrefix(entity, prefix);
+    //entityPrimDivComboBox->clear();
+    entityPrimDivComboBox->addItem("00-" + tr("None Identified") + " (000)");
+}
+
+void MainWindowInputOthers::readDarkMode()
+{
+    QSettings settings(util->getCfgFile (), QSettings::IniFormat);
+    settings.beginGroup ("Colors");
+    setDarkMode(settings.value("DarkMode", false).toBool ());
+    settings.endGroup ();
 }
 
 
