@@ -33,6 +33,8 @@
 #include "../dataproxy_sqlite.h"
 #include "../utilities.h"
 #include "../klogdefinitions.h"
+#include "../world.h"
+#include "../qso.h"
 
 class MainWindowInputOthers : public QWidget
 {
@@ -42,11 +44,16 @@ class MainWindowInputOthers : public QWidget
 public:
     MainWindowInputOthers(DataProxy_SQLite *dp, QWidget *parent = nullptr);
     ~MainWindowInputOthers();
-
+    void setDarkMode (const bool _dm);
+    QSO getQSOData(QSO _qso);
+    void setQSOData(const QSO &_qso);
     void setEntitiesList(const QStringList _qs);
-    void setEntity(const int _n);
+    void setEntity(const int _entity);               // Move the external call to setEntityAndPrefix
     int getEntity();
     QString getEntityPrefix();
+    void setEntityAndPrefix(const int _entity, const QString &_qrz); // Receives the entity & prefix of the call to check if
+                                                                // It is possible to focus the primary
+                                                                // subdivision. Updates also the IOTA continent
 
     void setPropMode(const QString &_qs, bool _keep);
     QString getPropModeFromComboBox();
@@ -65,16 +72,27 @@ public:
     double getDistance();
     bool setVUCCGrids(const QString &_op);
     QString getVUCCGrids();
+    bool setPOTA_REF(const QString &_op);
+    QString getPOTA_REF();
+    bool setSIG(const QString &_op);
+    QString getSIG();
+    bool setSIG_INFO(const QString &_op);
+    QString getSIG_INFO();
+    bool setWWFF_Ref(const QString &_op);
+    QString getWWFF_Ref();
 
     void setIOTA(const QString &_qs);
     QString getIOTA();
-    void setIOTAContinentFromEntity(const int _n);
+
     void setIOTAContinent(const QString &_qs);
     bool isIOTAModified();
     void clearIOTA();
     void setKeep(const bool _b);
     bool getKeep();
 
+    bool setState(const QString &_op);      // Sets a subdivision / State
+    QString getState();                     // Reads the subdivision / State
+
     void createUI();
     void clear(bool _full = false); //full= false leaves the "keep this data"; full = true clears everything
     void setLogLevel (const DebugLogLevel _l);
@@ -82,29 +100,42 @@ public:
 signals:
     void setPropMode(const QString _p);
     void debugLog (QString _func, QString _msg, DebugLogLevel _level);
+    //void showAll(bool _showAll);
 
 private slots:
     //void slotSetPropMode(const QString &_p); // To receive the signal from the SAT widget and set "SAT" propagation mode, of needed.
     void slotPropModeComboBoxChanged();
     void slotUSerDefinedADIFComboBoxChanged();
-    void slotSetCurrentUSerData();
+    void slotSetCurrentUserData();
+    void slotPrimarySubdivisionsComboBoxChanged();
+    void slotShowAllCheckBoxChanged();
+    void slotEntityNameComboBoxChanged();
+
 
 private:
     QString checkIfValidIOTA(const QString &_tiota); //TODO: There is an equivalent function in the Awards class. I should use only one!
     void setColorsForUserDefinedADIFValueLineEdit();
     bool checkVUCC_GRIDS(const QString &_string);
     bool setInitialADIFValues();
-    bool getDarkMode();
+    void updateShowAll();
+    void setPaletteIOTA(const bool _ok);
+
+    void updatePrimarySubdivisionsComboBox(QList<PrimarySubdivision> _subdivisions);
+    //bool getDarkMode();
+    void readDarkMode();
     void logEvent(const QString &_func, const QString &_msg, DebugLogLevel _level);
 
+
     Utilities *util;
     DataProxy_SQLite *dataProxy;
+    World *world;
+    bool darkMode;
 
     QStringList entitiesList, propModeList;
     //QLabel *entityPrimLabel, *entitySecLabel, *iotaAwardLabel, *entityNameLabel, *propModeLabel;
     QComboBox *iotaContinentComboBox, *entityPrimDivComboBox, *entitySecDivComboBox, *entityNameComboBox, *propModeComboBox;
     QLineEdit *iotaNumberLineEdit;
-    QCheckBox *keepPropCheckBox;
+    QCheckBox *keepPropCheckBox, *showAllCheckBox;
 
     QPalette palRed, palBlack, palWhite;
     bool autoUpdating;
@@ -113,7 +144,10 @@ private:
     QLineEdit *userDefinedADIFValueLineEdit;
     QStringList adifValidTypes;
 
-    QString sota_ref, vucc_grids;
+    QString currentPref;
+    int currentInt;         // if the showAllCheckBox is toggled
+
+    QString sota_ref, vucc_grids, pota_ref, sig, sig_info, wwff_ref;
     double age, distance;
     DebugLogLevel logLevel;
 };
