@@ -32,7 +32,7 @@
 MainWindowInputQSO::MainWindowInputQSO(DataProxy_SQLite *dp, QWidget *parent) :
     QWidget(parent)
 {
-       //qDebug() << "MainWindowInputQSO::MainWindowInputQSO"  ;
+   //qDebug() << Q_FUNC_INFO << " - Start";
     dataProxy = dp;
     //locator = new Locator();
 
@@ -45,28 +45,29 @@ MainWindowInputQSO::MainWindowInputQSO(DataProxy_SQLite *dp, QWidget *parent) :
     rxFreqSpinBox = new QDoubleSpinBox;
     splitCheckBox = new QCheckBox;
     rxPowerSpinBox = new QDoubleSpinBox;
-
     dataProxy = dp;
 
     createUI();
     setDefaultData();
     //installEventFilter (this);
     clear();
-       //qDebug() << "MainWindowInputQSO::MainWindowInputQSO - END"  ;
+    //qDebug() << "MainWindowInputQSO::MainWindowInputQSO - END"  ;
 }
 
 MainWindowInputQSO::~MainWindowInputQSO()
 {
-    delete(dataProxy);
+   //delete(dataProxy);
 }
 
 void MainWindowInputQSO::setModifying(const bool _m)
 {
+   //qDebug() << Q_FUNC_INFO << " - Start";
     modify = _m;
 }
 
 void MainWindowInputQSO::createUI()
 {
+   //qDebug() << Q_FUNC_INFO << " - Start";
     rstTXLineEdit->setToolTip(tr("TX RST."));
     rstRXLineEdit->setToolTip(tr("RX RST."));
     txFreqSpinBox->setToolTip(tr("TX Frequency in MHz."));
@@ -228,6 +229,7 @@ void MainWindowInputQSO::createUI()
     connect(locatorLineEdit, SIGNAL(returnPressed()), this, SLOT(slotReturnPressed() ) );
     connect(qthLineEdit, SIGNAL(returnPressed()), this, SLOT(slotReturnPressed() ) );
     connect(nameLineEdit, SIGNAL(returnPressed()), this, SLOT(slotReturnPressed() ) );
+    //connect(nameLineEdit, SIGNAL(paletteChanged(QPalette)), this, SLOT(slotPaletteChanged(QPalette)) );
     connect(locatorLineEdit, SIGNAL(textChanged(QString)), this, SLOT(slotLocatorTextChanged() ) );
     connect(txFreqSpinBox, SIGNAL(valueChanged(double)), this, SLOT(slotFreqTXChanged(double)) ) ;
     connect(rxFreqSpinBox, SIGNAL(valueChanged(double)), this, SLOT(slotFreqRXChanged(double)) ) ;
@@ -240,13 +242,46 @@ void MainWindowInputQSO::createUI()
     QWidget::setTabOrder (locatorLineEdit, rxPowerSpinBox);
 }
 
+QSO MainWindowInputQSO::getQSOData(QSO _qso)
+{
+    QSO qso = _qso;
+    qso.setGridSquare(getDXLocator());
+    qso.setName(getName());
+    qso.setQTH(getQTH());
+    qso.setRSTRX(getRSTRX());
+    qso.setRSTTX(getRSTTX());
+    qso.setFreq(getTXFreq());
+    qso.setFreqRX(getRXFreq());
+    qso.setRXPwr(getRXPwr());
+    setRSTToMode(qso.getSubmode(), true);
+
+    qso.setBandRX (dataProxy->getBandNameFromFreq (getRXFreq()));
+    qso.setBand(dataProxy->getBandNameFromFreq (getTXFreq()));
+    return qso;
+}
+
+void MainWindowInputQSO::setQSOData(const QSO &_qso)
+{
+    QSO qso(_qso);
+    setDXLocator(qso.getGridSquare());
+    setName(qso.getName());
+    setQTH(qso.getQTH());
+    setRSTRX(qso.getRSTRX());
+    setRSTTX(qso.getRSTTX());
+    setTXFreq(qso.getFreqTX());
+    setRXFreq(qso.getFreqRX());
+    setRXPwr(qso.getRXPwr());
+}
 
 void MainWindowInputQSO::setDefaultData()
 {
+   //qDebug() << Q_FUNC_INFO << " - Start";
     palRed.setColor(QPalette::Text, Qt::red);
     palBlack.setColor(QPalette::Text, Qt::black);
     palWhite.setColor(QPalette::Text, Qt::white);
-
+    completedWithPreviousName = false;
+    completedWithPreviousQTH = false;
+    completedWithPreviousLocator = false;
     rxFreqBeingAutoChanged = false;
     txFreqBeingAutoChanged = false;
     isSATPropagation = false;
@@ -254,11 +289,20 @@ void MainWindowInputQSO::setDefaultData()
     freqTX = 0.0;
     freqRX = 0.0;
     modify = false;
+    readDarkMode();
+}
+
+void MainWindowInputQSO::readDarkMode()
+{
+    QSettings settings(util->getCfgFile (), QSettings::IniFormat);
+    settings.beginGroup ("Colors");
+    setDarkMode(settings.value("DarkMode", false).toBool ());
+    settings.endGroup ();
 }
 
 void MainWindowInputQSO::clear()
 {
-    //qDebug() << Q_FUNC_INFO ;
+   //qDebug() << Q_FUNC_INFO << " - Start";
     qthLineEdit->clear();
     nameLineEdit->clear();
     locatorLineEdit->clear();
@@ -268,7 +312,7 @@ void MainWindowInputQSO::clear()
 
 void MainWindowInputQSO::cleanQRZCOM(const bool _dataFromQRZCOM)
 {
-    //qDebug() << Q_FUNC_INFO ;
+   //qDebug() << Q_FUNC_INFO << " - Start";
     if (_dataFromQRZCOM)
     {
         qthLineEdit->clear();
@@ -279,28 +323,34 @@ void MainWindowInputQSO::cleanQRZCOM(const bool _dataFromQRZCOM)
 
 void MainWindowInputQSO::clearName()
 {
+   //qDebug() << Q_FUNC_INFO << " - Start";
     nameLineEdit->clear();
+    completedWithPreviousName = false;
 }
 
 void MainWindowInputQSO::clearQTH()
 {
+   //qDebug() << Q_FUNC_INFO << " - Start";
     qthLineEdit->clear();
+    completedWithPreviousQTH = false;
 }
 
 void MainWindowInputQSO::clearDXLocator()
 {
-    //qDebug() << Q_FUNC_INFO ;
+   //qDebug() << Q_FUNC_INFO << " - Start";
     locatorLineEdit->clear ();
+    completedWithPreviousLocator = false;
 }
 
 void MainWindowInputQSO::slotReturnPressed()
 {
+   //qDebug() << Q_FUNC_INFO << " - Start";
     emit returnPressed();
 }
 
 void MainWindowInputQSO::slotLocatorTextChanged()
 {//TO BE REMOVED ONCE InfoWidget is FINISHED - At least modified
-    //qDebug() << Q_FUNC_INFO << ": " << locatorLineEdit->text();
+   //qDebug() << Q_FUNC_INFO << " - Start";
     int cursorP = locatorLineEdit->cursorPosition();
 
     locatorLineEdit->setText((util->getClearSQLi(locatorLineEdit->text())).toUpper());
@@ -331,38 +381,73 @@ void MainWindowInputQSO::slotLocatorTextChanged()
 
 QString MainWindowInputQSO::getDXLocator()
 {
-    //qDebug() << Q_FUNC_INFO << " - returning: " << locatorLineEdit->text ();
+   //qDebug() << Q_FUNC_INFO << " - Start";
     return locatorLineEdit->text();
 }
 
-void MainWindowInputQSO::setDXLocator(const QString &_loc)
+void MainWindowInputQSO::setDXLocator(const QString &_loc, bool _completing)
 {
-   //qDebug() << Q_FUNC_INFO << ": " << _loc;
-    if (util->isValidGrid(_loc))
-    //if (util->isValidGrid (_loc))
+  //qDebug() << Q_FUNC_INFO << " - Start";
+    if (!util->isValidGrid(_loc))
+       return;
+    if (_completing)
     {
         locatorLineEdit->setText (_loc.toUpper ());
     }
+
+    if ((_loc.length()>=0) && ((getDXLocator()).length()<=0) )
+    {
+        setPaletteRightDXLocator (true);
+        locatorLineEdit->setText (_loc.toUpper ());
+        completedWithPreviousLocator=true;
+    }
+    else if (completedWithPreviousLocator && (_loc != getDXLocator()))
+    {
+        completedWithPreviousLocator = false;
+        setPaletteRightDXLocator(false);
+    }
 }
 
 QString MainWindowInputQSO::getName()
 {
+   //qDebug() << Q_FUNC_INFO << " - Start";
     return nameLineEdit->text ();
 }
 
-void MainWindowInputQSO::setName(const QString &_st)
+void MainWindowInputQSO::setName(const QString &_st, bool _completing)
 {
-    nameLineEdit->setText (_st);
+   //qDebug() << Q_FUNC_INFO << " - Start";
+    if (!_completing)
+    {
+        nameLineEdit->setText (_st);
+        completedWithPreviousName = false;
+        return;
+    }
+
+    if ((_st.length()>=0) && (getName().length()<=0) )
+    {
+        //qDebug() << Q_FUNC_INFO << ": name: 1" ;
+        nameLineEdit->setText (_st);
+        setPaletteRightName (true);
+        completedWithPreviousName = true;
+    }
+    else if (completedWithPreviousName && (_st != getName()))
+    {
+        //qDebug() << Q_FUNC_INFO << ": name: 2" ;
+        completedWithPreviousName = false;
+        setPaletteRightName (false);
+    }
 }
 
 double MainWindowInputQSO::getTXFreq()
 {
+   //qDebug() << Q_FUNC_INFO << " - Start";
     return txFreqSpinBox->value();
 }
 
 void MainWindowInputQSO::setTXFreq(const double _ft)
 {
-    //qDebug() << Q_FUNC_INFO << ": " << QString::number(_ft);
+   //qDebug() << Q_FUNC_INFO << " - Start";
 
     if ( (_ft >= double(0)) && (_ft <= txFreqSpinBox->maximum()))
     {
@@ -379,11 +464,13 @@ void MainWindowInputQSO::setTXFreq(const double _ft)
 
 double MainWindowInputQSO::getRXFreq()
 {
+   //qDebug() << Q_FUNC_INFO << " - Start";
     return rxFreqSpinBox->value();
 }
 
 void MainWindowInputQSO::setRXFreq(const double _ft)
 {
+   //qDebug() << Q_FUNC_INFO << " - Start";
     if ( (_ft >= double(0)) && (_ft <= rxFreqSpinBox->maximum()))
     {
         rxFreqSpinBox->setValue(_ft);
@@ -401,6 +488,7 @@ double MainWindowInputQSO::getRXPwr()
 
 void MainWindowInputQSO::setRXPwr(const double _pw)
 {
+   //qDebug() << Q_FUNC_INFO << " - Start: " << _pw;
     if (_pw>=0)
     {
         rxPowerSpinBox->setValue(_pw);
@@ -409,37 +497,60 @@ void MainWindowInputQSO::setRXPwr(const double _pw)
 
 QString MainWindowInputQSO::getQTH()
 {
+   //qDebug() << Q_FUNC_INFO << " - Start";
     return qthLineEdit->text();
 }
 
-void MainWindowInputQSO::setQTH(const QString &_st)
-{
-    qthLineEdit->setText(_st);
+void MainWindowInputQSO::setQTH(const QString &_st, bool _completing)
+{// if _completing, I a completing from a previous QSO
+   //qDebug() << Q_FUNC_INFO << " - Start";
+    if (!_completing)
+    {
+        qthLineEdit->setText(_st);
+        return;
+    }
+
+    if ((_st.length()>=0) && (getQTH().length()<=0) )
+    {
+        setPaletteRightQTH (true);
+        completedWithPreviousQTH = true;
+        qthLineEdit->setText(_st);
+    }
+    else if (completedWithPreviousQTH && (_st != getQTH()))
+    {
+        completedWithPreviousQTH = false;
+        setPaletteRightQTH (false);
+    }
 }
 
 QString MainWindowInputQSO::getRSTTX()
 {
+   //qDebug() << Q_FUNC_INFO << " - Start";
     return rstTXLineEdit->text();
 }
 
 void MainWindowInputQSO::setRSTTX(const QString &_st)
 {
+   //qDebug() << Q_FUNC_INFO << " - Start";
     rstTXLineEdit->setText (_st);
 }
 
 QString MainWindowInputQSO::getRSTRX()
 {
+   //qDebug() << Q_FUNC_INFO << " - Start";
     return rstRXLineEdit->text();
 }
 
 void MainWindowInputQSO::setRSTRX(const QString &_st)
 {
+   //qDebug() << Q_FUNC_INFO << " - Start";
     rstRXLineEdit->setText (_st);
 }
 
 
 void MainWindowInputQSO::setRSTToMode(const QString &_m, const bool _reading)
 {
+   //qDebug() << Q_FUNC_INFO << " - Start";
     //qDebug() << Q_FUNC_INFO << ": " << _m ;
 
     if ((_m == "SSB") || (_m== "LSB") || (_m=="USB") || (_m == "FM") || (_m == "AM") )
@@ -497,16 +608,27 @@ void MainWindowInputQSO::setRSTToMode(const QString &_m, const bool _reading)
     }
 }
 
-bool MainWindowInputQSO::getDarkMode()
-{
-    return (nameLineEdit->palette().color(QPalette::Base) == "#646464");
-}
+//void MainWindowInputQSO::slotPaletteChanged(QPalette _p)
+//{
+   //qDebug() << Q_FUNC_INFO << " - " << nameLineEdit->palette().color(QPalette::Base);
+//}
+
+//bool MainWindowInputQSO::getdarkMode
+//{
+    //qDebug() << Q_FUNC_INFO << " - Start: " << nameLineEdit->palette().color(QPalette::Base).name(QColor::HexRgb);
+    //New faf9f8
+    //FOrmer color #646464
+    //qDebug() << Q_FUNC_INFO << " - Start: " << util->boolToQString((nameLineEdit->palette().color(QPalette::Base).name(QColor::HexRgb) == "#646464"));
+//    return darkMode;
+    //return  (nameLineEdit->palette().color(QPalette::Base).name(QColor::HexRgb) == "#faf9f8");
+//}
 
 void MainWindowInputQSO::setPaletteRightName(const bool _ok)
 {
+   //qDebug() << Q_FUNC_INFO << " - Start";
     if (_ok)
     {
-        if (getDarkMode())
+        if (darkMode)
         {
             nameLineEdit->setPalette (palWhite);
         }
@@ -523,9 +645,10 @@ void MainWindowInputQSO::setPaletteRightName(const bool _ok)
 
 void MainWindowInputQSO::setPaletteRightQTH(const bool _ok)
 {
+   //qDebug() << Q_FUNC_INFO << " - Start";
     if (_ok)
     {
-        if (getDarkMode())
+        if (darkMode)
         {
             qthLineEdit->setPalette (palWhite);
         }
@@ -542,9 +665,10 @@ void MainWindowInputQSO::setPaletteRightQTH(const bool _ok)
 
 void MainWindowInputQSO::setPaletteRightDXLocator(const bool _ok)
 {
+   //qDebug() << Q_FUNC_INFO << " - Start";
     if (_ok)
     {
-        if (getDarkMode())
+        if (darkMode)
         {
             locatorLineEdit->setPalette (palWhite);
         }
@@ -559,6 +683,21 @@ void MainWindowInputQSO::setPaletteRightDXLocator(const bool _ok)
     }
 }
 
+void MainWindowInputQSO::setDarkMode (const bool _dm)
+{
+    darkMode = _dm;
+
+    if (darkMode) {
+        txFreqSpinBox->setPalette(palWhite);
+        rxFreqSpinBox->setPalette(palWhite);
+        //qDebug() << Q_FUNC_INFO << " - DarkMode: ON";
+    } else {
+        //qDebug() << Q_FUNC_INFO << " - DarkMode: OFF";
+        txFreqSpinBox->setPalette(palBlack);
+        rxFreqSpinBox->setPalette(palBlack);
+    }
+}
+
 void MainWindowInputQSO::setPropModeFromSat(const QString &_p)
 {
     //qDebug() << Q_FUNC_INFO << ": " << _p;
@@ -575,10 +714,10 @@ void MainWindowInputQSO::setPropModeFromSat(const QString &_p)
 
 void MainWindowInputQSO::slotFreqTXChanged (double _f)
 {
-    //qDebug() << Q_FUNC_INFO << ": " << QString::number(_f);
+   //qDebug() << Q_FUNC_INFO << ": " << QString::number(_f);
     if (util->isSameFreq (_f, freqTX))
     {
-        //qDebug() << Q_FUNC_INFO << ": Same Freq return" ;
+       //qDebug() << Q_FUNC_INFO << ": Same Freq return" ;
         return;
     }
     freqTX = _f;
@@ -586,35 +725,38 @@ void MainWindowInputQSO::slotFreqTXChanged (double _f)
     if (bandId > 1)
     { // If the freq belongs to one ham band
         txFreqSpinBox->setToolTip(tr("TX Frequency in MHz."));
-        if (getDarkMode())
+        if (darkMode)
         {
+            //qDebug() << Q_FUNC_INFO << " - We are in darkmode";
             txFreqSpinBox->setPalette(palWhite);
         }
         else
         {
+            //qDebug() << Q_FUNC_INFO << " - We are NOT in darkmode";
             txFreqSpinBox->setPalette(palBlack);
         }
-        //qDebug() << Q_FUNC_INFO << ": emitting: " << QString::number(_f);
+       //qDebug() << Q_FUNC_INFO << ": emitting: " << QString::number(_f);
         emit txFreqChanged (_f);
     }
     else
     {
         txFreqSpinBox->setToolTip(tr("TX Frequency in MHz.\nFrequency is not in a hamradio band!"));
         txFreqSpinBox->setPalette(palRed);
-         //qDebug() << Q_FUNC_INFO << ":RED - Not in band " ;
+        //qDebug() << Q_FUNC_INFO << ":RED - Not in band " ;
     }
     if ((!splitCheckBox->isChecked()) && !modify)
     {
         rxFreqSpinBox->setValue (_f);
-        //qDebug() << Q_FUNC_INFO << ": copying to RX Freq " ;
+       //qDebug() << Q_FUNC_INFO << ": copying to RX Freq " ;
     }
-    //qDebug() << Q_FUNC_INFO << " - END" ;
+   //qDebug() << Q_FUNC_INFO << " - END" ;
     setSplitCheckBox();
 }
 
 void MainWindowInputQSO::slotSplitClicked()
 {
-    if ((!splitCheckBox->isChecked())  )
+   //qDebug() << Q_FUNC_INFO << " - Start";
+    if (!splitCheckBox->isChecked())
     {
         rxFreqSpinBox->setValue(txFreqSpinBox->value());
     }
@@ -622,6 +764,7 @@ void MainWindowInputQSO::slotSplitClicked()
 
 void MainWindowInputQSO::slotFreqRXChanged(double _f)
 {
+   //qDebug() << Q_FUNC_INFO << " - Start";
     if (util->isSameFreq (_f, freqRX))
     {
         return;
@@ -630,12 +773,14 @@ void MainWindowInputQSO::slotFreqRXChanged(double _f)
     int bandId = dataProxy->getBandIdFromFreq(_f);
     if (bandId > 1)
     { // If the freq belongs to one ham band
-        if (getDarkMode())
+        if (darkMode)
         {
+            //qDebug() << Q_FUNC_INFO << " - We are in darkmode";
             rxFreqSpinBox->setPalette(palWhite);
         }
         else
         {
+            //qDebug() << Q_FUNC_INFO << " - We are NOT in darkmode";
             rxFreqSpinBox->setPalette(palBlack);
         }
         rxFreqSpinBox->setToolTip(tr("RX Frequency in MHz."));
@@ -677,6 +822,7 @@ void MainWindowInputQSO::slotFreqRXChanged(double _f)
 
 void MainWindowInputQSO::setSplitCheckBox()
 {
+   //qDebug() << Q_FUNC_INFO << " - Start";
    if (util->isSameFreq(txFreqSpinBox->value(), rxFreqSpinBox->value()))
     {
         splitCheckBox->setChecked(false);
@@ -689,13 +835,14 @@ void MainWindowInputQSO::setSplitCheckBox()
 
 void MainWindowInputQSO::receiveFocus()
 {
-    //qDebug() << Q_FUNC_INFO;
+   //qDebug() << Q_FUNC_INFO << " - Start";
     rstTXLineEdit->setFocus ();
 }
 
 bool MainWindowInputQSO::eventFilter (QObject *object, QEvent *event)
 {
     Q_UNUSED(object);
+   //qDebug() << Q_FUNC_INFO << " - Start";
     if (!(event->type() == QEvent::Paint ))
     {
         //qDebug() << Q_FUNC_INFO << ": " << QString::number(event->type ());
@@ -718,3 +865,4 @@ bool MainWindowInputQSO::eventFilter (QObject *object, QEvent *event)
     }
     return QWidget::event(event);
 }
+
