@@ -34,6 +34,7 @@
 #include "../dataproxy_sqlite.h"
 //#include "../locator.h"
 #include "../utilities.h"
+#include "../qso.h"
 
 class MainWindowInputQSO : public QWidget
 {
@@ -43,19 +44,19 @@ class MainWindowInputQSO : public QWidget
 public:
     explicit MainWindowInputQSO(DataProxy_SQLite *dp, QWidget *parent = nullptr);
     ~MainWindowInputQSO();
-
+    void setDarkMode (const bool _dm);
     void setPaletteRightName(const bool _ok);
     void setPaletteRightQTH(const bool _ok);
     void setPaletteRightDXLocator(const bool _ok);
 
     QString getDXLocator();
-    void setDXLocator(const QString &_loc);
+    void setDXLocator(const QString &_loc, bool _completing = false);
 
     QString getName();
-    void setName(const QString &_st);
+    void setName(const QString &_st, bool _completing = false);
 
     QString getQTH();
-    void setQTH(const QString &_st);
+    void setQTH(const QString &_st, bool _completing = false);
 
     void setRSTToMode(const QString &_m, const bool _reading = true);
 
@@ -84,6 +85,9 @@ public:
     void clearQTH();
     void clearDXLocator();
 
+    QSO getQSOData(QSO _qso);
+    void setQSOData(const QSO &_qso);
+
 signals:
     void returnPressed();
     void dxLocatorChanged(QString _loc);
@@ -100,6 +104,7 @@ private slots:
     void slotFreqTXChanged (double _f);
     void slotFreqRXChanged (double _f);
     void slotSplitClicked();
+    //void slotPaletteChanged(QPalette _p);
 
 private:
     bool eventFilter(QObject *object, QEvent *event);
@@ -107,6 +112,7 @@ private:
     void setDefaultData();
     bool getDarkMode();
     void setSplitCheckBox();
+    void readDarkMode();
 
 
     QLineEdit *rstTXLineEdit, *rstRXLineEdit, *qthLineEdit, *locatorLineEdit, *nameLineEdit;
@@ -123,7 +129,8 @@ private:
     bool rxFreqBeingAutoChanged, txFreqBeingAutoChanged, isSATPropagation;
     QString propMode;
     double freqTX, freqRX;
-    bool modify;
+    bool modify, completedWithPreviousName, completedWithPreviousQTH, completedWithPreviousLocator;
+    bool darkMode;
 };
 
 #endif // MAINWINDOWINPUTQSO_H
