@@ -25,6 +25,7 @@
  *****************************************************************************/
 
 #include "mainwindowmydatatab.h"
+#include "../callsign.h"
 
 MainWindowMyDataTab::MainWindowMyDataTab(DataProxy_SQLite *dp, QWidget *parent) :
     QWidget(parent)
@@ -49,15 +50,16 @@ MainWindowMyDataTab::MainWindowMyDataTab(DataProxy_SQLite *dp, QWidget *parent)
 
     stationCallsign = QString();    // Defined in the configuration by the user, will be used if the user configured so in the setup
     operatorQRZ = QString();        // Defined in the configuration by the user, will be used if the user configured so in the setup
-    myLocator = QString();          // Defined in the configuration by the user, will be used if the user configured so in the setup
-    util = new Utilities(Q_FUNC_INFO);
-    modify = false;
+    myLocator   = QString();          // Defined in the configuration by the user, will be used if the user configured so in the setup
+    util        = new Utilities(Q_FUNC_INFO);
+    modify      = false;
+    darkMode    = false;
     createUI();
     setInitialADIFValues();
     myPower = 0;
     lastPower = 0;
-    util->setLongPrefixes(dataProxy->getLongPrefixes());
-    util->setSpecialCalls(dataProxy->getSpecialCallsigns());
+    //util->setLongPrefixes(dataProxy->getLongPrefixes());
+    //util->setSpecialCalls(dataProxy->getSpecialCallsigns());
        //qDebug() << "MainWindowMyDataTab::MainWindowMyDataTab - END"  ;
 }
 
@@ -66,7 +68,52 @@ MainWindowMyDataTab::~MainWindowMyDataTab()
     logEvent (Q_FUNC_INFO, "Start", Debug);
     delete(locator);
     delete(util);
-    delete(dataProxy);
+    //delete(dataProxy);
+}
+
+void MainWindowMyDataTab::readDarkMode()
+{
+    QSettings settings(util->getCfgFile (), QSettings::IniFormat);
+    settings.beginGroup ("Colors");
+    setDarkMode(settings.value("DarkMode", false).toBool ());
+    settings.endGroup ();
+}
+
+QSO MainWindowMyDataTab::getQSOData(QSO _qso)
+{
+    QSO qso = _qso;
+
+    qso.setOperatorCallsign(getOperator());
+    qso.setTXPwr(getMyPower());
+    qso.setStationCallsign(getStationCallsign());
+    qso.setMyGridSquare(getMyLocator());
+    qso.setMyRig(getMyRig());
+    qso.setMyAntenna(getMyAntenna());
+    qso.setMyPOTA_Ref(getMyPota_ref());
+    qso.setMySig(getMySig());
+    qso.setMySigInfo(getMySig_info());
+    qso.setMySOTA_REF(getMySOTA());
+    qso.setMyWWFF_Ref(getMyWWFF_Ref());
+    qso.setMyVUCCGrids(getMyVUCCGrids());
+
+    return qso;
+}
+
+void MainWindowMyDataTab::setQSOData(const QSO &_qso)
+{
+    QSO qso(_qso);
+    setOperator(qso.getOperatorCallsign());
+    setMyPower(qso.getTXPwr());
+    setStationCallsign(qso.getStationCallsign());
+    setMyLocator(qso.getMyGridSquare());
+    setMyRig(qso.getMyRig());
+    setMyAntenna(qso.getMyAntenna());
+    setMyPota_ref(qso.getMyPOTA_Ref());
+    setMySig(qso.getMySig());
+    setMySig_info(qso.getMySigInfo());
+    setMySOTA(qso.getMySOTA_REF());
+    setMyWWFF_Ref(qso.getMyWWFF_Ref());
+    setMyVUCCGrids(qso.getMyVUCCGrids());
 }
 
 void MainWindowMyDataTab::createUI()
@@ -121,9 +168,10 @@ void MainWindowMyDataTab::createUI()
     connect(operatorLineEdit, SIGNAL(textChanged(QString)), this, SLOT(slotOperatorTextChanged()) );
     connect(stationCallSignLineEdit, SIGNAL(returnPressed()), this, SLOT(slotReturnPressed() ) );
     connect(stationCallSignLineEdit, SIGNAL(textChanged(QString)), this, SLOT(slotStationCallSignTextChanged() ) );
-    connect(myUserADIFComboBox, SIGNAL(currentIndexChanged(QString)), this, SLOT(slotMyUserADIFComboBoxChanged() ) ) ;
+    connect(myUserADIFComboBox, SIGNAL(currentTextChanged(QString)), this, SLOT(slotMyUserADIFComboBoxChanged() ) ) ;
 
     connect(myUserADIFLineEdit, SIGNAL(textChanged(QString)), this, SLOT(slotSetCurrentMyUSerData() ) );
+    readDarkMode();
     logEvent (Q_FUNC_INFO, "END", Debug);
 }
 
@@ -136,7 +184,8 @@ void MainWindowMyDataTab::clear(bool _full)
     {
         //qDebug() << "MainWindowMyDataTab::clear: NOT checked" ;
         myPowerSpinBox->setValue(myPower);
-        if (util->isValidCall(operatorQRZ))
+        Callsign callsign(operatorQRZ);
+        if (callsign.isValid())
         {
             //qDebug() << Q_FUNC_INFO << ": " << operatorQRZ;
             operatorLineEdit->setText(operatorQRZ);
@@ -145,7 +194,8 @@ void MainWindowMyDataTab::clear(bool _full)
         {
             operatorLineEdit->clear();
         }
-        if (util->isValidCall(stationCallsign))
+        callsign(stationCallsign);
+        if (callsign.isValid())
         {
             stationCallSignLineEdit->setText(stationCallsign);
         }
@@ -178,7 +228,12 @@ void MainWindowMyDataTab::clear(bool _full)
         my_rig = QString();
         my_sota = QString();
         my_antenna = QString();
+        my_pota_ref = QString();
+        my_sig = QString();
+        my_sig_info = QString();
+        my_wwff_ref = QString();
         my_vucc_grids = QString();
+
         myUserADIFComboBox->setCurrentIndex(0);
         myUserADIFLineEdit->clear();
         keepThisDataForNextQSOQCheckbox->setChecked (false);
@@ -215,7 +270,7 @@ void MainWindowMyDataTab::slotMyLocatorTextChanged()
             myLocator = (myLocatorLineEdit->text()).toUpper();
         }
 
-        if (getDarkMode())
+        if (darkMode)
         {
             myLocatorLineEdit->setPalette(palWhite);
         }
@@ -252,19 +307,6 @@ void MainWindowMyDataTab::slotReturnPressed()
 }
 
 
-/*
-void MainWindowMyDataTab::setSetupStationQRZ(const QString &_op)
-{
-    //qDebug() << Q_FUNC_INFO << ": " << _op ;
-    if (!util->isValidCall (_op))
-    {
-        return;
-    }
-    stationQRZ = _op.toUpper();
-    stationCallSignLineEdit->setText(stationQRZ);
-}
-*/
-
 void MainWindowMyDataTab::setSetupMyLocator(const QString &_op)
 {
     //qDebug() << Q_FUNC_INFO;
@@ -324,7 +366,8 @@ void MainWindowMyDataTab::setStationCallsign(const QString &_op)
 {
     //qDebug() << Q_FUNC_INFO << ": " << _op;
     logEvent (Q_FUNC_INFO, "Start", Debug);
-    if (util->isValidCall (_op))
+    Callsign callsign(_op);
+    if (callsign.isValid())
     {
         stationCallSignLineEdit->setText(_op);
     }
@@ -363,8 +406,8 @@ void MainWindowMyDataTab::setData(const QString &_stationCallsign, const QString
 {
     //qDebug() << Q_FUNC_INFO;
     logEvent (Q_FUNC_INFO, "Start", Debug);
-
-    if (util->isValidCall (_stationCallsign))
+    Callsign callsign(_stationCallsign);
+    if (callsign.isValid())
     {
         stationCallsign = _stationCallsign;
     }
@@ -374,7 +417,7 @@ void MainWindowMyDataTab::setData(const QString &_stationCallsign, const QString
     }
     //qDebug() << Q_FUNC_INFO << ": Setting station Callsign: " << stationCallsign;
     setStationCallsign (stationCallsign);
-
+    callsign(_operator);
     if (_operator.length()>0)
     {
         setOperator (_operator);
@@ -403,9 +446,11 @@ void MainWindowMyDataTab::slotOperatorTextChanged()
     int cursorP = operatorLineEdit->cursorPosition();
 
     operatorLineEdit->setText(util->getClearSQLi(operatorLineEdit->text()).toUpper());
-    if (util->isValidCall(operatorLineEdit->text()))
+
+    Callsign callsign(operatorLineEdit->text());
+    if (callsign.isValid())
     {
-        if (getDarkMode())
+        if (darkMode)
         {
             operatorLineEdit->setPalette(palWhite);
         }
@@ -433,6 +478,25 @@ void MainWindowMyDataTab::slotOperatorTextChanged()
     operatorLineEdit->setCursorPosition(cursorP);
 }
 
+void MainWindowMyDataTab::setDarkMode (const bool _dm)
+{
+    darkMode = _dm;
+    if (darkMode)
+    {
+        myLocatorLineEdit->setPalette(palWhite);
+        operatorLineEdit->setPalette(palWhite);
+        stationCallSignLineEdit->setPalette(palWhite);
+        myUserADIFLineEdit->setPalette(palWhite);
+    }
+    else
+    {
+        myLocatorLineEdit->setPalette(palBlack);
+        operatorLineEdit->setPalette(palBlack);
+        stationCallSignLineEdit->setPalette(palBlack);
+        myUserADIFLineEdit->setPalette(palBlack);
+    }
+}
+
 void MainWindowMyDataTab::slotStationCallSignTextChanged()
 {
     //qDebug() << Q_FUNC_INFO;
@@ -440,9 +504,11 @@ void MainWindowMyDataTab::slotStationCallSignTextChanged()
     int cursorP = stationCallSignLineEdit->cursorPosition();
 
     stationCallSignLineEdit->setText(util->getClearSQLi(stationCallSignLineEdit->text()).toUpper());
-    if (util->isValidCall(stationCallSignLineEdit->text()))
+
+    Callsign callsign(stationCallSignLineEdit->text());
+    if (callsign.isValid())
     {
-        if (getDarkMode())
+     if (darkMode)
         {
             stationCallSignLineEdit->setPalette(palWhite);
         }
@@ -477,7 +543,12 @@ bool MainWindowMyDataTab::setInitialADIFValues()
     //qDebug() << Q_FUNC_INFO;
     logEvent (Q_FUNC_INFO, "Start", Debug);
     adifValidTypes.clear ();
-    adifValidTypes << "01-" + tr("My Rig") << "02-" + tr("My Antenna") << "03-" + tr("My SOTA_Ref")<< "04-" + tr("My VUCC_GRIDS");
+    adifValidTypes << "01-" + tr("My Rig") << "02-" + tr("My Antenna")
+                   << "03-" + tr("My POTA Ref") << "04-" + tr("My SIG")
+                   << "05-" + tr("My SIG Info") << "06-" + tr("My SOTA Ref")
+                   << "07-" + tr("My VUCC_GRIDS")
+                   << "08-" + tr("My WWFF Ref");
+
     myUserADIFComboBox->clear ();
     myUserADIFComboBox->addItems (adifValidTypes);
     return true;
@@ -495,19 +566,36 @@ bool MainWindowMyDataTab::setUserADIFTypeComboBox(const QString &_value)
     {
         myUserADIFComboBox->setCurrentIndex (1);
     }
-    else if (_value == "MY_SOTA_REF")
+    else if (_value == "MY_POTA_REF")
     {
         myUserADIFComboBox->setCurrentIndex (2);
     }
-    else if (_value == "MY_VUCC_GRIDS")
+    else if (_value == "MY_SIG")
     {
         myUserADIFComboBox->setCurrentIndex (3);
     }
+    else if (_value == "MY_SIG_INFO")
+    {
+        myUserADIFComboBox->setCurrentIndex (4);
+    }
+    else if (_value == "MY_SOTA_REF")
+    {
+        myUserADIFComboBox->setCurrentIndex (5);
+    }
+    else if (_value == "MY_VUCC_GRIDS")
+    {
+        myUserADIFComboBox->setCurrentIndex (6);
+    }
+    else if (_value == "MY_WWFF_REF")
+    {
+        myUserADIFComboBox->setCurrentIndex (7);
+    }
     else
     {
         myUserADIFComboBox->setCurrentIndex (0);
         return false;
     }
+
     return true;
 }
 
@@ -518,15 +606,22 @@ QString MainWindowMyDataTab::getUserADIFTypeComboBox()
     int value = (((myUserADIFComboBox->currentText ()).split('-')).at(0)).toInt ();
     switch (value)
     {
-
     case 1:
         return "MY_RIG";
     case 2:
         return "MY_ANTENNA";
     case 3:
-        return "MY_SOTA_REF";
+        return "MY_POTA_REF";
     case 4:
+        return "MY_SIG";
+    case 5:
+        return "MY_SIG_INFO";
+    case 6:
+        return "MY_SOTA_REF";
+    case 7:
         return "MY_VUCC_GRIDS";
+    case 8:
+        return "MY_WWFF_REF";
     default:
         return QString();
     }
@@ -637,10 +732,69 @@ QString MainWindowMyDataTab::getMyVUCCGrids()
     }
 }
 
+bool MainWindowMyDataTab::setMyPota_ref(const QString &_op)
+{
+    Adif adif(Q_FUNC_INFO);
+    if (!adif.isValidPOTA(_op))
+        return false;
+    my_pota_ref = _op;
+    slotMyUserADIFComboBoxChanged();
+    return true;
+}
+
+QString MainWindowMyDataTab::getMyPota_ref()
+{
+    return my_pota_ref;
+}
+
+bool MainWindowMyDataTab::setMySig(const QString &_op)
+{
+    if (_op.length()<=0)
+        return false;
+    my_sig = _op;
+    slotMyUserADIFComboBoxChanged();
+    return true;
+}
+
+QString MainWindowMyDataTab::getMySig()
+{
+    return my_sig;
+}
+
+bool MainWindowMyDataTab::setMySig_info(const QString &_op)
+{
+    if (_op.length()<=0)
+        return false;
+    my_sig_info = _op;
+    slotMyUserADIFComboBoxChanged();
+    return true;
+}
+
+QString MainWindowMyDataTab::getMySig_info()
+{
+    return my_sig_info;
+}
+
+bool MainWindowMyDataTab::setMyWWFF_Ref(const QString &_op)
+{
+    Adif adif(Q_FUNC_INFO);
+
+    if (!adif.isValidWWFF_Ref(_op))
+        return false;
+    my_wwff_ref = _op;
+    slotMyUserADIFComboBoxChanged();
+    return true;
+}
+
+QString MainWindowMyDataTab::getMyWWFF_Ref()
+{
+    return my_wwff_ref;
+}
+
 void MainWindowMyDataTab::setColorsForMyUserADIFLineEdit()
 {
     logEvent (Q_FUNC_INFO, "Start", Debug);
-    if (getDarkMode())
+    if (darkMode)
     {
         myUserADIFLineEdit->setPalette(palWhite);
     }
@@ -666,6 +820,18 @@ void MainWindowMyDataTab::slotMyUserADIFComboBoxChanged()
     {
         myUserADIFLineEdit->setText (my_antenna);
     }
+    else if (currentTag == "MY_POTA_REF")
+    {
+        myUserADIFLineEdit->setText (my_pota_ref);
+    }
+    else if (currentTag == "MY_SIG")
+    {
+        myUserADIFLineEdit->setText (my_sig);
+    }
+    else if (currentTag == "MY_SIG_INFO")
+    {
+        myUserADIFLineEdit->setText (my_sig_info);
+    }
     else if (currentTag == "MY_SOTA_REF")
     {
         myUserADIFLineEdit->setText (my_sota);
@@ -674,6 +840,10 @@ void MainWindowMyDataTab::slotMyUserADIFComboBoxChanged()
     {
         myUserADIFLineEdit->setText (my_vucc_grids);
     }
+    else if (currentTag == "MY_WWFF_REF")
+    {
+        myUserADIFLineEdit->setText (my_wwff_ref);
+    }
 }
 
 void MainWindowMyDataTab::slotSetCurrentMyUSerData()
@@ -691,18 +861,33 @@ void MainWindowMyDataTab::slotSetCurrentMyUSerData()
     {
         my_antenna = myUserADIFLineEdit->text();
     }
+    else if (currentTag == "MY_POTA_REF")
+    {
+        my_pota_ref = myUserADIFLineEdit->text();
+        //setMyPota_ref(myUserADIFLineEdit->text());
+    }
+    else if (currentTag == "MY_SIG")
+    {
+        my_sig = myUserADIFLineEdit->text();
+    }
+    else if (currentTag == "MY_SIG_INFO")
+    {
+        my_sig_info = myUserADIFLineEdit->text();
+    }
     else if (currentTag == "MY_SOTA_REF")
     {
         my_sota = myUserADIFLineEdit->text();
     }
     else if (currentTag == "MY_VUCC_GRIDS")
     {
-        //if (checkMyVUCC_GRIDS(myUserADIFLineEdit->text()))
-        //{}
-
         my_vucc_grids = myUserADIFLineEdit->text().toUpper();
         myUserADIFLineEdit->setText (my_vucc_grids);
     }
+    else if (currentTag == "MY_WWFF_REF")
+    {
+        my_wwff_ref = myUserADIFLineEdit->text();
+        //setMyWWFF_Ref(myUserADIFLineEdit->text());
+    }
     myUserADIFLineEdit->setCursorPosition (currentPos);
 }
 
@@ -714,18 +899,12 @@ void MainWindowMyDataTab::setModify(const bool _modify)
     //emit debugLog(Q_FUNC_INFO, "END", Debug);
 }
 
-bool MainWindowMyDataTab::getDarkMode()
-{
-    logEvent (Q_FUNC_INFO, "Start", Debug);
-    if (operatorLineEdit->palette().color (QPalette::Base) == "#646464")
-    {
-        return true;
-    }
-    else
-    {
-        return false;
-    }
-}
+//bool MainWindowMyDataTab::getDarkMode()
+//{
+//    logEvent (Q_FUNC_INFO, "Start", Debug);
+   //qDebug() << Q_FUNC_INFO << " - color: " << operatorLineEdit->palette().color (QPalette::Base);
+//    return  (operatorLineEdit->palette().color (QPalette::Base) == "#646464");
+//}
 
 void MainWindowMyDataTab::setLogLevel (const DebugLogLevel _b)
 {
@@ -760,7 +939,9 @@ void MainWindowMyDataTab::loadSettings()
     }
 
     //qDebug() << Q_FUNC_INFO << " - 11";
-    if (util->isValidCall (aux))
+
+    Callsign callsign(aux);                 // Only the first operator is selected. TODO: To save this in a QStringList so the user can select.
+    if (callsign.isValid())
     {
         //qDebug() << Q_FUNC_INFO << " - 12";
         operatorQRZ = aux.toUpper();
