@@ -65,7 +65,24 @@ MainWindowSatTab::MainWindowSatTab(DataProxy_SQLite *dp, QWidget *parent) :
 
 MainWindowSatTab::~MainWindowSatTab(){
     delete(util);
-    delete(dataProxy);
+    //delete(dataProxy);
+}
+
+QSO MainWindowSatTab::getQSOData(QSO _qso)
+{
+    QSO qso = _qso;
+
+    qso.setSatName(getSatName());
+    qso.setSatMode(getSatMode());
+
+    return qso;
+}
+
+void MainWindowSatTab::setQSOData(const QSO &_qso)
+{
+    QSO qso(_qso);
+    setSatName(qso.getSatName());
+    setSatMode(qso.getSatMode());
 }
 
 void MainWindowSatTab::createUI()
@@ -442,12 +459,6 @@ void MainWindowSatTab::setOtherSatName(const QString &_t)
     satNameLineEdit->setText(_t);
 }
 
-QString MainWindowSatTab::getOtherSatName()
-{
-    //qDebug() << Q_FUNC_INFO << " - Start" ;
-    return QString();
-}
-
 int MainWindowSatTab::getSatIndex(const QString &_p)
 {
     //qDebug() << Q_FUNC_INFO << ": - " << QString::number(satNameComboBox->findText(_p, Qt::MatchContains)) ;
@@ -521,7 +532,7 @@ void MainWindowSatTab::slotSatBandTXComboBoxChanged()
     { // If the freq does not belong to the current band, we need to update the band
        //qDebug() << "MainWindowsatTab::slotSatBandTXComboBoxChanged changing to: Band: " << satBandTXComboBox->currentText() ;
         //qDebug() << "MainWindowsatTab::slotSatBandTXComboBoxChanged changing to: " << QString::number(dataProxy->getLowLimitBandFromBandName(satBandTXComboBox->currentText())) ;
-        QString tmpFreq = dataProxy->getFreqFromBandId(dataProxy->getIdFromBandName(satBandTXComboBox->currentText()));
+        Frequency tmpFreq = dataProxy->getFreqFromBandId(dataProxy->getIdFromBandName(satBandTXComboBox->currentText()));
         //qDebug() << ": Normal" << dataProxy->getSatelliteUplink(getSatName());
         //qDebug() << ": Normal1" << dataProxy->getSatelliteUplink(getSatName(), 1);
         //qDebug() << ": Normal2" << dataProxy->getSatelliteUplink(getSatName(), 2);
