@@ -28,19 +28,20 @@
 
 LogModel::LogModel(DataProxy_SQLite *dp, QObject *parent):QSqlRelationalTableModel(parent)
 {
-    //qDebug() << Q_FUNC_INFO ;
+     //qDebug() << Q_FUNC_INFO ;
     //logModel = new QSqlRelationalTableModel(this);
     dataProxy = dp;
     util = new Utilities(Q_FUNC_INFO);
-    //qDebug() << Q_FUNC_INFO << "llamando a filterValidFields";
-    columns = dataProxy->filterValidFields(util->getDefaultLogFields());
+     //qDebug() << Q_FUNC_INFO << "llamando a filterValidFields";
+    columns.clear();
+    columns.append(dataProxy->filterValidFields(util->getDefaultLogFields()));
     setTable("log");
+
     setEditStrategy(QSqlTableModel::OnFieldChange);
     //qDebug() << Q_FUNC_INFO << " - END";
 }
 
-
-void LogModel::createlogModel(const int _i)
+bool LogModel::createlogModel(const int _i)
 {
 /*
     Log_Id = 0,
@@ -67,26 +68,35 @@ This should be coherent with the logview
 
     //qDebug() << Q_FUNC_INFO ;
 
-
     QString stringQuery = QString("lognumber='%1'").arg(_i);
     //QSqlQuery query(stringQuery);
     setFilter(stringQuery);
-    setColumns(columns);
+    if (!setColumns(columns))
+    {
+        //qDebug() << Q_FUNC_INFO << " - ERROR on setColumns";
+        return false;
+    }
 
-    select();
-    //qDebug() << Q_FUNC_INFO << " - END";
+    if (!select())
+    {
+        //qDebug() << Q_FUNC_INFO << " - ERROR on select()";
+        return false;
+    }
+
+  //qDebug() << Q_FUNC_INFO << " - END";
+    return true;
 }
 
- void LogModel::setColumns(const QStringList &_columns)
- {
-     //qDebug() << Q_FUNC_INFO ;
-     //QString auxt;
-     //foreach(auxt, _columns)
-     //{
-     //    //qDebug() << Q_FUNC_INFO << ": " << auxt;
-     //}
+bool LogModel::setColumns(const QStringList &_columns)
+{
+    //qDebug() << Q_FUNC_INFO ;
+    QString auxt;
+    foreach(auxt, _columns)
+    {
+        //qDebug() << Q_FUNC_INFO << ": " << auxt;
+    }
     columns.clear();
-    //qDebug() << Q_FUNC_INFO << "llamando a filterValidFields";
+     //qDebug() << Q_FUNC_INFO << " - calling filterValidFields";
     columns << dataProxy->filterValidFields(_columns);
 
      QSqlQuery q;
@@ -95,16 +105,21 @@ This should be coherent with the logview
 
      int nameCol;
 
-     bool sqlOK = q.exec(stringQuery);
-     if (!sqlOK)
+     if (!q.exec(stringQuery))
      {
-         emit queryError(Q_FUNC_INFO, q.lastError().databaseText(), q.lastError().nativeErrorCode(), q.lastQuery());
-
+        emit queryError(Q_FUNC_INFO, q.lastError().databaseText(), q.lastError().nativeErrorCode(), q.lastQuery());
+        //qDebug() << Q_FUNC_INFO << " - END - 1";
+        return false;
      }
-     q.next();
+
+     //if (!q.next())
+     //{
+     //    //qDebug() << Q_FUNC_INFO << " - END - 2";
+     //    return false;
+     //}
      rec = q.record(); // Number of columns
 
-    //qDebug() << "LogModel::createlogModel - columns: " << QString::number(rec.count());
+     //qDebug() <<Q_FUNC_INFO << ": - columns: " << QString::number(rec.count());
 
      if (_columns.contains("bandid"))
      {
@@ -143,27 +158,14 @@ This should be coherent with the logview
      foreach(aux, columns)
      {
          nameCol = rec.indexOf(aux);
-         setHeaderData(nameCol, Qt::Horizontal, util->getLogColumnName(aux));
+         if (!setHeaderData(nameCol, Qt::Horizontal, util->getLogColumnName(aux)))
+         {
+             //qDebug() << Q_FUNC_INFO << ": - ERROR when adding the following column to the log view model: " << aux;
+             return false;
+         }
          //qDebug() << Q_FUNC_INFO << ": - " << aux;
-     }
-     //qDebug() << Q_FUNC_INFO << " - END";
+    }
+    //qDebug() << Q_FUNC_INFO << " - END";
+    return true;
  }
-/*
- void LogModel::showColumn(const QString &_columnName)
- {
-     QString stringQuery;
-     stringQuery = QString("SELECT * FROM log LIMIT 1");
-     QSqlQuery query;
-     bool sqlOK = query.exec(stringQuery);
-     if (!sqlOK)
-     {
-         emit queryError(Q_FUNC_INFO, query.lastError().databaseText(), query.lastError().nativeErrorCode(), query.lastQuery());
-     }
-     QSqlRecord rec;
-     rec = query.record(); // Number of columns
 
-     int nameCol = rec.indexOf(_columnName);
-     setHeaderData(nameCol, Qt::Horizontal, _columnName);
-
- }
-*/
