@@ -39,8 +39,9 @@ class LogModel : public QSqlRelationalTableModel
     Q_OBJECT
 public:
     LogModel(DataProxy_SQLite *dp, QObject *parent);
-    void createlogModel(const int _i);
-    void setColumns(const QStringList &_columns);
+    bool createlogModel(const int _i);
+    bool setColumns(const QStringList &_columns);
+
 private:
     //void showColumn(const QString &_columnName);
 
@@ -52,7 +53,6 @@ private:
 
 signals:
     void queryError(QString functionFailed, QString errorCodeS, QString nativeError, QString failedQuery); // To alert about any failed query execution
-
 };
 
 #endif // LOGMODEL_H
