@@ -27,90 +27,110 @@
 #include "logwindow.h"
 
 
-LogWindow::LogWindow(DataProxy_SQLite *dp, QWidget *parent) : QWidget(parent)
+LogWindow::LogWindow(Awards *awards, QWidget *parent)
+    : QWidget(parent),
+    awards(awards)
 {
-    //qDebug() << "LogWindow::LogWindow: " ;
-    dataProxy = dp;
-    //sortingThroughProxyModel = false;
+
+    //qDebug() << Q_FUNC_INFO << " - Start";
+    dataProxy = awards->dataProxy;
     logModel = new LogModel(dataProxy, this);
     util = new Utilities(Q_FUNC_INFO);
     connect(logModel, SIGNAL(queryError(QString, QString, QString, QString)), this, SLOT(slotQueryErrorManagement(QString, QString, QString, QString)) );
     logView = new QTableView;
     columns.clear();
 
-    //dxccStatusWidget = new DXCCStatusWidget(dataProxy);
-    //elogClublog = new eLogClubLog();
     currentLog = -1;
-    //proxyModel = new LogViewSortFilterProxyModel(this);
 
-    awards = new Awards(dataProxy, Q_FUNC_INFO);
+    //awards = new Awards(dataProxy, Q_FUNC_INFO);
 
     createUI();
     createActions();
     setDefaultData();
     //qDebug() << "LogWindow::LogWindow: - END" ;
-
 }
 
 LogWindow::~LogWindow()
 {
+    //qDebug() << Q_FUNC_INFO << " - Start";
     delete(util);
-    delete(awards);
-//    emit clearError();
+    //delete(awards);
+    //qDebug() << Q_FUNC_INFO << " - END";
 }
 
 void LogWindow::setColumns(const QStringList &_columns)
 {
-    //qDebug() << Q_FUNC_INFO;
+    //qDebug() << Q_FUNC_INFO << " - Start";
     columns.clear();
-    //qDebug() << Q_FUNC_INFO << "llamando a filterValidFields";
+  //qDebug() << Q_FUNC_INFO << "llamando a filterValidFields";
     columns << dataProxy->filterValidFields(_columns);
     logModel->setColumns(columns);
+    //qDebug() << Q_FUNC_INFO << " - END";
 }
 
 void LogWindow::sortColumn(const int _c)
 {
-    //proxyModel->sort(_c);
+    //qDebug() << Q_FUNC_INFO << " - Start";
     logModel->sort(_c, Qt::AscendingOrder);
+    //qDebug() << Q_FUNC_INFO << " - END";
 }
 
 void LogWindow::clear()
 {
-      //qDebug() << "LogWindow::clear " ;
+    //qDebug() << Q_FUNC_INFO << " - Start/END";
 }
 
 void LogWindow::createUI()
 {
-    //qDebug() << Q_FUNC_INFO;
+    //qDebug() << Q_FUNC_INFO << " - Start";
 
     logView->setContextMenuPolicy(Qt::CustomContextMenu);
     logView->setSortingEnabled(true);
     logView->horizontalHeader ()->setSectionsMovable (true);
     //logView->setDragDropMode (QAbstractItemView::InternalMove);
     //logView->setDropIndicatorShown (true);
+    //retoreColumsOrder();
 
     QVBoxLayout *layout = new QVBoxLayout;
     layout->addWidget(logView);
     setLayout(layout);
+}
 
+void LogWindow::retoreColumsOrder()
+{
+    // Restore the column order from the settings
+    QSettings settings(util->getCfgFile (), QSettings::IniFormat);
+    settings.beginGroup("LogWindow");
+    QList<int> columnOrder = settings.value("columnOrder").value<QList<int>>();
+    settings.endGroup();
+
+    if (!columnOrder.isEmpty()) {
+        for (int i = 0; i < columnOrder.size(); ++i) {
+            logView->horizontalHeader()->moveSection(logView->horizontalHeader()->visualIndex(columnOrder[i]), i);
+        }
+    }
 }
 
 void LogWindow::setDefaultData()
 {
-    //qDebug() << Q_FUNC_INFO;
+    //qDebug() << Q_FUNC_INFO << " - Start";
     columns.clear();
     //qDebug() << Q_FUNC_INFO << "llamando a filterValidFields";
     columns << dataProxy->filterValidFields(util->getDefaultLogFields());
-       //qDebug() << "LogWindow::setDefaultData" ;
+    //qDebug() << "LogWindow::setDefaultData" ;
+    //qDebug() << Q_FUNC_INFO << " - END";
 }
 
 
 void LogWindow::createlogPanel(const int _currentLog)
 {
-    //qDebug() << "LogWindow::createlogPanel: " << QString::number(_currentLog);
+    //qDebug() << Q_FUNC_INFO << " - Start : " << QString::number(_currentLog);
     currentLog = _currentLog;
-    logModel->createlogModel(currentLog);
-    //proxyModel->setSourceModel(logModel);
+    if (!logModel->createlogModel(currentLog))
+    {
+      //qDebug() << Q_FUNC_INFO << " - ERROR creating model";
+    }
+
     logView->setModel(logModel);
     logView->setCurrentIndex(logModel->index(0, 0));
 
@@ -122,12 +142,12 @@ void LogWindow::createlogPanel(const int _currentLog)
     logView->resizeColumnsToContents();
     logView->horizontalHeader()->setStretchLastSection(true);
     logView->sortByColumn(1, Qt::DescendingOrder);
-
+    //qDebug() << Q_FUNC_INFO << " - END";
 }
 
 void LogWindow::setColumnsOfLog(const QStringList &_columns)
 {
-    //qDebug() << Q_FUNC_INFO << ": Length: " << QString::number(_columns.length());
+     //qDebug() << Q_FUNC_INFO << " - Start: Length: " << QString::number(_columns.length());
 
     QString stringQuery;
     stringQuery = QString("SELECT * FROM log LIMIT 1");
@@ -135,7 +155,7 @@ void LogWindow::setColumnsOfLog(const QStringList &_columns)
     bool sqlOK = query.exec(stringQuery);
     if (!sqlOK)
     {
-        emit queryError(Q_FUNC_INFO, query.lastError().databaseText(), query.lastError().nativeErrorCode(), query.lastQuery());
+        emit queryError(Q_FUNC_INFO, query.lastError().databaseText(), query.lastError().text(), query.lastQuery());
     }
     QSqlRecord rec;
     rec = query.record(); // Number of columns
@@ -147,41 +167,43 @@ void LogWindow::setColumnsOfLog(const QStringList &_columns)
     }
 
     QString aux;
-    foreach(aux, columns)
-    {
-        //qDebug() << Q_FUNC_INFO << ": columns-1: " << aux;
-    }
-    foreach(aux, _columns)
-    {
-        //qDebug() << Q_FUNC_INFO << ": _columns-1: " << aux;
-    }
+    //foreach(aux, columns)
+    //{
+         //qDebug() << Q_FUNC_INFO << ": columns-1: " << aux;
+    //}
+    //foreach(aux, _columns)
+    //{
+         //qDebug() << Q_FUNC_INFO << ": _columns-1: " << aux;
+    //}
     QStringList temPColumns;
     temPColumns.clear();
     temPColumns << _columns;
     columns.clear();
-    //qDebug() << Q_FUNC_INFO << "llamando a filterValidFields";
+    //qDebug() << Q_FUNC_INFO << "calling filterValidFields";
     columns <<  dataProxy->filterValidFields(temPColumns);
-    foreach(aux, columns)
-    {
+    //foreach(aux, columns)
+    //{
         //qDebug() << Q_FUNC_INFO << ":-2:  " << aux;
-    }
+    //}
 
     foreach(aux, columns)
     {
         //qDebug() << Q_FUNC_INFO << ": " << aux;
         showColumn(aux);
     }
+    //qDebug() << Q_FUNC_INFO << " - END";
 }
 
 void LogWindow::showColumn(const QString &_columnName)
 {
+    //qDebug() << Q_FUNC_INFO << " - Start";
     QString stringQuery;
     stringQuery = QString("SELECT * FROM log LIMIT 1");
     QSqlQuery query;
     bool sqlOK = query.exec(stringQuery);
     if (!sqlOK)
     {
-        emit queryError(Q_FUNC_INFO, query.lastError().databaseText(), query.lastError().nativeErrorCode(), query.lastQuery());
+        emit queryError(Q_FUNC_INFO, query.lastError().databaseText(), query.lastError().text(), query.lastQuery());
     }
     QSqlRecord rec;
     rec = query.record(); // Number of columns
@@ -191,28 +213,43 @@ void LogWindow::showColumn(const QString &_columnName)
 
 void LogWindow::refresh()
 {
-    //qDebug() << "LogWindow::refresh" ;
-    logModel->select();
+  //qDebug() << Q_FUNC_INFO << " - Start";
+    if (!logModel->select())
+    {
+        //qDebug() << Q_FUNC_INFO << " - ERROR on select()";
+      //qDebug() << Q_FUNC_INFO << " - Error refreshing log:" << logModel->lastError().text();
+        QMessageBox msgBox;
+        msgBox.setText(tr("There was a problem with the log, please restart KLog and contact the development team if the error persist."));
+        msgBox.setIcon(QMessageBox::Critical);
+        msgBox.setStandardButtons(QMessageBox::Ok);
+        msgBox.setDefaultButton(QMessageBox::Ok);
+        msgBox.exec();
+    }
+  //qDebug() << Q_FUNC_INFO << " - END";
 }
 
 void LogWindow::createActions()
 {
-    //qDebug() << Q_FUNC_INFO;
+    //qDebug() << Q_FUNC_INFO << " - Start";
     createActionsCommon();
     showMenuRightButtonFromLogCreateActions();
+    //qDebug() << Q_FUNC_INFO << " - END";
 }
 
 void LogWindow::createActionsCommon()
 {
+    //qDebug() << Q_FUNC_INFO << " - Start";
     //LOG VIEW
+    connect(logView, SIGNAL(customContextMenuRequested( const QPoint& ) ), this, SLOT(slotRighButtonFromLog( const QPoint& ) ) );
+    connect(logView, SIGNAL(doubleClicked ( const QModelIndex& ) ), this, SLOT(slotDoubleClickLog( const QModelIndex& ) ) );
+    connect(logView->horizontalHeader(), &QHeaderView::sectionMoved, this, &LogWindow::slotOnSectionMoved);
 
-        connect(logView, SIGNAL(customContextMenuRequested( const QPoint& ) ), this, SLOT(slotRighButtonFromLog( const QPoint& ) ) );
-        connect(logView, SIGNAL(doubleClicked ( const QModelIndex& ) ), this, SLOT(slotDoubleClickLog( const QModelIndex& ) ) );
+    //qDebug() << Q_FUNC_INFO << " - END";
 }
 
 void LogWindow::slotRighButtonFromLog(const QPoint& pos)
 {
-    //qDebug() << Q_FUNC_INFO;
+    //qDebug() << Q_FUNC_INFO << " - Start";
     int row = (logView->indexAt(pos)).row();
     QItemSelectionModel *select = logView->selectionModel();
     QModelIndexList list = select->selectedRows();
@@ -225,12 +262,13 @@ void LogWindow::slotRighButtonFromLog(const QPoint& pos)
     {
         rightButtonFromLogMenu(row);
     }
+    //qDebug() << Q_FUNC_INFO << " - END";
     //TODO: To be added to the logWindow and create an action that emist the QSO id
 }
 
 void LogWindow::rightButtonMultipleFromLogMenu()
 {
-    //qDebug() << Q_FUNC_INFO;
+    //qDebug() << Q_FUNC_INFO << " - Start";
 
     QMenu menu(this);
     menu.addAction(multipleDelQSOsFromLogAct);
@@ -260,14 +298,15 @@ void LogWindow::rightButtonMultipleFromLogMenu()
     menu.addAction(multipleSelectAll);
     menu.addAction(multipleDeselectAll);
     menu.exec(QCursor::pos());
+    //qDebug() << Q_FUNC_INFO << " - END";
 }
 
 void LogWindow::rightButtonFromLogMenu(const int trow)
 {
-    //qDebug() << "LogWindow::slotshowRighButtonFromLogMenu:  " << QString::number(trow);
-    //qDebug() << Q_FUNC_INFO;
+    //qDebug() << Q_FUNC_INFO << " - Start: " << QString::number(trow);
+     //qDebug() << Q_FUNC_INFO;
     int _qsoID = ((logModel->index(trow, 0)).data(0)).toInt();
-    //qDebug() << "LogWindow::slotshowRighButtonFromLogMenu:  QSOid: " << QString::number(_qsoID);
+     //qDebug() << "LogWindow::slotshowRighButtonFromLogMenu:  QSOid: " << QString::number(_qsoID);
     bool qslReceived = isQSLReceived(_qsoID);
     bool qslSent = isQSLSent(_qsoID);
     QMenu menu(this);
@@ -304,18 +343,19 @@ void LogWindow::rightButtonFromLogMenu(const int trow)
         menu.addAction(multipleSelectAll);
         menu.addAction(multipleDeselectAll);
     menu.exec(QCursor::pos());
+    //qDebug() << Q_FUNC_INFO << " - END";
 }
 
 void LogWindow::slotDoubleClickLog(const QModelIndex & index)
 {
-       //qDebug() << "LogWindow::slotDoubleClickLog: Row: " << QString::number(index.row()) << "Column: " << QString::number(index.column());
+    //qDebug() << Q_FUNC_INFO << " - Start Row: " << QString::number(index.row()) << "Column: " << QString::number(index.column());
 
     int row = index.row();
     //qsoToEdit((logModel->index(row, 0)).data(0).toInt());
     int qsoID = ((logModel->index(row, Qt::DisplayRole)).data(0)).toInt();
 
-       //qDebug() << "LogWindow::slotDoubleClickLog: n: " << QString::number (logModel->data(index, Qt::DisplayRole).toInt());
-       //qDebug() << "LogWindow::slotDoubleClickLog: emitted: " << QString::number (((logModel->index(row, Qt::DisplayRole)).data(0)).toInt());
+        //qDebug() << "LogWindow::slotDoubleClickLog: n: " << QString::number (logModel->data(index, Qt::DisplayRole).toInt());
+        //qDebug() << "LogWindow::slotDoubleClickLog: emitted: " << QString::number (((logModel->index(row, Qt::DisplayRole)).data(0)).toInt());
 
     emit actionQSODoubleClicked(qsoID);
     //qsoToEdit((logModel->index(row, 0)).data(0).toInt());
@@ -323,68 +363,70 @@ void LogWindow::slotDoubleClickLog(const QModelIndex & index)
     //TODO: To be added to the logWindow and create an action that emist the QSO id to be edited
 
     logModel->select();
+    //qDebug() << Q_FUNC_INFO << " - END";
 }
 
 bool LogWindow::isQSLReceived(const int _qsoId)
 {
-       //qDebug() << "LogWindow::isQSLReceived: " << QString::number(_qsoId);
+    //qDebug() << Q_FUNC_INFO << " - Start " << QString::number(_qsoId);
     return dataProxy->isQSOConfirmed(_qsoId, true, false); // We check just paper QSL
     //return dataProxy->isQSLReceived(_qsoId);
 }
 
 bool LogWindow::isQSLSent(const int _qsoId)
 {
-       //qDebug() << "LogWindow::isQSLSent: " << QString::number(_qsoId);
+    //qDebug() << Q_FUNC_INFO << " - Start: " << QString::number(_qsoId);
 
     return dataProxy->isQSLSent(_qsoId);
+    //qDebug() << Q_FUNC_INFO << " - END";
 }
 
 void LogWindow::showMenuRightButtonFromLogCreateActions()
 {
-   //qDebug() << "LogWindow::showMenuRightButtonFromLogCreateActions";
+    //qDebug() << Q_FUNC_INFO << " - Start";
 
     delQSOFromLogAct = new QAction(tr("&Delete"), this);
-    delQSOFromLogAct->setShortcut(Qt::CTRL + Qt::Key_D);
+    delQSOFromLogAct->setShortcut(Qt::CTRL | Qt::Key_D);
     delQSOFromLogAct->setStatusTip(tr("Delete a QSO"));
     connect(delQSOFromLogAct, SIGNAL(triggered()), this, SLOT(slotQsoDeleteFromLog()));
 
     qsoToEditFromLogAct = new QAction(tr("&Edit QSO"), this);
-    qsoToEditFromLogAct->setShortcut(Qt::CTRL + Qt::Key_E);
+    qsoToEditFromLogAct->setShortcut(Qt::CTRL | Qt::Key_E);
     qsoToEditFromLogAct->setStatusTip(tr("Edit this QSO"));
     connect(qsoToEditFromLogAct, SIGNAL(triggered()), this, SLOT(slotQSOToEditFromLog()));
 
     qslSentViaBureauFromLogAct = new QAction(tr("Via &bureau"), this);
-    qslSentViaBureauFromLogAct->setShortcut(Qt::CTRL + Qt::Key_B);
+    qslSentViaBureauFromLogAct->setShortcut(Qt::CTRL | Qt::Key_B);
     qslSentViaBureauFromLogAct->setStatusTip(tr("Send this QSL via bureau"));
     connect(qslSentViaBureauFromLogAct, SIGNAL(triggered()), this, SLOT( slotQSLSentViaBureauFromLog() ));
 
     qslSentViaDirectFromLogAct = new QAction(tr("D&irect"), this);
-    qslSentViaDirectFromLogAct->setShortcut(Qt::CTRL + Qt::Key_I);
+    qslSentViaDirectFromLogAct->setShortcut(Qt::CTRL | Qt::Key_I);
     qslSentViaDirectFromLogAct->setStatusTip(tr("Send this QSL via direct"));
     connect(qslSentViaDirectFromLogAct, SIGNAL(triggered()), this, SLOT( slotQSLSentViaDirectFromLog()   ));
 
     qslRecViaBureauFromLogAct = new QAction(tr("Via bureau"), this);
-    qslRecViaBureauFromLogAct->setShortcut(Qt::CTRL + Qt::Key_R);
+    qslRecViaBureauFromLogAct->setShortcut(Qt::CTRL | Qt::Key_R);
     qslRecViaBureauFromLogAct->setStatusTip(tr("QSL &received via bureau"));
     connect(qslRecViaBureauFromLogAct, SIGNAL(triggered()), this, SLOT( slotQSLRecViaBureauFromLog() ));
 
     qslRecViaDirectFromLogAct = new QAction(tr("Direct"), this);
-    qslRecViaDirectFromLogAct->setShortcut(Qt::CTRL + Qt::Key_T);
+    qslRecViaDirectFromLogAct->setShortcut(Qt::CTRL | Qt::Key_T);
     qslRecViaDirectFromLogAct->setStatusTip(tr("QSL received via direc&t"));
     connect(qslRecViaDirectFromLogAct, SIGNAL(triggered()), this, SLOT( slotQSLRecViaDirectFromLog() ));
 
     checkQRZCOMFromLogAct = new QAction(tr("Check in QRZ.com"), this);
-    checkQRZCOMFromLogAct->setShortcut(Qt::CTRL + Qt::Key_Q);
+    checkQRZCOMFromLogAct->setShortcut(Qt::CTRL | Qt::Key_Q);
     checkQRZCOMFromLogAct->setStatusTip(tr("Check this callsign in QRZ.com"));
     connect(checkQRZCOMFromLogAct, SIGNAL(triggered()), this, SLOT( slotCheckQRZCom() ));
 
     checkDXHeatFromLogAct = new QAction(tr("Check in DXHeat.com"), this);
-    checkDXHeatFromLogAct->setShortcut(Qt::CTRL + Qt::Key_Q);
+    checkDXHeatFromLogAct->setShortcut(Qt::CTRL | Qt::Key_Q);
     checkDXHeatFromLogAct->setStatusTip(tr("Check this callsign in DXHeat.com"));
     connect(checkDXHeatFromLogAct, SIGNAL(triggered()), this, SLOT( slotCheckDXHeatCom() ));
 
     multipleDelQSOsFromLogAct = new QAction(tr("Delete selected QSOs"), this);
-    //multipleDelQSOsFromLogAct->setShortcut(Qt::CTRL + Qt::Key_D);
+    //multipleDelQSOsFromLogAct->setShortcut(Qt::CTRL | Qt::Key_D);
     multipleDelQSOsFromLogAct->setStatusTip(tr("Delete the selected QSOs"));
     connect(multipleDelQSOsFromLogAct, SIGNAL(triggered()), this, SLOT(slotQSOsDeleteFromLog()));
 
@@ -432,46 +474,53 @@ void LogWindow::showMenuRightButtonFromLogCreateActions()
    multipleSelectAll = new QAction(tr("Select all"), this);
    multipleSelectAll->setStatusTip(tr("Select all the QSOs"));
    connect(multipleSelectAll, SIGNAL(triggered()), this, SLOT( slotQSOsSelectAll() ));
+   //qDebug() << Q_FUNC_INFO << " - END";
 }
 
 void LogWindow::slotQSOsSelectAll()
 {
+   //qDebug() << Q_FUNC_INFO << " - Start";
     logView->selectAll();
+   //qDebug() << Q_FUNC_INFO << " - END";
 }
 
 void LogWindow::slotQSOsDeselectAll()
 {
+    //qDebug() << Q_FUNC_INFO << " - Start";
     logView->selectionModel()->clearSelection();
+    //qDebug() << Q_FUNC_INFO << " - END";
 }
 
 void LogWindow::slotQSLSentViaBureauFromLog()
 {
-      //qDebug() << "LogWindow::slotQSLSentViaBureauFromLog: " << (qslSentViaBureauFromLogAct->data()).toString() << " - Id = " << QString::number( ((logModel->index( ( (qslSentViaBureauFromLogAct->data()).toInt()  ) , 0)).data(0).toInt()) );
+    //qDebug() << Q_FUNC_INFO << " - Start: " << (qslSentViaBureauFromLogAct->data()).toString() << " - Id = " << QString::number( ((logModel->index( ( (qslSentViaBureauFromLogAct->data()).toInt()  ) , 0)).data(0).toInt()) );
     int _qsoId = ((logModel->index( ( (qslSentViaBureauFromLogAct->data()).toInt()  ) , 0)).data(0).toInt());
     qslSentViaBureau(_qsoId);
+    //qDebug() << Q_FUNC_INFO << " - END";
 }
 
 void LogWindow::slotQSLSentViaDirectFromLog()
 {
-       //qDebug() << "LogWindow::slotQSLSentViaDirectFromLog: " << (qslSentViaDirectFromLogAct->data()).toString() << " - Id = " << QString::number( ((logModel->index( ( (qslSentViaDirectFromLogAct->data()).toInt()  ) , 0)).data(0).toInt()) );
+    //qDebug() << Q_FUNC_INFO << " - Start: " << (qslSentViaDirectFromLogAct->data()).toString() << " - Id = " << QString::number( ((logModel->index( ( (qslSentViaDirectFromLogAct->data()).toInt()  ) , 0)).data(0).toInt()) );
      int _qsoId = ((logModel->index( ( (qslSentViaDirectFromLogAct->data()).toInt()  ) , 0)).data(0).toInt());
     //dataProxy->qslSentViaDirect(_qsoId, (QDateTime::currentDateTime()).toString("yyyy-MM-dd"));
     dataProxy->qslSentViaDirect(_qsoId, QDate::currentDate());
-
+     //qDebug() << Q_FUNC_INFO << " - END";
 }
 
 void LogWindow::slotQSLRecViaBureauFromLog()
 {
-      //qDebug() << "LogWindow::slotQSLRecViaBureauFromLog: ";
+    //qDebug() << Q_FUNC_INFO << " - Start";
 
     int _qsoId = ((logModel->index( ( (qslRecViaBureauFromLogAct->data()).toInt()  ) , 0)).data(0).toInt());
     qslRecViaBureau(_qsoId);
+    //qDebug() << Q_FUNC_INFO << " - END";
     //TODO: To be added to the logWindow and create an action that emist the QSO id
 }
 
 void LogWindow::slotQSLRecViaDirectFromLog()
 {
-       //qDebug() << "LogWindow::slotQSLRecViaDirectFromLog: " << (qslRecViaDirectFromLogAct->data()).toString() << " - Id = " << QString::number( ((logModel->index( ( (qslRecViaDirectFromLogAct->data()).toInt()  ) , 0)).data(0).toInt()) );
+    //qDebug() << Q_FUNC_INFO << " - Start: " << (qslRecViaDirectFromLogAct->data()).toString() << " - Id = " << QString::number( ((logModel->index( ( (qslRecViaDirectFromLogAct->data()).toInt()  ) , 0)).data(0).toInt()) );
     int _qsoId = ((logModel->index( ( (qslRecViaDirectFromLogAct->data()).toInt()  ) , 0)).data(0).toInt());
     qslRecViaDirect(_qsoId);
     // Mark Sent, Bureau, date, update log.
@@ -480,7 +529,7 @@ void LogWindow::slotQSLRecViaDirectFromLog()
 
 void LogWindow::slotQSOToEditFromLog()
 {
-       //qDebug() << "slotQSOToEditFromLog: " << (qsoToEditFromLogAct->data()).toString();
+    //qDebug() << Q_FUNC_INFO << " - Start: " << (qsoToEditFromLogAct->data()).toString();
 
     //qsoToEdit((logModel->index((qsoToEditFromLogAct->data()).toInt(), 0)).data(0).toInt());
     int QSOid = ((logModel->index((qsoToEditFromLogAct->data()).toInt(), 0)).data(0)).toInt();
@@ -493,6 +542,7 @@ void LogWindow::slotQSOToEditFromLog()
     //int row = index.row();
     //qsoToEdit((logModel->index(row, 0)).data(0).toInt());
     emit actionQSODoubleClicked(QSOid);
+    //qDebug() << Q_FUNC_INFO << " - END";
 
 
 
@@ -501,14 +551,15 @@ void LogWindow::slotQSOToEditFromLog()
 
 void LogWindow::deleteQSO(const int _qsoId)
 {
-   //qDebug() << "LogWindow::deleteQSO " << QString::number(_qsoId);
+    //qDebug() << Q_FUNC_INFO << " - Start: " << QString::number(_qsoId);
     emit actionDeleteQSO(_qsoId);
+    //qDebug() << Q_FUNC_INFO << " - END";
 }
 
 /*
 void LogWindow::deleteQSO(const int _qsoID)
 {
-       //qDebug() << "LogWindow::deleteQSO: " << QString::number(_qsoID);
+        //qDebug() << "LogWindow::deleteQSO: " << QString::number(_qsoID);
 
 
 
@@ -528,16 +579,16 @@ void LogWindow::deleteQSO(const int _qsoID)
 */
 void LogWindow::slotQsoDeleteFromLog()
 {
-      //qDebug() << "LogWindow::slotQsoDeleteFromLog: " << (delQSOFromLogAct->data()).toString();
+    //qDebug() << Q_FUNC_INFO << " - Start: " << (delQSOFromLogAct->data()).toString();
     //TODO: To be added to the logWindow and create an action that emist the QSO id
 
     int QSOid = ((logModel->index((delQSOFromLogAct->data()).toInt(), 0)).data(0)).toInt();
     deleteQSO(QSOid);
-      //qDebug() << "LogWindow::slotQsoDeleteFromLog (id): " << QString::number(QSOid);
+       //qDebug() << "LogWindow::slotQsoDeleteFromLog (id): " << QString::number(QSOid);
     /*
     switch (ret) {
       case QMessageBox::Yes:
-          //qDebug() << "LogWindow::slotQsoDeleteFromLog (id): -1";
+           //qDebug() << "LogWindow::slotQsoDeleteFromLog (id): -1";
         deleteQSO(QSOid);
 
           break;
@@ -549,11 +600,12 @@ void LogWindow::slotQsoDeleteFromLog()
           break;
     }
     */
+       //qDebug() << Q_FUNC_INFO << " - END";
 }
 
 void LogWindow::slotQSOsDeleteFromLog()
 {
-    //qDebug() << "LogWindow::slotQSOsDeleteFromLog";
+    //qDebug() << Q_FUNC_INFO << " - Start";
     QItemSelectionModel *select = logView->selectionModel();
     QList<int> qsos;
     qsos.clear();
@@ -563,19 +615,20 @@ void LogWindow::slotQSOsDeleteFromLog()
         foreach (QModelIndex index, list)
         {
             qsos.append(index.data(0).toInt());
-            //qDebug() << "LogWindow::slotshowRighButtonFromLog: " << QString::number(index.row()) ;
-            //qDebug() << "LogWindow::slotshowRighButtonFromLog: " << QString::number(index.data(0).toInt()) ;
+             //qDebug() << "LogWindow::slotshowRighButtonFromLog: " << QString::number(index.row()) ;
+             //qDebug() << "LogWindow::slotshowRighButtonFromLog: " << QString::number(index.data(0).toInt()) ;
         }
     }
     if (qsos.length()>0)
     {
         emit deleteTheseQSOs(qsos);
     }
+    //qDebug() << Q_FUNC_INFO << " - END";
 }
 
 void LogWindow::slotQSOsExportFromLog()
 {
-   //qDebug() << "LogWindow::slotQSOsExportFromLog";
+    //qDebug() << Q_FUNC_INFO << " - Start";
     QItemSelectionModel *select = logView->selectionModel();
     QList<int> qsos;
     qsos.clear();
@@ -585,31 +638,31 @@ void LogWindow::slotQSOsExportFromLog()
         foreach (QModelIndex index, list)
         {
             qsos.append(index.data(0).toInt());
-           //qDebug() << "LogWindow::slotQSOsExportFromLog: " << QString::number(index.row()) ;
-           //qDebug() << "LogWindow::slotQSOsExportFromLog: " << QString::number(index.data(0).toInt()) ;
+            //qDebug() << "LogWindow::slotQSOsExportFromLog: " << QString::number(index.row()) ;
+            //qDebug() << "LogWindow::slotQSOsExportFromLog: " << QString::number(index.data(0).toInt()) ;
         }
     }
     if (qsos.length()>0)
     {
         emit exportToADIFTheseQSOs(qsos);
     }
-   //qDebug() << "LogWindow::slotQSOsExportFromLog - END - " << QString::number(qsos.length());
+    //qDebug() << "LogWindow::slotQSOsExportFromLog - END - " << QString::number(qsos.length());
 }
 
 
 void LogWindow::slotQSOsUploadToLoTWFromLog()
 {
-    //qDebug() << "LogWindow::slotQSOsUploadToLoTWFromLog - TO BE IMPLEMENTED";
+    //qDebug() << Q_FUNC_INFO << " - Start - TO BE IMPLEMENTED";
 }
 
 void LogWindow::slotQSOsUploadToClubLogFromLog()
 {
-    //qDebug() << "LogWindow::slotQSOsUploadToClubLogFromLog - TO BE IMPLEMENTED";
+    //qDebug() << Q_FUNC_INFO << " - Start - TO BE IMPLEMENTED";
 }
 
 void LogWindow::slotQSOsQRZUploadFromLog()
 {
-   //qDebug() << "LogWindow::slotQSOsQRZUploadFromLog - TO BE IMPLEMENTED";
+    //qDebug() << Q_FUNC_INFO << " - Start - TO BE IMPLEMENTED";
     QItemSelectionModel *select = logView->selectionModel();
     QList<int> qsos;
     qsos.clear();
@@ -619,67 +672,70 @@ void LogWindow::slotQSOsQRZUploadFromLog()
         foreach (QModelIndex index, list)
         {
             qsos.append(index.data(0).toInt());
-            //qDebug() << "LogWindow::slotQSOsQRZUploadFromLog: " << QString::number(index.row()) ;
-            //qDebug() << "LogWindow::slotQSOsQRZUploadFromLog: " << QString::number(index.data(0).toInt()) ;
+            //qDebug() << Q_FUNC_INFO << " : " << QString::number(index.row()) ;
+            //qDebug() << Q_FUNC_INFO << " : " << QString::number(index.data(0).toInt()) ;
         }
     }
     if (qsos.length()>0)
     {
         emit uploadToQRZcomTheseQSOs(qsos);
     }
+    //qDebug() << Q_FUNC_INFO << " - END";
 }
 
 void LogWindow::slotQSOsUploadToEQSLFromLog()
 {
-    //qDebug() << "LogWindow::slotQSOsUploadToEQSLFromLog - TO BE IMPLEMENTED";
+    //qDebug() << Q_FUNC_INFO << " - Start - TO BE IMPLEMENTED";
 }
 
 void LogWindow::slotMultipleQSLSentViaBureauFromLog()
 {
-    //qDebug() << "LogWindow::slotMultipleQSLSentViaBureauFromLog - TO BE IMPLEMENTED";
+    //qDebug() << Q_FUNC_INFO << " - Start - TO BE IMPLEMENTED";
 }
 
 void LogWindow::slotMultipleQSLSentViaDirectFromLog()
 {
-    //qDebug() << "LogWindow::slotMultipleQSLSentViaDirectFromLog - TO BE IMPLEMENTED";
+    //qDebug() << Q_FUNC_INFO << " - Start - TO BE IMPLEMENTED";
 }
 
 void LogWindow::slotMultipleQSLRecViaBureauFromLog()
 {
-    //qDebug() << "LogWindow::slotMultipleQSLRecViaBureauFromLog - TO BE IMPLEMENTED";
+    //qDebug() << Q_FUNC_INFO << " - Start - TO BE IMPLEMENTED";
 }
 
 void LogWindow::slotMultipleQSLRecViaDirectFromLog()
 {
-    //qDebug() << "LogWindow::slotMultipleQSLRecViaDirectFromLog - TO BE IMPLEMENTED";
+    //qDebug() << Q_FUNC_INFO << " - Start - TO BE IMPLEMENTED";
 }
 
 
 void LogWindow::qslSentViaBureau(const int _qsoId)
 {
-       //qDebug() << "LogWindow::qslSentViaBureau: " << QString::number(_qsoId)yyyy-MM-dd
+    //qDebug() << Q_FUNC_INFO << " - Start: " << QString::number(_qsoId);
     dataProxy->qslSentViaBureau(_qsoId, QDate::currentDate());
 }
 
 void LogWindow::qslRecViaBureau(const int _qsoId)
 {
-   //    //qDebug() << "LogWyyyy-MM-ddRecViaBureau: " << QString::number(_qsoIyyyy-MM-dd<< (dateTime->currentDateTime()).toString("yyyy/MM/dd");
+    //qDebug() << Q_FUNC_INFO << " - Start: " << QString::number(_qsoId);
     dataProxy->qslRecViaBureau(_qsoId, QDate::currentDate(), false);
-    awards->setAwards(_qsoId);   //Update the Award status
+    awards->setAwards();   //Update the Award status
 
     refresh();
     emit updateAwards();
+    //qDebug() << Q_FUNC_INFO << " - END";
 }
 
 
 void LogWindow::qslRecViaDirect(const int _qsoId)
 {
-       //qDebug() << "LogWindow::qslRecViaDirect: " << QString::number(_qsoId)yyyy-MM-dd
+    //qDebug() << Q_FUNC_INFO << " - Start: " << QString::number(_qsoId);
     dataProxy->qslRecViaDirect(_qsoId, QDate::currentDate(), false);
-    awards->setAwards(_qsoId);
+    awards->setAwards();
 
     refresh();
     emit updateAwards();
+    //qDebug() << Q_FUNC_INFO << " - END";
 }
 
 
@@ -690,22 +746,57 @@ void LogWindow::slotQueryErrorManagement(QString functionFailed, QString errorCo
 
 void LogWindow::slotCheckQRZCom()
 {
+    //qDebug() << Q_FUNC_INFO << " - Start";
     QString _qrz = ((logModel->index( ( (qslRecViaDirectFromLogAct->data()).toInt()  ) , 2)).data(Qt::DisplayRole).toString());
     //int _qsoId = ((logModel->index( ( (qslRecViaDirectFromLogAct->data()).toInt()  ) , 0)).data(0).toInt());
     //QString _qrz = dataProxy->getCallFromId(_qsoId);
-      //qDebug() << "LogWindow::sloTCheckQRZCom: " << _qrz;
+    //qDebug() << Q_FUNC_INFO << " : " << _qrz;
     util->openQrzcom (_qrz);
     //QString url = "https://www.qrz.com/db/" + _qrz;
     //QDesktopServices::openUrl(QUrl(url));
+    //qDebug() << Q_FUNC_INFO << " - END";
 }
 
 void LogWindow::slotCheckDXHeatCom()
 {
+    //qDebug() << Q_FUNC_INFO << " - Start";
     QString _qrz = ((logModel->index( ( (qslRecViaDirectFromLogAct->data()).toInt()  ) , 2)).data(Qt::DisplayRole).toString());
     //int _qsoId = ((logModel->index( ( (qslRecViaDirectFromLogAct->data()).toInt()  ) , 0)).data(0).toInt());
     //QString _qrz = dataProxy->getCallFromId(_qsoId);
-      //qDebug() << "LogWindow::slotCheckDXHeatCom(): " << _qrz;
+    //qDebug() << Q_FUNC_INFO << " : " << _qrz;
     QString url = "https://www.dxheat.com/db/" + _qrz;
     QDesktopServices::openUrl(QUrl(url));
+    //qDebug() << Q_FUNC_INFO << " - END";
 }
 
+void LogWindow::slotOnSectionMoved(int logicalIndex, int oldVisualIndex, int newVisualIndex)
+{
+    Q_UNUSED(logicalIndex);
+    Q_UNUSED(oldVisualIndex);
+    Q_UNUSED(newVisualIndex);
+
+    // Get the current column order
+    QStringList header = getOrderedVisibleHeaders();
+
+    QSettings settings(util->getCfgFile (), QSettings::IniFormat);
+    settings.beginGroup("LogWindow");
+    settings.setValue("ColumnOrder", QVariant::fromValue(header));
+    settings.endGroup();
+}
+
+QStringList LogWindow::getOrderedVisibleHeaders() const
+{
+    QStringList orderedHeaders;
+    QHeaderView* headerView = logView->horizontalHeader();
+    for (int i = 0; i < headerView->count(); ++i)
+    {
+        int logicalIndex = headerView->logicalIndex(i);
+        if (!logView->isColumnHidden(logicalIndex))
+        {
+            QString header = logModel->headerData(logicalIndex, Qt::Horizontal).toString();
+
+            orderedHeaders.append(util->getLogColumnDBName(header));
+        }
+    }
+    return orderedHeaders;
+}
