@@ -29,7 +29,6 @@
 
 #include <QtWidgets>
 #include <QWidget>
-//#include <QSqlRelationalTableModel>
 #include <QTableView>
 #include <QAction>
 #include <QSqlQuery>
@@ -39,20 +38,15 @@
 #include "dataproxy_sqlite.h"
 #include "logmodel.h"
 #include "awards.h"
-//#include "dxccstatuswidget.h"
-//#include "elogclublog.h"
 #include "utilities.h"
-//#include "logviewsortfilterproxymodel.h"
-
-//class  LogViewSortFilterProxyModel;
-//class ItemDelegate;
 
 class LogWindow : public  QWidget
 {
     Q_OBJECT
+    friend class tst_LogWindow;
 
 public:
-    explicit LogWindow(DataProxy_SQLite *dp, QWidget *parent = nullptr);
+    LogWindow(Awards *awards, QWidget *parent = nullptr);
     ~LogWindow();
     void createlogPanel(const int _currentLog);
     void clear();
@@ -107,12 +101,13 @@ private slots:
     void slotMultipleQSLRecViaBureauFromLog();
     void slotMultipleQSLRecViaDirectFromLog();
     void slotQSOsQRZUploadFromLog();
+    void slotOnSectionMoved(int logicalIndex, int oldVisualIndex, int newVisualIndex);
 
 private:    
     void createUI();
     void createActionsCommon();
     void createActions();
-
+    void retoreColumsOrder();
     void deleteQSO(const int _qsoID);
     void rightButtonFromLogMenu(const int trow);
     void rightButtonMultipleFromLogMenu();
@@ -121,6 +116,7 @@ private:
 
     void setDefaultData();
     void setColumnsOfLog(const QStringList &_columns);
+    QStringList getOrderedVisibleHeaders() const;
 
 
     DataProxy_SQLite *dataProxy;
@@ -161,7 +157,6 @@ private:
 
     Utilities *util;
     QStringList columns;
-
    //LogViewSortFilterProxyModel *proxyModel;
    //bool sortingThroughProxyModel;
 };
