@@ -25,6 +25,7 @@
  *****************************************************************************/
 
 #include "lotwutilities.h"
+#include "callsign.h"
 #include <QCoreApplication>
 #include <QUrl>
 #include <QNetworkRequest>
@@ -40,9 +41,6 @@ LoTWUtilities::LoTWUtilities(const QString &_klogDir, const QString &_klogVersio
 #endif
     dataProxy = dp;
     calendar = new QCalendarWidget;
-    util = new Utilities(Q_FUNC_INFO);
-    util->setLongPrefixes(dataProxy->getLongPrefixes());
-    util->setSpecialCalls(dataProxy->getSpecialCallsigns());
 
     manager = new QNetworkAccessManager(this);
 
@@ -66,45 +64,44 @@ LoTWUtilities::LoTWUtilities(const QString &_klogDir, const QString &_klogVersio
 
     connect(calendar, SIGNAL(activated(QDate)), this, SLOT(slotCalendarDateSelected(QDate)));
 
-   //qDebug() << "LoTWUtilities::LoTWUtilities(): - END" ;
+   //qDebug() << Q_FUNC_INFO << ":  - END" ;
 }
 
 LoTWUtilities::~LoTWUtilities()
 {
-    delete(dataProxy);
-    delete(util);
     delete(file);
+    delete(pDialog);
+    delete(calendar);
     delete(manager);
-      //qDebug() << "LoTWUtilities::~LoTWUtilities" ;
+      //qDebug() << Q_FUNC_INFO << " - END" ;
 }
 
 void LoTWUtilities::slotCalendarDateSelected(const QDate _d)
 {
-   //qDebug() << "LoTWUtilities::slotCalendarDateSelected: " << _d.toString("yyyyMMdd") ;
+   //qDebug() << Q_FUNC_INFO << ": " << _d.toString("yyyyMMdd") ;
     firstDate = _d;
     startThefullDownload();
-
 }
 
 void LoTWUtilities::setFileName(const QString &_fn)
 {
-    //qDebug() << "LoTWUtilities::setFileName: " << _fn ;
+    //qDebug() << Q_FUNC_INFO << ":  " << _fn ;
     if (_fn.length()>0)
     {
         fileName = _fn;
     }
-    //qDebug() << "LoTWUtilities::setFileName - END"  ;
+    //qDebug() << Q_FUNC_INFO << ":  - END"  ;
 }
 
 QString LoTWUtilities::getFileName()
 {
-    //qDebug() << "LoTWUtilities::getFileName: " << fileName  ;
+    //qDebug() Q_FUNC_INFO << ":  " << fileName  ;
     return fileName;
 }
 
 bool LoTWUtilities::selectQuery(const int _queryId)
 {
-     //qDebug() << "LoTWUtilities::selectQuery: - Start: " << QString::number(_queryId);
+     //qDebug() << Q_FUNC_INFO << ":  - Start: " << QString::number(_queryId);
     bool savePassword = true;
     if (lotwPassword.length()<1)
     {
@@ -115,7 +112,7 @@ bool LoTWUtilities::selectQuery(const int _queryId)
                                                    tr("Please enter your LoTW password: "), QLineEdit::Password, "", &ok);
         if (!ok)
         {
-             //qDebug() << "LoTWUtilities::selectQuery: - END 1" <<  QT_ENDL;
+             //qDebug() << Q_FUNC_INFO << ":  - END 1" <<  QT_ENDL;
             return false;
         }
     }
@@ -139,52 +136,53 @@ bool LoTWUtilities::selectQuery(const int _queryId)
     }
     url = QUrl(lotwQuery);
 
-     //qDebug() << "LoTWUtilities::selectQuery: - END" <<  QT_ENDL;
+     //qDebug() << Q_FUNC_INFO << ":  - END" <<  QT_ENDL;
 
     return true;
 }
 
 bool LoTWUtilities::setStationCallSign(const QString &_call)
 {
-    //qDebug() << "LoTWUtilities::setStationCallSign: " << _call;
-    if (!util->isValidCall(_call))
+    //qDebug() << Q_FUNC_INFO << ":  " << _call;
+    Callsign callsign(_call);
+    if (!callsign.isValid())
     {
-        //qDebug() << "LoTWUtilities::setStationCallSign: FALSE 1" ;
+        //qDebug() << Q_FUNC_INFO << ":  FALSE 1" ;
         return false;
     }
     if (((dataProxy->getStationCallSignsFromLog(-1)).contains(_call)))
     {
-        //qDebug() << "LoTWUtilities::setStationCallSign: TRUE" ;
+        //qDebug() << Q_FUNC_INFO << ":  TRUE" ;
         stationCallsign = _call;
         QDate date = dataProxy->getFirstQSODateFromCall(stationCallsign);
-        //qDebug() << "LoTWUtilities::setStationCallSign: Date: " << startDate ;
+        //qDebug() << Q_FUNC_INFO << ":  Date: " << startDate ;
         if (date.isValid())
         {
             startDate = date.toString("yyyyMMdd");
-             //qDebug() << "LoTWUtilities::setStationCallSign: StartDate" << startDate ;
+             //qDebug() << Q_FUNC_INFO << ":  StartDate" << startDate ;
         }
         else
         {
             startDate.clear();
-             //qDebug() << "LoTWUtilities::setStationCallSign: StartDate not valid Date";
+             //qDebug() << Q_FUNC_INFO << ":  StartDate not valid Date";
              //qDebug() << Q_FUNC_INFO << "False 2 - END";
             return false;
         }
 
-        //qDebug() << "LoTWUtilities::setStationCallSign: startDate: " << startDate ;
+        //qDebug() << Q_FUNC_INFO << ":  startDate: " << startDate ;
         //qDebug() << Q_FUNC_INFO << "True 1 - END";
         return true;
     }
     else if (dataProxy->getHowManyQSOInLog(-1) <1)
     {
-        //qDebug() << "LoTWUtilities::setStationCallSign:TRUE Empty log" ;
+        //qDebug() << Q_FUNC_INFO << ": TRUE Empty log" ;
         stationCallsign = _call;
         //qDebug() << Q_FUNC_INFO << "True 2 - END";
         return true;
     }
     else
     {
-        //qDebug() << "LoTWUtilities::setStationCallSign: Not a single QSO in the log with that StationCallsign: " << stationCallsign ;
+        //qDebug() << Q_FUNC_INFO << ":  Not a single QSO in the log with that StationCallsign: " << stationCallsign ;
         QMessageBox msgBox;
         msgBox.setIcon(QMessageBox::Question);
         msgBox.setWindowTitle(tr("KLog - LoTW Station callsign"));
@@ -203,7 +201,7 @@ bool LoTWUtilities::setStationCallSign(const QString &_call)
         }
         else
         {
-            //qDebug() << "LoTWUtilities::setStationCallSign: FALSE 2" ;
+            //qDebug() << Q_FUNC_INFO << ":  FALSE 2" ;
             //qDebug() << Q_FUNC_INFO << "FALSE 3 - END";
             return false;
         }
@@ -212,7 +210,7 @@ bool LoTWUtilities::setStationCallSign(const QString &_call)
 
 void LoTWUtilities::startRequest(QUrl url)
 {
-    //qDebug() << "LoTWUtilities::startRequest: " << url.toString() ;
+    //qDebug() << Q_FUNC_INFO << ":  " << url.toString() ;
     QByteArray agent = QString("KLog-" + klogVersion).toUtf8();
     QNetworkRequest request;
     request.setUrl(url);
@@ -220,7 +218,7 @@ void LoTWUtilities::startRequest(QUrl url)
     //request.setRawHeader("User-Agent", agent);
     //reply = manager->get(QNetworkRequest(url));
     reply = manager->get(request);
-    //qDebug() << "LoTWUtilities::startRequest - 10" ;
+    //qDebug() << Q_FUNC_INFO << ":  - 10" ;
     // Whenever more data is received from the network,
     // this readyRead() signal is emitted
     connect(reply, SIGNAL(readyRead()), this, SLOT(slotReadyRead()));
@@ -231,24 +229,24 @@ void LoTWUtilities::startRequest(QUrl url)
     // After this signal is emitted,
     // there will be no more updates to the reply's data or metadata.
     connect(reply, SIGNAL(finished()), this, SLOT(slotFinished()));
-    //qDebug() << "LoTWUtilities::startRequest: - END";
+    //qDebug() << Q_FUNC_INFO << ":  - END";
 }
 
 int LoTWUtilities::download()
 {
-    //qDebug() << "LoTWUtilities::download - Start";
+    //qDebug() << Q_FUNC_INFO << ": - Start";
     if (!selectQuery(-1))
     {
-        //qDebug() << "LoTWUtilities::download - END-1";
+        //qDebug() << Q_FUNC_INFO << ":  - END-1";
         return -1;
     }
-    //qDebug() << "LoTWUtilities::download: - 10";
+    //qDebug() << Q_FUNC_INFO << ":  - 10";
     QFileInfo fileInfo(url.path());
 
-    //qDebug() << "LoTWUtilities::download: - 11";
+    //qDebug() << Q_FUNC_INFO << ":  - 11";
     if (QFile::exists(fileName))
     {
-        //qDebug() << "LoTWUtilities::download: - 12";
+        //qDebug() << Q_FUNC_INFO << ":  - 12";
         QMessageBox msgBox;
         msgBox.setIcon(QMessageBox::Question);
         msgBox.setWindowTitle(tr("KLog - LoTW File already exists"));
@@ -258,21 +256,21 @@ int LoTWUtilities::download()
         msgBox.setStandardButtons(QMessageBox::Yes|QMessageBox::No);
         msgBox.setDefaultButton(QMessageBox::Yes);
         int ret = msgBox.exec();
-        //qDebug() << "LoTWUtilities::download: - 13";
+        //qDebug() << Q_FUNC_INFO << ":  - 13";
         if (ret == QMessageBox::No)
         {
-             //qDebug() << "LoTWUtilities::download - END- 2";
+             //qDebug() <<Q_FUNC_INFO << ":  - END- 2";
             return -2;
         }
       }
-        //qDebug() << "LoTWUtilities::download: - 20 Filename: -" << fileName << "-";
+        //qDebug() << Q_FUNC_INFO << ":  - 20 Filename: -" << fileName << "-";
         if (!file->isOpen())
         {
-            //qDebug() << "LoTWUtilities::download: - 21 Filename: -";
+            //qDebug() << Q_FUNC_INFO << ":  - 21 Filename: -";
             file->setFileName(fileName);
-            //qDebug() << "LoTWUtilities::download: - 22 Filename: -";
+            //qDebug() << Q_FUNC_INFO << ":  - 22 Filename: -";
         }
-        //qDebug() << "LoTWUtilities::download: - 23 Filename: -";
+        //qDebug() << Q_FUNC_INFO << ":  - 23 Filename: -";
 
       if (!file->open(QIODevice::WriteOnly)) /* Flawfinder: ignore */
       {
@@ -288,49 +286,48 @@ int LoTWUtilities::download()
           //file->close();
           //delete file;
           //file = nullptr;
-           //qDebug() << "LoTWUtilities::download - END - 3";
+           //qDebug() << Q_FUNC_INFO << ":  - END - 3";
           return -3;
       }
-    //qDebug() << "LoTWUtilities::download: - 30";
+    //qDebug() << Q_FUNC_INFO << ":  - 30";
       // used for progressDialog
       // This will be set true when canceled from progress dialog
     downloadAborted = false;
-    //qDebug() << "LoTWUtilities::download: - 31";
+    //qDebug() << Q_FUNC_INFO << ":  - 31";
     //progressDialog = new QProgressDialog(nullptr);
-    //qDebug() << "LoTWUtilities::download: - 40";
+    //qDebug() << Q_FUNC_INFO << ":  - 40";
     pDialog->setLabelText(tr("Downloading data to file: %1.").arg(fileName));
-    //qDebug() << "LoTWUtilities::download: - 41";
+    //qDebug() << Q_FUNC_INFO << ":  - 41";
     pDialog->setWindowTitle(tr("KLog - LoTW download"));
-    //qDebug() << "LoTWUtilities::download: - 42";
+    //qDebug() << Q_FUNC_INFO << ":  - 42";
     pDialog->setWindowModality(Qt::WindowModal);
-    //qDebug() << "LoTWUtilities::download: - 43";
+    //qDebug() << Q_FUNC_INFO << ":  - 43";
     pDialog->reset();
-    //qDebug() << "LoTWUtilities::download: - 44";
+    //qDebug() << Q_FUNC_INFO << ":  - 44";
     pDialog->setRange(0, 0);
-    //qDebug() << "LoTWUtilities::download: - 45";
+    //qDebug() << Q_FUNC_INFO << ":  - 45";
     pDialog->setMinimumDuration(0);
-    //qDebug() << "LoTWUtilities::download: - 46";
+    //qDebug() << Q_FUNC_INFO << ":  - 46";
     pDialog->show();
-    //qDebug() << "LoTWUtilities::download: - 47";
+    //qDebug() << Q_FUNC_INFO << ":  - 47";
 
     connect(pDialog, SIGNAL(canceled()), this, SLOT(slotCancelDownload()));
-    //qDebug() << "LoTWUtilities::download: - 50";
+    //qDebug() << Q_FUNC_INFO << ":  - 50";
 
     startRequest(url);
      //qDebug() << "LoTWUtilities::download - END";
     return 1;
-
 }
 
 int LoTWUtilities::fullDownload()
 {
-   //qDebug() << "LoTWUtilities::fullDownload";
+   //qDebug() << Q_FUNC_INFO << " - Start";
     QDate date = dataProxy->getFirstQSODateFromCall(stationCallsign);
-   //qDebug() << "LoTWUtilities::fullDownload: Date: " << startDate ;
+   //qDebug() << Q_FUNC_INFO << ":  Date: " << startDate ;
     if (date.isValid())
     {
         startDate = date.toString("yyyyMMdd");
-        //qDebug() << "LoTWUtilities::fullDownload: StartDate" << startDate ;
+        //qDebug() << Q_FUNC_INFO << ":  StartDate" << startDate ;
     }
     QMessageBox msgBox;
     msgBox.setIcon(QMessageBox::Question);
@@ -343,7 +340,7 @@ int LoTWUtilities::fullDownload()
     int ret = msgBox.exec();
     if (ret == QMessageBox::Yes)
     {
-         //qDebug() << "LoTWUtilities::fulldownload - Yes";
+         //qDebug() << Q_FUNC_INFO << ":  - Yes";
           firstDate = date;
           startThefullDownload();
           return 1;
@@ -353,14 +350,13 @@ int LoTWUtilities::fullDownload()
     calendar->setGridVisible(true);
     calendar->setMaximumDate(QDate::currentDate());
     calendar->show();
-   //qDebug() << "LoTWUtilities::fullDownload - END";
+   //qDebug() << Q_FUNC_INFO << ":  - END";
     return 2;
 }
 
 int LoTWUtilities::startThefullDownload()
 {
-
-   //qDebug() << "LoTWUtilities::startThefulldownload - Start";
+   //qDebug() << Q_FUNC_INFO << ":  - Start";
     if (calendar->isVisible())
     {
         calendar->close();
@@ -368,16 +364,16 @@ int LoTWUtilities::startThefullDownload()
 
     if (!selectQuery(2))
     {
-       //qDebug() << "LoTWUtilities::startThefulldownload - END-1";
+       //qDebug() << Q_FUNC_INFO << ":  - END-1";
         return -1;
     }
-   //qDebug() << "LoTWUtilities::startThefulldownload: - 10";
+   //qDebug() << Q_FUNC_INFO << ": : - 10";
     QFileInfo fileInfo(url.path());
 
-   //qDebug() << "LoTWUtilities::startThefulldownload: - 11";
+   //qDebug() << Q_FUNC_INFO << ": : - 11";
    if (QFile::exists(fileName))
    {
-       //qDebug() << "LoTWUtilities::startThefulldownload: - 12";
+       //qDebug() << Q_FUNC_INFO << ": : - 12";
        QMessageBox msgBox;
        msgBox.setIcon(QMessageBox::Question);
        msgBox.setWindowTitle(tr("KLog - LoTW File already exists"));
@@ -387,21 +383,21 @@ int LoTWUtilities::startThefullDownload()
        msgBox.setStandardButtons(QMessageBox::Yes|QMessageBox::No);
        msgBox.setDefaultButton(QMessageBox::Yes);
        int ret = msgBox.exec();
-       //qDebug() << "LoTWUtilities::startThefulldownload: - 13";
+       //qDebug() << Q_FUNC_INFO << ": : - 13";
        if (ret == QMessageBox::No)
        {
-            //qDebug() << "LoTWUtilities::startThefulldownload - END- 2";
+            //qDebug() << Q_FUNC_INFO << ":  - END- 2";
            return -2;
        }
      }
-       //qDebug() << "LoTWUtilities::startThefulldownload: - 20 Filename: -" << fileName << "-";
+       //qDebug() << Q_FUNC_INFO << ": : - 20 Filename: -" << fileName << "-";
        if (!file->isOpen())
        {
-           //qDebug() << "LoTWUtilities::startThefulldownload: - 21 Filename: -";
+           //qDebug() << Q_FUNC_INFO << ": : - 21 Filename: -";
            file->setFileName(fileName);
-           //qDebug() << "LoTWUtilities::startThefulldownload: - 22 Filename: -";
+           //qDebug() << Q_FUNC_INFO << ": : - 22 Filename: -";
        }
-       //qDebug() << "LoTWUtilities::startThefulldownload: - 23 Filename: -";
+       //qDebug() << Q_FUNC_INFO << ": : - 23 Filename: -";
 
      if (!file->open(QIODevice::WriteOnly)) /* Flawfinder: ignore */
      {
@@ -417,65 +413,65 @@ int LoTWUtilities::startThefullDownload()
          //file->close();
          //delete file;
          //file = nullptr;
-          //qDebug() << "LoTWUtilities::startThefulldownload - END - 3";
+          //qDebug() << Q_FUNC_INFO << ":  - END - 3";
          return -3;
      }
-   //qDebug() << "LoTWUtilities::startThefulldownload: - 30";
+   //qDebug() << Q_FUNC_INFO << ": : - 30";
      // used for progressDialog
      // This will be set true when canceled from progress dialog
    downloadAborted = false;
-   //qDebug() << "LoTWUtilities::startThefulldownload: - 31";
+   //qDebug() << Q_FUNC_INFO << ": : - 31";
    //progressDialog = new QProgressDialog(nullptr);
-   //qDebug() << "LoTWUtilities::startThefulldownload: - 40";
+   //qDebug() << Q_FUNC_INFO << ": : - 40";
    pDialog->setLabelText(tr("Downloading data to file: %1.").arg(fileName));
-   //qDebug() << "LoTWUtilities::startThefulldownload: - 41";
+   //qDebug() << Q_FUNC_INFO << ": : - 41";
    pDialog->setWindowTitle(tr("KLog - LoTW download"));
-   //qDebug() << "LoTWUtilities::startThefulldownload: - 42";
+   //qDebug() << Q_FUNC_INFO << ": : - 42";
    pDialog->setWindowModality(Qt::WindowModal);
-   //qDebug() << "LoTWUtilities::startThefulldownload: - 43";
+   //qDebug() << Q_FUNC_INFO << ": : - 43";
    pDialog->reset();
-   //qDebug() << "LoTWUtilities::startThefulldownload: - 44";
+   //qDebug() << Q_FUNC_INFO << ": : - 44";
    pDialog->setRange(0, 0);
-   //qDebug() << "LoTWUtilities::startThefulldownload: - 45";
+   //qDebug() << Q_FUNC_INFO << ": : - 45";
    pDialog->setMinimumDuration(0);
-   //qDebug() << "LoTWUtilities::startThefulldownload: - 46";
+   //qDebug() << Q_FUNC_INFO << ": : - 46";
    pDialog->show();
-   //qDebug() << "LoTWUtilities::startThefulldownload: - 47";
+   //qDebug() << Q_FUNC_INFO << ": : - 47";
 
    connect(pDialog, SIGNAL(canceled()), this, SLOT(slotCancelDownload()));
-   //qDebug() << "LoTWUtilities::startThefulldownload: - 50";
+   //qDebug() << Q_FUNC_INFO << ": : - 50";
 
    startRequest(url);
-    //qDebug() << "LoTWUtilities::startThefulldownload - END";
+    //qDebug() << Q_FUNC_INFO << ":  - END";
 
     return 1;
 }
 
 void LoTWUtilities::slotDownloadProgress(qint64 bytesRead) {
-    //qDebug() << "LoTWUtilities::slotDownloadProgress: " << QString::number(bytesRead);
+    //qDebug() << Q_FUNC_INFO << ": " << QString::number(bytesRead);
     if (downloadAborted)
     {
-         //qDebug() << "LoTWUtilities::slotDownloadProgress: CANCELLED";
+         //qDebug() << Q_FUNC_INFO << ":  CANCELLED";
         return;
     }
 
     pDialog->setValue(bytesRead);
-     //qDebug() << "LoTWUtilities::slotDownloadProgress - END ";
+     //qDebug() << Q_FUNC_INFO << ": - END ";
 }
 
 void LoTWUtilities::slotReadyRead()
 {
-    //qDebug() << "LoTWUtilities::slotReadyRead: " << reply->readLine();
+    //qDebug() << Q_FUNC_INFO << ":  " << reply->readLine();
     if (file)
     {
         file->write(reply->readAll());
     }
-    //qDebug() << "LoTWUtilities::slotReadyRead - END";
+    //qDebug() << Q_FUNC_INFO << ":  - END";
 }
 
 void LoTWUtilities::slotFinished()
 {
-    //qDebug() << "LoTWUtilities::slotFinished - Started";
+    //qDebug() << Q_FUNC_INFO << ":  - Started";
     // when canceled
      if (downloadAborted)
      {
@@ -489,21 +485,21 @@ void LoTWUtilities::slotFinished()
          //reply->deleteLater();
          pDialog->cancel();
          reply->close();
-         //qDebug() << "LoTWUtilities::slotFinished - END Canceled";
+         //qDebug() << Q_FUNC_INFO << ":  - END Canceled";
          return;
      }
-    //qDebug() << "LoTWUtilities::slotFinished - 10";
+    //qDebug() << Q_FUNC_INFO << ":  - 10";
      // download finished normally
     pDialog->cancel();
-    //qDebug() << "LoTWUtilities::slotFinished - 11";
+    //qDebug() << Q_FUNC_INFO << ":  - 11";
     file->flush();
-    //qDebug() << "LoTWUtilities::slotFinished - 12";
+    //qDebug() << Q_FUNC_INFO << ":  - 12";
     file->close();
-    //qDebug() << "LoTWUtilities::slotFinished - 13";
+    //qDebug() << Q_FUNC_INFO << ":  - 13";
 
      // get redirection url
      QVariant redirectionTarget = reply->attribute(QNetworkRequest::RedirectionTargetAttribute);
-     //qDebug() << "LoTWUtilities::slotFinished - 14";
+     //qDebug() << Q_FUNC_INFO << ":  - 14";
      if (reply->error())
      {
          file->remove();
@@ -520,7 +516,7 @@ void LoTWUtilities::slotFinished()
     }
     else if (!redirectionTarget.isNull())
     {
-         //qDebug() << "LoTWUtilities::slotFinished - Redirection";
+         //qDebug() << Q_FUNC_INFO << ":  - Redirection";
         QUrl newUrl = url.resolved(redirectionTarget.toUrl());
         QMessageBox msgBox;
         msgBox.setIcon(QMessageBox::Question);
@@ -538,13 +534,13 @@ void LoTWUtilities::slotFinished()
             file->open(QIODevice::WriteOnly); /* Flawfinder: ignore */
             file->resize(0);
             startRequest(url);
-             //qDebug() << "LoTWUtilities::slotFinished - END-1";
+             //qDebug() << Q_FUNC_INFO << ":  - END-1";
             return;
         }
      }
     else
     {
-        //qDebug() << "LoTWUtilities::slotFinished:  " ;
+        //qDebug() << Q_FUNC_INFO << ": :  " ;
     }
     //qDebug() << "LoTWUtilities::slotReadyRead - Going to parse ...";
     parseDownloadedFile(file->fileName());
@@ -553,45 +549,44 @@ void LoTWUtilities::slotFinished()
 
 void LoTWUtilities::slotCancelDownload()
 {
-     //qDebug() << "LoTWUtilities::slotCancelDownload - Start";
+     //qDebug() << Q_FUNC_INFO << ":  - Start";
     downloadAborted = true;
     reply->abort();
-     //qDebug() << "LoTWUtilities::slotCancelDownload - END";
+     //qDebug() << Q_FUNC_INFO << ":  - END";
 }
 
 void LoTWUtilities::setUser(const QString &_call)
 {
-     //qDebug() << "LoTWUtilities::setUser: " << _call;
+     //qDebug() << Q_FUNC_INFO << ":  " << _call;
     lotwUser = _call;
-     //qDebug() << "LoTWUtilities::setUser: END";
+     //qDebug() << Q_FUNC_INFO << ":  END";
 }
 
 void LoTWUtilities::setPass(const QString &_pass)
 {
-     //qDebug() << "LoTWUtilities::setPass: " << _pass;
+     //qDebug() << Q_FUNC_INFO << ":  " << _pass;
     lotwPassword = _pass;
-     //qDebug() << "LoTWUtilities::setPass: END";
+     //qDebug() << Q_FUNC_INFO << ": END";
 }
 
 bool LoTWUtilities::getIsReady()
 {
-     //qDebug() << "LoTWUtilities::getIsReady: user/station: -" << lotwUser <<"/" << stationCallsign << "-";
+     //qDebug() << Q_FUNC_INFO << ":  user/station: -" << lotwUser <<"/" << stationCallsign << "-";
     if ((lotwUser.length()>1) && (stationCallsign.length()>1))
     {
-         //qDebug() << "LoTWUtilities::getIsReady: true";
+         //qDebug() << Q_FUNC_INFO << ":  true";
         return true;
     }
     else
     {
-         //qDebug() << "LoTWUtilities::getIsReady: false";
+         //qDebug() << Q_FUNC_INFO << ":  false";
       return false;
     }
-
 }
 
 void LoTWUtilities::parseDownloadedFile(const QString &_fn)
 {
-    //qDebug() << "LoTWUtilities::parseDownloadedFile: " << _fn;
+    //qDebug() << Q_FUNC_INFO << ":  " << _fn;
     QString _fileName = _fn;
     QMessageBox msgBox;
     QString aux;
@@ -599,7 +594,7 @@ void LoTWUtilities::parseDownloadedFile(const QString &_fn)
     QFile file( _fileName );
     if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) /* Flawfinder: ignore */
     {
-        //qDebug() << "LoTWUtilities::parseDownloadedFile File not found" << _fileName;
+        //qDebug() << Q_FUNC_INFO << ":  File not found" << _fileName;
         msgBox.setIcon(QMessageBox::Warning);
         msgBox.setWindowTitle(tr("KLog - LoTW File not found"));
         msgBox.setText(tr("KLog can't find the downloaded file."));
@@ -609,7 +604,7 @@ void LoTWUtilities::parseDownloadedFile(const QString &_fn)
         msgBox.setStandardButtons(QMessageBox::Ok);
         msgBox.setDefaultButton(QMessageBox::Ok);
         msgBox.exec();
-        //qDebug() << "LoTWUtilities::parseDownloadedFile: END-1";
+        //qDebug() <<Q_FUNC_INFO << ":  END-1";
         return ;
     }
     else
@@ -626,20 +621,20 @@ void LoTWUtilities::parseDownloadedFile(const QString &_fn)
         {
             QByteArray line = file.readLine();
             QString lineU = line.toUpper();
-            //qDebug() << "LoTWUtilities::parseDownloadedFile: lineU: " << lineU;
+            //qDebug() << Q_FUNC_INFO << ":  lineU: " << lineU;
             if (lineU.contains("<EOH>"))
             {
-                 //qDebug() << "LoTWUtilities::parseDownloadedFile: EOH found";
+                 //qDebug() << Q_FUNC_INFO << ":  EOH found";
                 hasHeader = true;
             }
             //else if (lineU.contains("<PROGRAMID:4>LOTW"))
             //{
-            //     //qDebug() << "LoTWUtilities::parseDownloadedFile: ProgramID found";
+            //     //qDebug() << Q_FUNC_INFO << ":  ProgramID found";
             //    hasProgramID = true;
             //}
             //else if (lineU.contains(Lotw_owncall))
             //{
-            //     //qDebug() << "LoTWUtilities::parseDownloadedFile: OWNCALL found";
+            //     //qDebug() << Q_FUNC_INFO << ":  OWNCALL found";
             //    hasOwnCall = true;
             //}
             else if (lineU.contains("<APP_LOTW_NUMREC:"))
@@ -648,7 +643,7 @@ void LoTWUtilities::parseDownloadedFile(const QString &_fn)
                 data << lineU.split('>', QT_SKIP);
 
                 numQSO = (data.at(1)).toInt();
-                 //qDebug() << "LoTWUtilities::parseDownloadedFile: QSOs: " << QString::number(numQSO);
+                 //qDebug() << Q_FUNC_INFO << ":  QSOs: " << QString::number(numQSO);
             }
             else if (lineU.contains("<I>USERNAME/PASSWORD INCORRECT</I>"))
             {
@@ -658,8 +653,7 @@ void LoTWUtilities::parseDownloadedFile(const QString &_fn)
         // WE HAVE JUST FINISHED TO READ THE HEADER OR THE FILE, IF IT IS NOT AN ADIF
         if (!hasHeader || (numQSO<1))
         {
-
-             //qDebug() << "LoTWUtilities::parseDownloadedFile Header not found" << _fileName;
+             //qDebug() << Q_FUNC_INFO << ":  Header not found" << _fileName;
             QString aux;
             if (userPasswordError)
             {
@@ -686,7 +680,7 @@ void LoTWUtilities::parseDownloadedFile(const QString &_fn)
             msgBox.setStandardButtons(QMessageBox::Ok);
             msgBox.setDefaultButton(QMessageBox::Ok);
             msgBox.exec();
-            //qDebug() << "LoTWUtilities::parseDownloadedFile: END-2";
+            //qDebug() << Q_FUNC_INFO << ":  END-2";
             file.remove();
             return ;
         }
@@ -701,12 +695,11 @@ void LoTWUtilities::parseDownloadedFile(const QString &_fn)
         msgBox.setDefaultButton(QMessageBox::Yes);
         if (msgBox.exec() == QMessageBox::No)
         {
-            //qDebug() << "LoTWUtilities::parseDownloadedFile: END-2";
+            //qDebug() << Q_FUNC_INFO << ":  END-2";
             return ;
         }
         //file.seek(startOfFile);
         emit actionProcessLoTWDownloadedFile(_fileName);
-
     }
 
 
