@@ -39,7 +39,8 @@
 #include <QMessageBox>
 #include <QInputDialog>
 #include "dataproxy_sqlite.h"
-#include "utilities.h"
+#include "qso.h"
+
 // https://lotw.arrl.org/lotw-help/developer-query-qsos-qsls/?lang=en
 class QSslError;
 
@@ -67,7 +68,7 @@ private:
     void parseDownloadedFile(const QString &_fn);
     //void showMessage(const int _messageIcon, const QString &_msg, const QString &_msgExt);
 
-    Utilities *util;
+    //Utilities *util;
 
     //void setTarget(const QString& t);
 
@@ -103,7 +104,6 @@ private slots:
 
 signals:
     void actionProcessLoTWDownloadedFile(QString _fn);
-
 };
 
 #endif // LOTWUTILITIES_H
