@@ -26,7 +26,7 @@
 #include <QtWidgets>
 //#include <QtSql>
 #include <QTranslator>
-#include <cstdlib>
+//#include <cstdlib>
 #include <QTextStream>
 #include <QCoreApplication>
 #include <QCommandLineParser>
@@ -38,6 +38,75 @@
 #include "mainwindow.h"
 #include "utilities.h"
 
+
+int showNoDB()
+{
+    QMessageBox msgBox;
+    Utilities util(Q_FUNC_INFO);
+    QString msg = QString("There is no DB in the KLog folder and could not create it. KLog can't continue like this.\n") +
+                  QString("Please remove or rename the %1 file and restart KLog.").arg(util.getCfgFile());
+
+    msgBox.setWindowTitle("KLog");
+    msgBox.setIcon(QMessageBox::Critical);
+    msgBox.setTextFormat(Qt::RichText);
+    msgBox.setText(msg);
+    msgBox.setStandardButtons(QMessageBox::Ok);
+    msgBox.setDefaultButton(QMessageBox::Ok);
+    msgBox.exec();
+    return -1;
+}
+
+int showErrorUpdatingTheDB()
+{
+    QMessageBox msgBox;
+    Utilities util(Q_FUNC_INFO);
+    QString msg = QString("KLog could not update the DB and it is a critical step for this release. KLog can't continue like this.\n") +
+                  QString("Please use the previews version of KLog to export your log to ADIF. Then do a clean installation of the new KLog version and import the ADIF file. If that doesn't work, please contact the KLog development team.");
+
+    msgBox.setWindowTitle("KLog");
+    msgBox.setIcon(QMessageBox::Critical);
+    msgBox.setTextFormat(Qt::RichText);
+    msgBox.setText(msg);
+    msgBox.setStandardButtons(QMessageBox::Ok);
+    msgBox.setDefaultButton(QMessageBox::Ok);
+    msgBox.exec();
+    return -1;
+}
+
+// Function to handle missing translation files
+void loadTranslations(QApplication &app, QTranslator &myappTranslator)
+{
+    Utilities util(Q_FUNC_INFO);
+    QString translationPath, translationPath2;
+    QString language = (QLocale::system().name()).left(2);
+    bool missingTranslation = true;
+
+// Check possible translation paths
+#if defined(Q_OS_WIN)
+    translationPath = QCoreApplication::applicationDirPath() + "/translations/klog_" + language + ".qm";
+#elif defined(Q_OS_OSX)
+    translationPath = QCoreApplication::applicationDirPath() + "/translations/klog_" + language + ".qm";
+#else
+    translationPath = "/usr/share/klog/translations/klog_" + language + ".qm";
+    translationPath2 = util.getHomeDir() + "/translations/klog_" + language + ".qm";
+#endif
+
+    if (myappTranslator.load(translationPath) || myappTranslator.load(translationPath2))
+    {
+        missingTranslation = false;
+    }
+
+    if (missingTranslation && language != "en")
+    {
+        QMessageBox::warning(nullptr, "KLog",
+                             QString("No translation files for your language were found. KLog will be shown in English.\n")
+                                 + QString("If you have the klog_%1.qm file for your language, copy it to the translations folder and restart KLog.")
+                                       .arg(language));
+    }
+
+    app.installTranslator(&myappTranslator);
+}
+
 int main(int argc, char *argv[])
 {
     //qDebug() << Q_FUNC_INFO << " -  Start! ";
@@ -46,14 +115,8 @@ int main(int argc, char *argv[])
     //qDebug() << QT_VERSION_STR;
 
     QDir d1 = QDir();
-    //QCoreApplication::setApplicationVersion(QString(APP_VERSION));
     //qDebug() << Q_FUNC_INFO << " - STARTED: ";
     Utilities util(Q_FUNC_INFO);
-    QStringList arguments;
-    QTextStream cout(stdout);
-    //QCoreApplication::setOrganizationName("EA4K");
-    //QCoreApplication::setOrganizationDomain("klog.xyz");
-    //QCoreApplication::setApplicationName("KLog");
     QApplication app(argc, argv);
 
     QString iconSt;
@@ -66,137 +129,31 @@ int main(int argc, char *argv[])
     app.setApplicationVersion(QString(APP_VERSION));
     QString version = QCoreApplication::applicationVersion();
     //qDebug() << Q_FUNC_INFO << " -  -10 ";
+
     // Now we check if the user is executing from the command line
-    arguments.clear();
-    arguments << app.arguments();
-    if (arguments.length()>1)
+
+
+    // Command-line arguments
+    QTextStream cout(stdout);
+    QStringList arguments = app.arguments();
+    if (arguments.size() > 1)
     {
+        Utilities util(Q_FUNC_INFO);
         if (arguments.contains("-v"))
         {
             cout << "Version: KLog-" << app.applicationVersion() << "\n";
         }
-        else if ((arguments.contains("-?")) || (arguments.contains("-h")) )
-        {
-            util.printCommandHelp();
-        }
         else
         {
             util.printCommandHelp();
-            app.quit();
-            return 1;
         }
-        app.quit();
         return 0;
     }
-    //qDebug() << Q_FUNC_INFO << " -  Start of translation activities: "<< (QTime::currentTime()).toString("HH:mm:ss");
-    //qDebug() << Q_FUNC_INFO << " -  Detected language: " << (QLocale::system().name()).left(2) << ".qm";
-    // Translations begin
-    QTranslator qtTranslator;
-    qtTranslator.load("qt_" + QLocale::system().name(), QLibraryInfo::location(QLibraryInfo::TranslationsPath)); /* Flawfinder: ignore */
-    app.installTranslator(&qtTranslator);
-    QTranslator myappTranslator;
-
-    bool missingTranslation = false;
-    //QString msgOSFilePath = QString();        // The OS depending part of the message to be printed if no translation is found.
-
-    #if defined(Q_OS_WIN)
-        //qDebug() << Q_FUNC_INFO << " - WIN ";
-        //qDebug() << Q_FUNC_INFO << " - 20 - WIN";
-        if (QFile::exists(QCoreApplication::applicationDirPath() + "/translations/klog_" + (QLocale::system().name()).left(2) + ".qm") ) /* Flawfinder: ignore */
-        {
-            myappTranslator.load(QCoreApplication::applicationDirPath() + "/translations/klog_" + (QLocale::system().name()).left(2) + ".qm"); /* Flawfinder: ignore */
-        }
-        else if (QFile::exists(QDir::homePath()+"/klog/klog_" + (QLocale::system().name()).left(2)+ ".qm") ) /* Flawfinder: ignore */
-        {
-            myappTranslator.load(QDir::homePath()+"/klog/klog_" + (QLocale::system().name())); /* Flawfinder: ignore */
-        }
-        else if (((QLocale::system().name()).left(2)) == "en") /* Flawfinder: ignore */
-        { // If language is English, it will execute without showing message
-        }
-        else
-        {
-            missingTranslation = true;
-            //msgOSFilePath = QCoreApplication::applicationDirPath() + "/translations/" ;
-        }
-      //qDebug() << Q_FUNC_INFO << " -  -20 - end WIN ";
-    #elif defined(Q_OS_OSX)
-        //qDebug() << Q_FUNC_INFO << " -  OSX ";
-
-        if (QFile::exists(QCoreApplication::applicationDirPath() + "/translations/klog_" +  (QLocale::system().name()).left(2) + ".qm") ) /* Flawfinder: ignore */
-        {
-            myappTranslator.load(QCoreApplication::applicationDirPath() + "/translations/klog_" + (QLocale::system().name()).left(2) + ".qm"); /* Flawfinder: ignore */
-        }
-        else if (((QLocale::system().name()).left(2)) == "en") /* Flawfinder: ignore */
-        { // If language is English, it will execute without showing message
-
-        }
-        else
-        {
-            missingTranslation = true;
-        }
-    #else
-            //qDebug() << Q_FUNC_INFO << " - OTHER OS: " << (QLocale::system()).name();
-        if (QFile::exists("klog_" + (QLocale::system().name()).left(2) + ".qm") ) /* Flawfinder: ignore */
-        {
-            myappTranslator.load("klog_" + (QLocale::system().name()).left(2)); /* Flawfinder: ignore */
-        }
-        else if (QFile::exists("/usr/share/klog/translations/klog_" + (QLocale::system().name()).left(2) + ".qm") ) /* Flawfinder: ignore */
-        {
-               //qDebug() << Q_FUNC_INFO << " - OTHER -2: " << "/usr/share/klog/klog_" + (QLocale::system().name()).left(2); /* Flawfinder: ignore */
-            myappTranslator.load("/usr/share/klog/translations/klog_" + (QLocale::system().name()));  /* Flawfinder: ignore */
-        }
-        else if (QFile::exists(QCoreApplication::applicationDirPath() + "/translations/klog_" + (QLocale::system().name()).left(2) + ".qm")) /* Flawfinder: ignore */
-        {
-            //qDebug() << Q_FUNC_INFO << " - OTHER -3: " << QCoreApplication::applicationDirPath() + "/translations/klog_" + (QLocale::system().name()).left(2);
-            myappTranslator.load(QCoreApplication::applicationDirPath() + "/translations/klog_" + (QLocale::system().name())); /* Flawfinder: ignore */
-        }
-
-        else if (((QLocale::system().name()).left(2)) == "en") /* Flawfinder: ignore */
-        { // If language is English, it will execute without showing message
-
-        }
-        else
-        {
-            missingTranslation = true;
-            //sgOSFilePath = QCoreApplication::applicationDirPath() + "/translations/" ;
-        }
-
-    #endif
-    //qDebug() << Q_FUNC_INFO << " -  -40 ";
-    if (missingTranslation)
-        {
-            //qDebug() << Q_FUNC_INFO << " -  Translation missing! ";
-            QMessageBox msgBox;
-            QString urlTranslate = QString();
-            urlTranslate = "<p><a href=\"https://translate.google.com/?sl=auto&tl=auto#en/auto/No%20translation%20files%20for%20your%20language%20have%20been%20found%20so%20KLog%20will%20be%20shown%20in%20English.%0A%0AIf%20you%20have%20the%20klog_en.qm%20file%20for%20your%20language%2C%20you%20can%20copy%20it%20in%20the%20%2Fhome%2Fdevel%2F.klog%2F%20folder%20and%20restart%20KLog%20again.%0A%0A%20If%20you%20want%20to%20help%20to%20translate%20KLog%20into%20your%20language%2C%20please%20contact%20the%20author.\">TRANSLATE</a></p>";
-
-            QString msg = QString();
-
-            msgBox.setWindowTitle("KLog");
-            msgBox.setIcon(QMessageBox::Warning);
-            msgBox.setTextFormat(Qt::RichText);
-            QString language = (QLocale::system().name()).left(2); /* Flawfinder: ignore */
-
-            msg = QString("No translation files for your language have been found so KLog will be shown in English.") + "<p>" +
-                  QString("If you have the klog_%1.qm file for your language, you can copy it into the %2/translations/ folder and restart KLog.</p><p>If you want to help to translate KLog into your language, please contact the author.").arg(language).arg(QCoreApplication::applicationDirPath()) +
-                  "</p>" + urlTranslate;
-
-            msgBox.setText(msg);
-            msgBox.setStandardButtons(QMessageBox::Ok);
-            msgBox.setDefaultButton(QMessageBox::Ok);
-            msgBox.exec();
-
-        }
-
-    //qDebug() << Q_FUNC_INFO << " - 1" << (QTime::currentTime()).toString("HH:mm:ss") ;
-
-    app.installTranslator(&myappTranslator);
-    //qDebug() << Q_FUNC_INFO << " -  End of translation activities: "<< (QTime::currentTime()).toString("HH:mm:ss");
-    // Traslations end
 
     /* Application Singleton
      *
      * We want to run only one instance of KLog application
+     *
      */
     QSystemSemaphore semaphore("klogapp", 1);  // create semaphore with unique ID klogapp
     semaphore.acquire();                       // Raise the semaphore, barring other instances to work with shared memory
@@ -246,12 +203,18 @@ int main(int argc, char *argv[])
 
     // END OF Application Singleton
 
+    // Load translations
+    //qDebug() << Q_FUNC_INFO << " -  Start of translation activities: "<< (QTime::currentTime()).toString("HH:mm:ss");
+    //qDebug() << Q_FUNC_INFO << " -  Detected language: " << (QLocale::system().name()).left(2) << ".qm";
+    QTranslator myappTranslator;
+    loadTranslations(app, myappTranslator);
+
+
     QString klogDir = util.getHomeDir();
-    //configFileName = util.getCfgFile();
 
     //qDebug() << Q_FUNC_INFO << " - 10";
-
     //qDebug() << Q_FUNC_INFO << " - Setting klog dir: " << (QTime::currentTime()).toString("HH:mm:ss")<< QT_ENDL;;
+    // First step when running KLog, if the KLog folder does not exist, KLog creates it
     if (!QDir::setCurrent (klogDir) )
     {
         //qDebug() << Q_FUNC_INFO << " - KLogDir does not exist.... creating ";
@@ -267,10 +230,10 @@ int main(int argc, char *argv[])
 
     //qDebug() << Q_FUNC_INFO << " -  Setting config file: " << (QTime::currentTime()).toString("HH:mm:ss") ;
     QPixmap pixmap(":img/klog_512x512.png");
-    //qDebug() << Q_FUNC_INFO << " - 51" << (QTime::currentTime()).toString("HH:mm:ss");
+   //qDebug() << Q_FUNC_INFO << " - 51" << (QTime::currentTime()).toString("HH:mm:ss");
     QSplashScreen splash(pixmap);
-
-
+    //int firstTime = true;
+    // If the KLog configuration file does not exist, we launch the wizard.
     if (!((QFile::exists(util.getCfgFile ()))))
     {
         //qDebug() << Q_FUNC_INFO << " -  Starting wizard... ";
@@ -279,34 +242,45 @@ int main(int argc, char *argv[])
         wizard->exec();
     }
     else
-    {
-        //qDebug() << Q_FUNC_INFO << " -  Start of DB Activities" << (QTime::currentTime()).toString("HH:mm:ss");
+    {   // KLog configuration file exists, let's look for the DB
+       //qDebug() << Q_FUNC_INFO << " -  Start of DB Activities" << (QTime::currentTime()).toString("HH:mm:ss");
+        //firstTime = false;
         DataBase *db = new DataBase(Q_FUNC_INFO, version, util.getKLogDBFile());
-        //qDebug() << Q_FUNC_INFO << " -  After Start of DB Activities";
+       //qDebug() << Q_FUNC_INFO << " -  After Start of DB Activities";
         if (!db->createConnection(Q_FUNC_INFO))
         {
-            //qDebug() << Q_FUNC_INFO << " - Conection not created";
-            return -1; // Exits with an error; no DB has been created
+           //qDebug() << Q_FUNC_INFO << " - Conection not created";
+            return showNoDB();
+            //return -1; // Exits with an error; no DB has been created
         }
         else
         {
-            //qDebug() << Q_FUNC_INFO << " - DB to be updated";
-            db->updateIfNeeded(); // Check if we need to update the DB
-            //qDebug() << Q_FUNC_INFO << " - DB Updated";
+           //qDebug() << Q_FUNC_INFO << " - DB to be updated";
+            if (!db->updateIfNeeded()) // Check if we need to update the DB
+            {
+               //qDebug() << Q_FUNC_INFO << " - DB NOT Updated";
+            }
+
+           //qDebug() << Q_FUNC_INFO << " - DB Updated";
         }
-        //qDebug() << Q_FUNC_INFO << " - DB Updated";
-        //qDebug() << Q_FUNC_INFO << " - 98" << (QTime::currentTime()).toString("HH:mm:ss");
+       //qDebug() << Q_FUNC_INFO << " - 98" << (QTime::currentTime()).toString("HH:mm:ss");
         db->~DataBase();
-        //qDebug() << Q_FUNC_INFO << " - 99" << (QTime::currentTime()).toString("HH:mm:ss");
+       //qDebug() << Q_FUNC_INFO << " - 99" << (QTime::currentTime()).toString("HH:mm:ss");
     }
-    //qDebug() << Q_FUNC_INFO << " - 100 " << (QTime::currentTime()).toString("HH:mm:ss");
+  //qDebug() << Q_FUNC_INFO << " - 100 - Show" << (QTime::currentTime()).toString("HH:mm:ss");
     splash.show();
-    //qDebug() << Q_FUNC_INFO << " - 101 " << (QTime::currentTime()).toString("HH:mm:ss");
+   //qDebug() << Q_FUNC_INFO << " - 101 " << (QTime::currentTime()).toString("HH:mm:ss");
+
+    splash.showMessage ("Creating the Data Base...");
+    DataProxy_SQLite dataProxy (Q_FUNC_INFO, version);
+
     splash.showMessage ("Creating window...");
-    //qDebug() << Q_FUNC_INFO << " - 102 " << (QTime::currentTime()).toString("HH:mm:ss");
-    MainWindow mw(version);
-    //qDebug() << Q_FUNC_INFO << " - 103 " << (QTime::currentTime()).toString("HH:mm:ss");
+   //qDebug() << Q_FUNC_INFO << " - 102 " << (QTime::currentTime()).toString("HH:mm:ss");
+
+    MainWindow mw(&dataProxy);
     splash.showMessage ("Initializing window...");
+    //qDebug() << Q_FUNC_INFO << " - 103 " << (QTime::currentTime()).toString("HH:mm:ss");
+
     //qDebug() << Q_FUNC_INFO << " - 104 " << (QTime::currentTime()).toString("HH:mm:ss");
     mw.init();
     //qDebug() << Q_FUNC_INFO << " - 105 " << (QTime::currentTime()).toString("HH:mm:ss");
@@ -321,14 +295,11 @@ int main(int argc, char *argv[])
     splash.showMessage ("Showing window...");
     //qDebug() << Q_FUNC_INFO << " - 110 " << (QTime::currentTime()).toString("HH:mm:ss");
     mw.show();
-    //qDebug() << Q_FUNC_INFO << " - 111 " << (QTime::currentTime()).toString("HH:mm:ss");
+     //qDebug() << Q_FUNC_INFO << " - 111 " << (QTime::currentTime()).toString("HH:mm:ss");
     splash.finish(&mw);
-    //qDebug() << Q_FUNC_INFO << " - 112 " << (QTime::currentTime()).toString("HH:mm:ss");
-    mw.showNotWar();
+     //qDebug() << Q_FUNC_INFO << " - 112 " << (QTime::currentTime()).toString("HH:mm:ss");
+    //mw.showNotWar();
     //qDebug() << Q_FUNC_INFO << " - 113 " << (QTime::currentTime()).toString("HH:mm:ss");
     //qDebug() << Q_FUNC_INFO << " - END";
     return app.exec();
 }
-
-
-
