@@ -26,11 +26,12 @@
  *****************************************************************************/
 //https://github.com/ea4k/klog/commit/1ac02c7b779922a8e5907ebee088fa64654cbdf5
 #include "mainqsoentrywidget.h"
+#include "callsign.h"
 
 MainQSOEntryWidget::MainQSOEntryWidget(DataProxy_SQLite *dp, QWidget *parent) : QWidget(parent)
 {
-       //qDebug()<< Q_FUNC_INFO;
-    logEvent (Q_FUNC_INFO, "Start", Debug);
+    //qDebug()<< Q_FUNC_INFO;
+    logEvent (Q_FUNC_INFO, "Start", Debug);       
     modifyingBands = false;
     upAndRunning = false;
     dataProxy = dp;
@@ -141,8 +142,8 @@ void MainQSOEntryWidget::createUI()
     connect(qrzLineEdit, SIGNAL(textChanged(QString)), this, SLOT(slotStartDelayInputTimer() ) );
     connect(delayInputTimer, SIGNAL(timeout()), this, SLOT(slotDelayInputTimedOut() ) );
 
-    connect(bandComboBox, SIGNAL(currentIndexChanged (QString)), this, SLOT(slotBandComboBoxChanged(QString) ) ) ;
-    connect(modeComboBox, SIGNAL(currentIndexChanged (QString)), this, SLOT(slotModeComboBoxChanged(QString) ) ) ;
+    connect(bandComboBox, SIGNAL(currentTextChanged (QString)), this, SLOT(slotBandComboBoxChanged(QString) ) ) ;
+    connect(modeComboBox, SIGNAL(currentTextChanged (QString)), this, SLOT(slotModeComboBoxChanged(QString) ) ) ;
 
     connect(OKButton, SIGNAL(clicked()), this, SLOT(slotOKButtonClicked()));
     connect(clearButton, SIGNAL(clicked()), this, SLOT(slotClearButtonClicked()));
@@ -160,6 +161,8 @@ void MainQSOEntryWidget::createUI()
      //qDebug() << Q_FUNC_INFO << ": (" << QString::number(this->size ().width ()) << "/" << QString::number(this->size ().height ()) << ")" ;
 }
 
+
+
 void MainQSOEntryWidget::setShowSeconds(const bool &t)
 {
     if (t)
@@ -179,12 +182,6 @@ void MainQSOEntryWidget::setLogLevel (const DebugLogLevel _b)
     logEvent (Q_FUNC_INFO, "END", Debug);
 }
 
-void MainQSOEntryWidget::setCallValidation (const bool _b)
-{
-    util->setCallValidation(_b);
-    dataProxy->setCallValidation(_b);
-}
-
 void MainQSOEntryWidget::slotCheckBoxClicked()
 {
    logEvent (Q_FUNC_INFO, "Start", Debug);
@@ -252,7 +249,7 @@ void MainQSOEntryWidget::setCleaning (const bool _c)
 void MainQSOEntryWidget::slotQRZTextChanged()
 {
     logEvent (Q_FUNC_INFO, "Start: " + qrzLineEdit->text(), Debug);
-     //qDebug()<< Q_FUNC_INFO << qrzLineEdit->text() << " / Length: " << QString::number((qrzLineEdit->text()).size()) << "###### START ######";
+   //qDebug()<< Q_FUNC_INFO << qrzLineEdit->text() << " / Length: " << QString::number((qrzLineEdit->text()).size()) << "###### START ######";
     logEvent (Q_FUNC_INFO, "Start", Debug);
 
     if ((qrzLineEdit->text()).length()<1)
@@ -300,7 +297,8 @@ void MainQSOEntryWidget::slotQRZTextChanged()
     //TODO: This validCharactersInCall may be removed?
     InValidCharsInPrevCall = validCharactersInCall(qrzLineEdit->text());
      //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: checking for invalid chars 00 ";
-    if (!util->isValidCall(qrzLineEdit->text()))
+    Callsign callsign(qrzLineEdit->text());
+    if (!callsign.isValid())
     {
         qrzLineEdit->setPalette(palRed);
         //emit showInfoLabel(tr("Callsign not valid"));
@@ -381,7 +379,7 @@ void MainQSOEntryWidget::slotQRZTextChanged()
     emit currentQRZSignal(currentQrz);
 
     qrzSmallModDontCalculate = false; // If the text has not been modified in this method
-     //qDebug() << "MainQSOEntryWidget::slotQRZTextChanged: cursorP at the end : " << QString::number(cursorP);
+   //qDebug() << "MainQSOEntryWidget::slotQRZTextChanged: cursorP at the end : " << QString::number(cursorP);
     qrzLineEdit->setCursorPosition(cursorP);
     checkIfDupe(Q_FUNC_INFO);
     qrzAutoChanging = false;
@@ -403,9 +401,11 @@ void MainQSOEntryWidget::slotBandComboBoxChanged(const QString &_b){
          //qDebug() << Q_FUNC_INFO << ": Modifying bands - END" ;
         return;
     }
+
     bottomBandLimit = dataProxy->getLowLimitBandFromBandName (_b);
     upperBandLimit = dataProxy->getUpperLimitBandFromBandName (_b);
     emit bandChanged(_b);
+   //qDebug() << Q_FUNC_INFO << " - 99";
     checkIfDupe(Q_FUNC_INFO);
     logEvent (Q_FUNC_INFO, "END", Debug);
     //qDebug() << Q_FUNC_INFO << " - END";
@@ -414,8 +414,9 @@ void MainQSOEntryWidget::slotBandComboBoxChanged(const QString &_b){
 void MainQSOEntryWidget::slotModeComboBoxChanged(const QString &_m)
 {
     logEvent (Q_FUNC_INFO, "Start", Debug);
-
+   //qDebug() << Q_FUNC_INFO << " - 00";
     emit modeChanged(_m);
+   //qDebug() << Q_FUNC_INFO << " - 99";
     checkIfDupe(Q_FUNC_INFO);
     logEvent (Q_FUNC_INFO, "END", Debug);
 }
@@ -442,7 +443,7 @@ void MainQSOEntryWidget::slotOKButtonClicked()
 
 void MainQSOEntryWidget::slotClearButtonClicked()
 {
-     //qDebug() << "MainQSOEntryWidget::slotClearButtonClicked: " ;
+   //qDebug() << "MainQSOEntryWidget::slotClearButtonClicked: " ;
     logEvent (Q_FUNC_INFO, "Start", Debug);
     setCleaning (true);
     clear();
@@ -469,9 +470,49 @@ void MainQSOEntryWidget::clear()
     logEvent (Q_FUNC_INFO, "END", Debug);
 }
 
+QSO MainQSOEntryWidget::getQSOData(QSO & _qso)
+{
+    //qDebug() << Q_FUNC_INFO << " -  Call-01   : " << _qso.getCall();
+    QSO tQSO(_qso);
+    //qDebug() << Q_FUNC_INFO << " -  Call-02   : " << tQSO.getCall();
+    tQSO.setCall(getQrz());
+    //qDebug() << Q_FUNC_INFO << " -  Call-03   : " << tQSO.getCall();
+    tQSO.setBand(getBand());
+    tQSO.setMode(dataProxy->getNameFromSubMode (getMode()));
+    tQSO.setSubmode(getMode());
+    tQSO.setDateTimeOn(getDateTime());
+    return tQSO;
+}
+
+void MainQSOEntryWidget::setQSOData(QSO _qso)
+{
+    //qDebug()<< Q_FUNC_INFO << "Call: " << _qso.getCall();
+
+    QSO qso(_qso);
+    //qDebug() << "Setting QSO Data - Call:" << qso.getCall();
+    //qDebug() << "Setting QSO Data - Band:" << qso.getBand();
+    //qDebug() << "Setting QSO Data - Mode:" << qso.getSubmode();
+    //qDebug() << "Setting QSO Data - DateTime:" << qso.getDateTimeOn().toString();
+
+
+    //qDebug()<< Q_FUNC_INFO << "Call2: " << qso.getCall();
+    //if (qso.isValid())
+    //{
+    //   //qDebug()<< Q_FUNC_INFO << "QSO is NOT Valid...";
+    //    return;
+    //}
+    //qDebug()<< Q_FUNC_INFO << "QSO is Valid...";
+
+    setQRZ(qso.getCall());
+    setBand(qso.getBand());
+    setMode(qso.getSubmode());
+    setDateTime(qso.getDateTimeOn());
+   //qDebug()<< Q_FUNC_INFO << "Call: " << getQrz();
+}
+
 void MainQSOEntryWidget::setInitialData()
 {
-       //qDebug()<< "MainQSOEntryWidget::setInitialData";
+       //qDebug()<< Q_FUNC_INFO;
     logEvent (Q_FUNC_INFO, "Start", Debug);
     //Default band/modes
     modify = false;
@@ -480,9 +521,6 @@ void MainQSOEntryWidget::setInitialData()
     qrzSmallModDontCalculate=false;
     previousQRZ = QString();
 
-    util->setLongPrefixes(dataProxy->getLongPrefixes());
-    util->setSpecialCalls(dataProxy->getSpecialCallsigns());
-
     bands.clear();
     modes.clear();
     bands << "10M" << "15M" << "20M" << "40M" << "80M" << "160M";
@@ -578,7 +616,7 @@ void MainQSOEntryWidget::setBands(const QStringList &_bands)
 void MainQSOEntryWidget::setModes(const QStringList &_modes)
 {
     logEvent (Q_FUNC_INFO, "Start", Debug);
-     //qDebug() << Q_FUNC_INFO;
+    //qDebug() << Q_FUNC_INFO;
 
     modes.clear();
     modes = _modes;
@@ -588,7 +626,6 @@ void MainQSOEntryWidget::setModes(const QStringList &_modes)
     modeComboBox->addItems(modes);
     selectDefaultMode(true);
     logEvent (Q_FUNC_INFO, "END", Debug);
-
 }
 
 QStringList MainQSOEntryWidget::getModes()
@@ -685,17 +722,18 @@ bool MainQSOEntryWidget::setBand(const QString &_band)
 
 bool MainQSOEntryWidget::setMode(const QString &_mode)
 {
+    //TODO: If the mode is not already selected, add the mode automatically.
     logEvent (Q_FUNC_INFO, "Start" + _mode, Debug);
-     //qDebug() << Q_FUNC_INFO << ":  " << _mode;
+    //qDebug() << Q_FUNC_INFO << ":  " << _mode;
     if (modeComboBox->findText(_mode, Qt::MatchCaseSensitive) < 0)
     {
-         //qDebug() << Q_FUNC_INFO << ":  NOT found";
+       //qDebug() << Q_FUNC_INFO << " -  NOT found";
         logEvent (Q_FUNC_INFO, "END-1", Debug);
         return false;
     }
     else
     {
-         //qDebug() << Q_FUNC_INFO << ":  Updated";
+       //qDebug() << Q_FUNC_INFO << " -  Updated";
         modeComboBox->setCurrentIndex(modeComboBox->findText(_mode, Qt::MatchCaseSensitive));
         logEvent (Q_FUNC_INFO, "END-2", Debug);
         return true;
@@ -757,6 +795,7 @@ QString MainQSOEntryWidget::getQrz()
         return QString();
     }
     logEvent(Q_FUNC_INFO, "END", Debug);
+    //qDebug() << Q_FUNC_INFO << " - " << aux.toUpper();
     return aux.toUpper();
 }
 
@@ -1055,25 +1094,47 @@ void MainQSOEntryWidget::checkIfDupe(const QString &_func)
 {
     Q_UNUSED(_func);
 #ifdef QT_DEBUG
-    //qDebug() << Q_FUNC_INFO << "(" << _func << ")";
+   //qDebug() << Q_FUNC_INFO << "(" << _func << ")";
 #else
 #endif
     logEvent (Q_FUNC_INFO, "Start", Debug);
+   //qDebug() << Q_FUNC_INFO << " - " << _func;
+   //qDebug() << Q_FUNC_INFO << " - " << qrzLineEdit->text();
+    Callsign call(qrzLineEdit->text());
+    if (!call.isValid())
+        return;
+   //qDebug() << Q_FUNC_INFO << " - 20";
     QDateTime _dateTime;
     _dateTime.setDate(dateEdit->date());
     _dateTime.setTime(timeEdit->time());
-
-    if ((dataProxy->isThisQSODuplicated(Q_FUNC_INFO, qrzLineEdit->text(), _dateTime, dataProxy->getIdFromBandName(bandComboBox->currentText()), dataProxy->getIdFromModeName(modeComboBox->currentText()), duplicatedQSOSlotInSecs).length()<2) || modify)
+   //qDebug() << Q_FUNC_INFO << " - 30";
+    QSO q;
+    q.setCall(qrzLineEdit->text());
+    q.setDateTimeOn(_dateTime);
+    q.setBand(bandComboBox->currentText());
+    q.setMode(modeComboBox->currentText());
+   //qDebug() << Q_FUNC_INFO << " - 35";
+    if (!q.isValid())
     {
-         //qDebug() << Q_FUNC_INFO << " - NOT DUPE ";
-         //qDebug() << Q_FUNC_INFO << " - Modify: " << util->boolToQString(modify);
+       //qDebug() << Q_FUNC_INFO << " - QSO not valid!";
+        return;
+    }
+   //qDebug() << Q_FUNC_INFO << " - 40";
+
+    if ((dataProxy->isThisQSODuplicated(q, duplicatedQSOSlotInSecs).length()<2) || modify)
+    {
+       //qDebug() << Q_FUNC_INFO << " - 41";
+        //qDebug() << Q_FUNC_INFO << " - DUPE ";
+        //qDebug() << Q_FUNC_INFO << " - Modify: " << util->boolToQString(modify);
         qrzgroupBox->setTitle(tr("Callsign"));
     }
     else
     {
-         //qDebug() << Q_FUNC_INFO << " - NOT DUPE ";
+       //qDebug() << Q_FUNC_INFO << " - 42";
+       //qDebug() << Q_FUNC_INFO << " - NOT DUPE ";
         qrzgroupBox->setTitle(tr("DUPE", "Translator: DUPE is a common world for hams. Do not translate of not sure"));
     }
+   //qDebug() << Q_FUNC_INFO << " - END";
     logEvent (Q_FUNC_INFO, "END", Debug);
 }
 
