@@ -30,13 +30,14 @@
 #include <QtWidgets>
 #include "dataproxy_sqlite.h"
 #include "utilities.h"
+#include "qso.h"
 
 class MainQSOEntryWidget : public QWidget
 {
     Q_OBJECT
     friend class tst_MainWindow;
 
-public:
+public:    
     explicit MainQSOEntryWidget(DataProxy_SQLite *dp, QWidget *parent = nullptr);
     ~MainQSOEntryWidget();
     void setBands(const QStringList &_bands);
@@ -54,6 +55,10 @@ public:
     bool isModeExisting(const QString &_m);
     bool isBandExisting(const QString &_b);
     void setShowSeconds(const bool &t);
+    void setQSOData(QSO _qso);
+    QSO getQSOData(QSO &_qso);
+
+
     QString getQrz();
     QString getBand(int _b=-1);
     QString getMode(int _m=-1);
@@ -78,8 +83,8 @@ public:
     void setDuplicatedQSOSlot (const int _secs);
     void setFocusToOK();
     void setLogLevel (const DebugLogLevel _b);
-    void setCallValidation (const bool _b);
     void clear();
+    bool getDarkMode();
 
 protected:
     //void keyPressEvent(QKeyEvent *event);
@@ -96,6 +101,7 @@ signals:
     void validBands(QStringList _bands);
     void handOverFocusSignal();
     void manualModeSignal(bool _active);
+                       // Returns if we are in dark mode or not
 
 private slots:
     void slotCaptureDebugLogs(const QString &_func, const QString &_msg, DebugLogLevel _level);
@@ -141,7 +147,7 @@ private:
     bool InValidCharsInPrevCall;
     bool qrzSmallModDontCalculate;
     bool upAndRunning;
-    bool getDarkMode();
+
 
     QString previousQRZ;
     QString currentQrz;
