@@ -40,10 +40,13 @@
 #include "tipsdialog.h"
 #include "world.h"
 #include "filemanager.h"
-#include "fileawardmanager.h"
+//#include "fileawardmanager.h"
 #include "dataproxy_sqlite.h"
-#include "locator.h"
-#include "dxcluster.h"
+//#include "locator.h"
+#include "dxcluster/dxcluster.h"
+#include "dxcluster/dxspot.h"
+//#include "dxcluster/dxclusterassistant.h"
+#include "frequency.h"
 #include "awards.h"
 #include "inputwidgets/mainwindowsattab.h"
 #include "inputwidgets/mainwindowmydatatab.h"
@@ -75,8 +78,10 @@
 #include "widgets/map/mapwindowwidget.h"
 #include "widgets/showkloglogwidget.h"
 #include "qso.h"
-#include "updatesettings.h"
 #include "klogdefinitions.h"
+#include <memory>
+
+#include <memory>
 
 class QTimer;
 class QDateTime;
@@ -133,18 +138,18 @@ class MainWindow : public  QMainWindow
     friend class tst_MainWindow;
 
 public:
-    MainWindow(const QString &tversion);
+    MainWindow(DataProxy_SQLite *dp);
     ~MainWindow();
     void checkIfNewVersion();
     void recommendBackupIfNeeded();
     void init();
-    void showNotWar();
+    //void showNotWar();
 
 private slots:
     //void slotQueryErrorManagement(QString functionFailed, QString errorCodeS, QString nativeError, QString failedQuery);
     //void slotTest();        // Slot for testing purposes only
     void slotOpenWiki();
-    void slotAWAImport();
+    //void slotAWAImport();
     void slotClearNoMorErrorShown();
     void slotQueryErrorManagement(QString functionFailed, QString errorCodeS, QString nativeError, QString queryFailed);
     void slotQRZReturnPressed();
@@ -153,7 +158,7 @@ private slots:
     //void slotSRXTextChanged();
     //void slotSTXTextChanged();
     void slotUpdateLocator(QString _loc);
-    void slotLocatorTextChanged(const QString &_loc);
+    KLOG_DEPRECATED void slotLocatorTextChanged(const QString &_loc);
     //void slotMyLocatorTextChanged();
     void slotFreqTXChanged(const double _fr);
     void slotFreqRXChanged(const double _fr);
@@ -206,6 +211,7 @@ private slots:
     void slotLoTWDownload();
     void slotLoTWFullDownload();
     void slotADIFExportSelection(const QString &_call, QList<int> _qsos, ExportMode _eM);
+    void slotADIFExportClose();
     void slotADIFExportAll();
     void slotADIFImport();
     void slotRQSLExport();
@@ -259,8 +265,8 @@ private slots:
     //SEARCH
 
     // CLUSTER
-    void slotAnalyzeDxClusterSignal(const QStringList _qs);
-    void slotDXClusterSpotArrived(const QString _dxCall, const QString _dxGrid, const double _freq);
+    void slotAnalyzeDxClusterSignal(const DXSpot &_spot);
+    void slotDXClusterSpotArrived(const DXSpot &_spot);
 
     // CLUSTER
     //CLUBLOG
@@ -303,16 +309,15 @@ private slots:
     //void slotShowQSOFromDXCCWidget(const int _q);
     void slotShowQSOsFromDXCCWidget(QList<int> _qsos);
 
+    // DXCLUSTER ASSISTANT
+    //void slotShowDXClusterAssistant();
+
     //UDP Server (WXJT-x)
     void slotWSJXstatusFromUDPServer(const int _type, const QString &_dxcall, const double _freq, const QString &_mode,
                                  const QString &_report, const QString &_de_call, const QString &_de_grid,
                                  const QString &_dx_grid, const QString &_sub_mode);
 
-    void slotWSJTXloggedQSO (const QString &_dxcall, const QString &_mode, const QString &_band, const double _freq,
-                     const QString &_mygrid, const QString &_dxgrid, const QString &_rstTX, const QString &_rstRX,
-                     const QString &_comment, const QString &_stationcallsign, const QString &_name,
-                     const QString &_opCall, const QDateTime &_datetime, const QDateTime &_datetime_off,
-                     const QString &_exchangeTX, const QString &_exchangeRX, const QString &_mypwr);
+    void slotQSOReceived(const QSO &_qso);
 
     void slotCaptureDebugLogs(const QString &_func, const QString &_msg, DebugLogLevel _level);
     //void slotTakeOverFocus(int _id);
@@ -320,10 +325,18 @@ private slots:
     void slotTakeOverFocusToMainQSOInput();
     void slotNewLogLevel(DebugLogLevel l);
     void slotQSO_SetMode(const QString _submode);
+    void slotDarkModeChanged(const bool _dm);
 
 private:
     //void setWidgetsOrder();
-
+    void setDarkMode(const bool _dm);
+    void init_variables();      // Refactored from init()
+    void checkDebugFile();      // Refactored from init()
+    void checkExistingData();   // Refactored from init()
+    void readSettingsFile();    // Refactored from init()
+    void checkVersions();       // Refactored from init()
+    void checkHomeDir();        // Refactored from init()
+    bool showWSJTXDuplicatedMSG(const QSO &_qso);  //Shows an error if the QSO received from WSJTX is dupe.
     void startServices();
     void backupCurrentQSO();
     void restoreCurrentQSO(const bool restoreConfig);
@@ -335,6 +348,7 @@ private:
     void setCleaning(const bool _c);
     bool setHamlib(const bool _b);
     bool setUDPServer(const bool _b);
+    bool askToAddQSOReceived(const QSO &_qso);  // Shows a message with the data of the QSO
     void logEvent(const QString &_func, const QString &_msg, DebugLogLevel _level);
     void setLogLevel(const DebugLogLevel _sev);
     //void fileExportLoTW(const QString &_st, const QString &_grid, const QDate &_startDate, const QDate &_endDate);
@@ -345,15 +359,20 @@ private:
     void fileExportEQSL2(const QString &_call, QList<int> _qsos);
     //void fileExportADIF(const QString &_st, const QString &_grid, const QDate &_startDate, const QDate &_endDate);
     void fileExportADIF2(const QString &_call, QList<int> _qsos);
-
+    void setColors (const QColor &_newOne, const QColor &_needed, const QColor &_worked, const QColor &_confirmed, const QColor &_default);
     bool callTQSL(const QString &_filename, const QString &_call);
     void showNumberOfSavedQSO(const QString &_fn, const int _n);
+
+
     //QString getCallToUseForLoTWExportUpload();
     UpdateSatsData *updateSatsData;
     //UPDATE CTY.DAT
     DownLoadCTY *downloadcty;
     HamLibClass *hamlib;
-    QSO *qso, *backupQSO;
+    //QSO qso;           // QSO that is being managed in one specific moment
+    QSO *backupQSO;     // QSO that has been backed up to send another QSO to the UI
+    QSO qsoInUI;        // The QSO tat is shown in the UI  for a given time
+    //QSO *modifyingQSO;
 
     bool hamlibActive;
     bool hamlibChangingMode;
@@ -380,8 +399,10 @@ private:
     void createActionsCommon();
 
 
-    //bool validCharactersInCall(const QString &_qrz); // Looks for SQLi and no valid chars in the QRZ
-    bool readQSOFromUI();
+    bool readQSOFromUI();                           // Adds the data in the UI to the qso instance (calling getQSODataFromUI)
+    void getQSODataFromUI();                        // Calls to the different widgets for QSO data and fills qso instance
+    void sendQSOToUI(const QSO &_qso);              // Shows the content of a QSO in the UI
+
     //QString readDataFromUI(); // Reads the QSO data from the UI and returns the SQL Query
     //QString readDataFromUIDX();
     //QString readDataFromUIDXModifying();
@@ -389,12 +410,9 @@ private:
     //void clearForNextQSO();
     void clearUIDX(bool _full = false); //full= false leaves the "keep this data"; full = true clears everything
 
-    void setAwardDXCC(const int _qsoId, bool modifying); // Adds or modify the status of a DXCC entity
-    // data << dxcc(id) << band(id) << mode(id) << confirmed(0/1) << qsoid(id) << modify(0/1);
-
-    //void checkIfWorkedB4(const QString &_qrz);
+     //void checkIfWorkedB4(const QString &_qrz);
     //bool checkContest();
-    void showStatusOfDXCC(const QStringList _qs);
+    void showStatusOfDXCC(EntityStatus _entityStatus);
     void showDXMarathonNeeded(const int _dxcc, const int _cqz, const int _year, const int _log);
 
     bool createConnection();
@@ -404,7 +422,8 @@ private:
     bool loadSettings();
     bool applySettings();
     void selectTheLog(const int _i);    // Receives a log number from loadSettings and setups all about the logN
-    void defineStationCallsign(const QString &_call);
+    void defineStationCallsign();
+    QString findStationCallsignToUse(); // Used to select the station Callsign used
     QString selectStationCallsign();
 
     void checkIfNewBandOrMode();
@@ -418,8 +437,10 @@ private:
 
     void qsoToEdit (const int _qso);
     void setModifying(const bool _m);
-
+    void clearIfNotCompleted();                 // Refactored from completeWithPreviousQSO
     void completeWithPreviousQSO(const QString &_call);
+    bool checkValidCallBeforeAddingToLog(const QString &_call);                             // Asks the user if call is not valid
+    int checkDXCCBeforeAddingToLog(const int dxcc_Call, const int dxcc_qso);                // Asks the user if DXCC if unsure
 
     //void showAwards();
     //void showDXMarathon(const int _year);
@@ -429,7 +450,7 @@ private:
 
 
     // CLUSTER
-    void clusterSpotToLog(const QString &_call, const QString &_freq);
+    void clusterSpotToLog(const QString &_call, Frequency _fr);
     QStringList dxclusterServersList;
     //QString dxclusterServerToConnect;
     //int dxclusterServerPort;
@@ -445,9 +466,9 @@ private:
     //QWidget *dxClusterTabWidget;//, *searchTabWidget;
     World *world;
     FileManager *filemanager;
-    FileAwardManager *fileAwardManager;
-    Locator *locator;
-    Awards *awards;
+    //FileAwardManager *fileAwardManager;
+    //Locator *locator;
+    Awards awards;
     Utilities *util;
     //SetupPageMisc *miscPage;
 
@@ -460,11 +481,18 @@ private:
     TipsDialog *tipsDialog;
     ShowKLogLogWidget * showKLogLogWidget;
     StatisticsWidget *statsWidget;
-    DXCCStatusWidget *dxccStatusWidget;
+    std::unique_ptr<DXCCStatusWidget> dxccStatusWidget; // Defined like this to send the same award instance
+    std::unique_ptr<DXClusterWidget> dxClusterWidget;   // Defined like this to send the same award instance
+    std::unique_ptr<SearchWidget> searchWidget;        // Defined like this to send the same award instance
+    std::unique_ptr<LogWindow> logWindow;        // Defined like this to send the same award instance
+
+
+     //DXClusterWidget *dxClusterWidget;
+    //DXCCStatusWidget *dxccStatusWidget;
     QLabel *logLabel;
 
     //LogModel *logModel;
-    LogWindow *logWindow;
+    //LogWindow *logWindow;
     UDPServer *UDPLogServer;
 
     ShowErrorDialog *showErrorDialog;
@@ -558,6 +586,7 @@ private:
     QAction *qslSentRequestedAct;
     QAction *qslRecRequestedAct;
     QAction *showMapAct;
+    //QAction *dxClusterAssistantAct;
 
     QStringList bands;
     QStringList modes;
@@ -591,7 +620,7 @@ private:
     MainQSOEntryWidget *mainQSOEntryWidget;
 
     AwardsWidget *awardsWidget;
-    SearchWidget *searchWidget;
+    //SearchWidget *searchWidget;
     InfoWidget *infoWidget;
 
     //AdvancedSearchWidget *advancedSearchWidget;
@@ -602,14 +631,16 @@ private:
     SetupDialog *setupDialog;
 
     // <CLUSTER>
-    DXClusterWidget *dxClusterWidget;
+
     bool dxClusterShowHF, dxClusterShowVHF, dxClusterShowWARC, dxClusterShowWorked, dxClusterShowConfirmed, dxClusterShowAnn, dxClusterShowWWV, dxClusterShowWCY;
     // </CLUSTER>
 
+   // DXClusterAssistant *dxClusterAssistant;
+
     // </UI>
     int infoTimeout; // timeout that temporary info will stay in the infobars
     QTimer *timer, *timerInfoBars;
-    QDateTime *dateTime, *dateTimeTemp;
+    std::unique_ptr<QDateTime> dateTime;
     bool yearChangedDuringModification;
     QString infoLabel1T, infoLabel2T;
 
@@ -631,13 +662,13 @@ private:
     bool qrzAutoChanging; //To remove the data coming from QRZ.com only when data is coming.
     QString mainQRZ, stationCallsign, operatorQRZ, dxLocator;
 
-    //int my_CQz, my_ITUz; Not used
+    int my_CQz, my_ITUz;
     int defaultMode, defaultBand, currentMode, currentModeShown, currentBand, currentBandShown;
     int currentEntity, previousEntity;
     bool InValidCharsInPrevCall;
     int currentLog; // This is to be able to manage multiple logs without showing
                     // them all at the same time.
-    int modifyingQSO; // When modifying, the QSO is saved here.
+    int modifyingQSOid; // When modifying, the QSO is saved here.
     int selectedYear;
     bool readingTheUI;  // While reading the data from UI after QSO intro or modificationthis is true
 
@@ -690,12 +721,10 @@ private:
 signals:
     void queryError(QString functionFailed, QString errorCodeS, QString nativeError, QString failedQuery); // To alert about any failed query execution
 
-
 protected:
     void keyPressEvent(QKeyEvent *event) override;
     void closeEvent(QCloseEvent *event) override;
     void showEvent(QShowEvent *event) override;
-
 };
 
 #endif
