@@ -26,18 +26,15 @@
  *                                                                           *
  *****************************************************************************/
 
+
 #include <QString>
 #include <QSqlQuery>
 #include <QDate>
 #include <QTime>
 #include <QObject>
-//#include <QDebug>
 #include "utilities.h"
 #include "klogdefinitions.h"
 #include "adif.h"
-#include "database.h"
-
-//#include <functional>
 
 class QSO : public QObject
 {
@@ -45,19 +42,23 @@ class QSO : public QObject
     friend class tst_QSO;
 
 public:
-    QSO();
+    QSO(QObject *parent = nullptr);
+    QSO(const QSO& other);
     ~QSO();
+    void operator=(QSO const &_other);
+
+    bool copy(const QSO& other);
     void setLogLevel (const DebugLogLevel _b);
     void setRealTime(const bool _rt);   // Not QSO info but KLog status
-    bool getRealTime();
+    bool getRealTime() const;
     void setManualMode(const bool _rt); // Not QSO info but KLog status
-    bool getManualMode();
+    bool getManualMode() const;
 
     void setBackup(const bool _rt);
-    bool getBackup();
+    bool getBackup() const;
 
     void setModifying(const bool _mod);
-    bool getModifying();
+    bool getModifying() const;
 
     bool setData(const QString &_adifPair);
     void clear();
@@ -65,30 +66,30 @@ public:
     void setLoTWUpdating(bool _lotw);
 
     bool setCall(const QString &_c);
-    QString getCall();
+    QString getCall() const;
     bool setBand(const QString &_c);
-    QString getBand();
+    QString getBand() const;
     bool setMode(const QString &_c);
-    QString getMode();
+    QString getMode() const;
 
     bool setDateTimeOn(const QDateTime &_c);
-    QDateTime getDateTimeOn();
+    QDateTime getDateTimeOn() const;
     bool setDate(const QDate &_c);
-    QDate getDate();
+    QDate getDate() const;
     bool setTimeOn(const QTime &_c);
-    QTime getTimeOn();
+    QTime getTimeOn() const;
 
     bool setQSOid(const int _i);
-    int getQSOid();
+    int getQSOid() const;
 
     bool setLogId(const int _i);
-    int getLogId();
+    int getLogId() const;
 
     bool setBandRX(const QString &_c);
-    QString getBandRX();
+    QString getBandRX() const;
 
     bool setRSTTX(const QString &_c);
-    QString getRSTTX();
+    QString getRSTTX() const;
     bool setRSTRX(const QString &_c);
     QString getRSTRX();
     bool setFreq(const double _f);
@@ -99,78 +100,82 @@ public:
     QString getQTH();
     bool setGridSquare(const QString &_c);
     QString getGridSquare();
+    bool setGridSquare_ext(const QString &_c);
+    QString getGridSquare_ext();
     bool setName(const QString &_c);
     QString getName();
     bool setRXPwr(const double _f);
-    double getRXPwr();
+    double getRXPwr() const;
 
     // QSL TAB
     bool setQSL_SENT(const QString &_c);
-    QString getQSL_SENT();
+    QString getQSL_SENT() const;
     bool setQSLSDate(const QDate &_c);
-    QDate getQSLSDate();
+    QDate getQSLSDate() const;
     bool setQSLSenVia(const QString &_qs);
-    QString getQSLSentVia();
+    QString getQSLSentVia() const;
 
     bool setQSL_RCVD(const QString &_c);
-    QString getQSL_RCVD();
+    QString getQSL_RCVD() const;
     bool setQSLRDate(const QDate &_c);
-    QDate getQSLRDate();
+    QDate getQSLRDate() const;
     bool setQSLRecVia(const QString &_qs);
-    QString getQSLRecVia();
+    QString getQSLRecVia() const;
 
     bool setQSLVia(const QString &_qs);
-    QString getQSLVia();
+    QString getQSLVia() const;
     bool setQSLMsg(const QString &_qs);
-    QString getQSLMsg();
-
+    QString getQSLMsg() const;
 
     // eQSL tab
     bool setClubLogStatus(const QString &_c);
-    QString getClubLogStatus();
+    QString getClubLogStatus() const;
+
     bool setClubLogDate(const QDate &_c);
-    QDate getClubLogDate();
+    bool setClubLogDate(const QString& data);
+
+    QDate getClubLogDate() const;
 
     bool setEQSLQSL_RCVD(const QString &_c);
-    QString getEQSLQSL_RCVD();
+    QString getEQSLQSL_RCVD() const;
     bool setEQSLQSL_SENT(const QString &_c);
-    QString getEQSLQSL_SENT();
+    QString getEQSLQSL_SENT() const;
     bool setEQSLQSLRDate(const QDate &_c);
-    QDate getEQSLQSLRDate();
+    QDate getEQSLQSLRDate() const;
     bool setEQSLQSLSDate(const QDate &_c);
-    QDate getEQSLQSLSDate();
+    QDate getEQSLQSLSDate() const;
 
     bool setLoTWQSL_RCVD(const QString &_c);
-    QString getLoTWQSL_RCVD();
+    QString getLoTWQSL_RCVD() const;
     bool setLoTWQSL_SENT(const QString &_c);
-    QString getLoTWQSL_SENT();
+    QString getLoTWQSL_SENT() const;
     bool setLoTWQSLRDate(const QDate &_c);
-    QDate getLoTWQSLRDate();
+    QDate getLoTWQSLRDate() const;
     bool setLoTWQSLSDate(const QDate &_c);
-    QDate getLoTWQSLSDate();
+    QDate getLoTWQSLSDate() const;
 
     bool setQRZCOMStatus(const QString &_c);
-    QString getQRZCOMStatus();
+    QString getQRZCOMStatus() const;
     bool setQRZCOMDate(const QDate &_c);
-    QDate getQRZCOMDate();
+    QDate getQRZCOMDate() const;
 
     void setDefaultEQSLSentServices(const bool _send);
 
     // Comment Tab
     bool setComment(const QString &_c);
-    QString getComment();
+    QString getComment() const;
     bool setKeepComment(bool _k);
-    bool getKeepComment();
+    bool getKeepComment() const;
 
     // Others Tab
     bool setDXCC(const int _i);
-    int getDXCC();
+    int getDXCC() const;
     bool setPropMode(const QString &_c);
-    QString getPropMode();
+    QString getPropMode() const;
     bool setSOTA_REF(const QString &_c);
-    QString getSOTA_REF();
+    QString getSOTA_REF() const;
     bool setAge(const double _c);
-    double getAge();
+    double getAge() const;
     bool setIOTA(const QString &_c);
     QString getIOTA();
     bool setKeepOthers(bool _k);
@@ -178,211 +183,240 @@ public:
     bool setVUCCGrids(const QString &_c);
     QString getVUCCGrids();
 
+    bool setPOTA_Ref(const QString &_c);
+    QString getPOTA_Ref();
+    bool setWWFF_Ref(const QString &_c);
+    QString getWWFF_Ref() const;
+    bool setSIG(const QString &_c);
+    QString getSIG() const;
+    bool setSIG_INFO(const QString &_c);
+    QString getSIG_INFO() const;
 
     // My data Tab
     bool setTXPwr(double _f);
-    double getTXPwr();
+    double getTXPwr() const;
     bool setOperatorCallsign(const QString &_c);
-    QString getOperatorCallsign();
+    QString getOperatorCallsign() const;
     bool setStationCallsign(const QString &_c);
-    QString getStationCallsign();
+    QString getStationCallsign() const;
     bool setMyGridSquare(const QString &_c);
-    QString getMyGridSquare();
+    QString getMyGridSquare() const;
+    bool setMyGridSquare_ext(const QString &_c);
+    QString getMyGridSquare_ext() const;
     bool setKeepMyData(bool _k);
-    bool getKeepMyData();
+    bool getKeepMyData() const;
+
     bool setMySOTA_REF(const QString &_c);
-    QString getMySOTA_REF();
+    QString getMySOTA_REF() const;
     bool setMyRig(const QString &_c);
-    QString getMyRig();
+    QString getMyRig() const;
     bool setMyAntenna(const QString &_c);
-    QString getMyAntenna();
-    bool setMyArrlSect(const QString &_c);
-    QString getMyArrlSect();
+    QString getMyAntenna() const;
     bool setMyVUCCGrids(const QString &_c);
-    QString getMyVUCCGrids();
+    QString getMyVUCCGrids() const;
+
+    bool setMyPOTA_Ref(const QString &_c);
+    QString getMyPOTA_Ref() const;
+    bool setMyWWFF_Ref(const QString &_c);
+    QString getMyWWFF_Ref() const;
+
+
+
     // Satellite Tab
     bool setSatName(const QString &_c);
-    QString getSatName();
+    QString getSatName() const;
     bool setSatMode(const QString &_c);
-    QString getSatMode();
+    QString getSatMode() const;
     bool setKeepSatTab(bool _k);
-    bool getKeepSatTab();
+    bool getKeepSatTab() const;
 
     bool setAddress(const QString &_c);
-    QString getAddress();
+    QString getAddress() const;
+    bool setAltitude(const double _c);
+    double getAltitude() const;
     bool setA_Index(const int _i);
-    int getA_Index();
+    int getA_Index() const;
     bool setAnt_az(const double _c);
-    double getAnt_az();
+    double getAnt_az() const;
     bool setAnt_el(const double _c);
-    double getAnt_el();
+    double getAnt_el() const;
     bool setAnt_Path(const QString &_c);
-    QString getAnt_Path();
+    QString getAnt_Path() const;
     bool setARRL_Sect(const QString &_c);
-    QString getARRL_Sect();
+    QString getARRL_Sect() const;
     bool setCheck(const QString &_c);
-    QString getCheck();
+    QString getCheck() const;
     bool setClass(const QString &_c);
-    QString getClass();
-    bool setClublogQSOUpdateDate(const QDate &_c);
-    QDate getClublogQSOUpdateDate();
+    QString getClass() const;
     bool setContinent(const QString &_c);
-    QString getContinent();
+    QString getContinent() const;
     bool setDistance(const double _i);
-    double getDistance();
+    double getDistance() const;
     bool setOwnerCallsign(const QString &_c);
-    QString getOwnerCallsign();
+    QString getOwnerCallsign() const;
     bool setEQ_Call(const QString &_c); // Contacted station owner
-    QString getEQ_Call();               // Contacted station owner
+    QString getEQ_Call() const;               // Contacted station owner
     bool setHRDUpdateDate(const QDate &_c);
-    QDate getHRDUpdateDate();
+    QDate getHRDUpdateDate() const;
     bool setHRDLogStatus(const QString &_c);
-    QString getHRDLogStatus();
+    QString getHRDLogStatus() const;
+
+    bool setHamLogEUStatus(const QString &_c);
+    QString getHamLogEUStatus() const;
+    bool setHamLogEUUpdateDate(const QDate &_c);
+    QDate getHamLogEUUpdateDate() const;
+    bool setHamQTHStatus(const QString &_c);
+    QString getHamQTHStatus()  const;
+    bool setHamQTHUpdateDate(const QDate &_c);
+    QDate getHamQTHUpdateDate() const;
+
+
     bool setK_Index(const int _i);
-    int getK_Index();
+    int getK_Index() const;
     bool setDateOff(const QDate &_c);
-    QDate getDateOff();
+    QDate getDateOff() const;
     bool setTimeOff(const QTime &_c);
-    QTime getTimeOff();
+    QTime getTimeOff() const;
     bool setRig(const QString &_c);
-    QString getRig();
+    QString getRig() const;
     bool setCountry(const QString &_c);
-    QString getCountry();
+    QString getCountry() const;
     bool setAwardGranted(const QString &_c);
-    QString getAwardGranted();
+    QString getAwardGranted() const;
     bool setAwardSubmitted(const QString &_c);
-    QString getAwardSubmitted();
+    QString getAwardSubmitted() const;
     bool setCounty(const QString &_c);
-    QString getCounty();
+    QString getCounty() const;
     bool setContactedOperator(const QString &_c);
-    QString getContactedOperator();
+    QString getContactedOperator() const;
     bool setContestID(const QString &_c);
-    QString getContestID();
+    QString getContestID() const;
     bool setCQZone(const int _i);
-    int getCQZone();
+    int getCQZone() const;
     bool setCreditGranted(const QString &_c);
-    QString getCreditGranted();
+    QString getCreditGranted() const;
     bool setCreditSubmitted(const QString &_c);
-    QString getCreditSubmitted();
+    QString getCreditSubmitted() const;
     bool setDarcDok(const QString &_c);
-    QString getDarcDok();
+    QString getDarcDok() const;
     bool setEmail(const QString &_c);
-    QString getEmail();
+    QString getEmail() const;
     bool setFists(const int _i);
-    int getFists();
+    int getFists() const;
     bool setFistsCC(const int _i);
-    int getFistsCC();
+    int getFistsCC() const;
     bool setForceInit(bool _k);
-    bool getForceInit();
+    bool getForceInit() const;
     bool setIotaID(const int _i);
-    int getIotaID();
+    int getIotaID() const;
     bool setItuZone(const int _i);
-    int getItuZone();
+    int getItuZone() const;
     bool setLatitude(const QString &_c);
-    QString getLatitude();
+    QString getLatitude() const;
     bool setLongitude(const QString &_c);
-    QString getLongitude();
+    QString getLongitude() const;
     bool setQSOComplete(const QString &_c);         // Receives valid ADIF data (Y/N/NIL/?)
-    QString getQSOComplete();
+    QString getQSOComplete() const;
     bool setNrBursts(const int _i);
-    int getNrBursts();
+    int getNrBursts() const;
     bool setMaxBursts(const int _i);
-    int getMaxBursts();
+    int getMaxBursts() const;
     bool setNrPings(const int _i);
-    int getNrPings();
+    int getNrPings() const;
     bool setMsShower(const QString &_c);
-    QString getMsShower();
+    QString getMsShower() const;
     bool setQSORandom(bool _k);
-    bool getQSORandom();
+    bool getQSORandom() const;
+    bool setMyAltitude(const double _c);
+    double getMyAltitude() const;
+    bool setMyARRL_Sect(const QString &_c);
+    QString getMyARRL_Sect() const;
     bool setMyCity(const QString &_c);
-    QString getMyCity();
+    QString getMyCity() const;
     bool setMyCounty(const QString &_c);
-    QString getMyCounty();
+    QString getMyCounty() const;
     bool setMyCountry(const QString &_c);
-    QString getMyCountry();
+    QString getMyCountry() const;
     bool setMyCQZone(const int _i);
-    int getMyCQZone();
+    int getMyCQZone() const;
     bool setMyDXCC(const int _i);
-    int getMyDXCC();
+    int getMyDXCC() const;
     bool setMyFists(const int _c);
-    int getMyFists();
+    int getMyFists() const;
     bool setMyIOTA(const QString &_c);
-    QString getMyIOTA();
+    QString getMyIOTA() const;
     bool setMyIotaID(const int _i);
-    int getMyIotaID();
+    int getMyIotaID() const;
     bool setMyITUZone(const int _i);
-    int getMyITUZone();
+    int getMyITUZone() const;
     bool setMyLatitude(const QString &_c);
-    QString getMyLatitude();
+    QString getMyLatitude() const;
     bool setMyLongitude(const QString &_c);
-    QString getMyLongitude();
+    QString getMyLongitude() const;
     bool setMyName(const QString &_c);
-    QString getMyName();
+    QString getMyName() const;
     bool setMyPostalCode(const QString &_c);
-    QString getMyPostalCode();
+    QString getMyPostalCode() const;
     bool setMySig(const QString &_c);
-    QString getMySig();
+    QString getMySig() const;
     bool setMySigInfo(const QString &_c);
     QString getMySigInfo();
     bool setMyState(const QString &_c);
-    QString getMyState();
+    QString getMyState() const;
     bool setMyStreet(const QString &_c);
-    QString getMyStreet();
+    QString getMyStreet() const;
     bool setMyUsacaCounties(const QString &_c);
-    QString getMyUsacaCounties();
+    QString getMyUsacaCounties() const;
     bool setNotes(const QString &_c);
-    QString getNotes();
-    bool setPrefix(const QString &_c);
-    QString getPrefix();
+    QString getNotes() const;
+    bool setPrefix(const QString &_c);          // ADIF - PFX   - WPX Prefix
+    QString getPrefix() const;
     bool setPrecedence(const QString &_c);
-    QString getPrecedence();
+    QString getPrecedence() const;
     bool setPublicKey(const QString &_c);
-    QString getPublicKey();
+    QString getPublicKey() const;
     bool setRegion(const QString &_c);
-    QString getRegion();
+    QString getRegion() const;
     bool setTenTen(const int _i);
-    int getTenTen();
+    int getTenTen() const;
     bool setSFI(const int _i);
-    int getSFI();
-    bool setSig(const QString &_c);
-    QString getSig();
-    bool setSigInfo(const QString &_c);
-    QString getSigInfo();
+    int getSFI() const;
+
     bool setSilentKey(bool _k);
-    bool getSilentKey();
+    bool getSilentKey() const;
     bool setSkcc(const QString &_c);
-    QString getSkcc();
+    QString getSkcc() const;
     bool setSrx(const int _i);
-    int getSrx();
+    int getSrx() const;
     bool setSrxString(const QString &_c);
-    QString getSrxString();
-    bool setState(const QString &_c);
-    QString getState();
+    QString getSrxString() const;
+    bool setState(const QString &_c);       // ADIF - STATE - Primary subdivision
+    QString getState() const;
     bool setStx(const int _i);
-    int getStx();
+    int getStx() const;
     bool setStxString(const QString &_c);
-    QString getStxString();
+    QString getStxString() const;
     //bool setSubmode(const QString &_c, bool requestMode = false);
     bool setSubmode(const QString &_c);
-    QString getSubmode();
+    QString getSubmode() const;
     bool setSwl(bool _k);
-    bool getSwl();
+    bool getSwl() const;
     bool setUksmg(const int _i);
-    int getUksmg();
+    int getUksmg() const;
     bool setUsacaCounties(const QString &_c);
-    QString getUsacaCounties();
+    QString getUsacaCounties() const;
     bool setVeProv(const QString &_c);
-    QString getVeProv();
+    QString getVeProv() const;
     bool setWeb(const QString &_c);
-    QString getWeb();
-    bool setWwffRef(const QString &_c);
-    QString getWwffRef();
-    bool setMyWwffRef(const QString &_c);
-    QString getMyWwffRef();
+    QString getWeb() const;
+
+
+
     int toDB(int _qsoId = 0);
+    bool fromDB(int _qsoId);
     //bool add();
     //bool modify(const int _qsoId);
-    bool isComplete();
+    bool isComplete() const;
     QString getADIF();
     QString getBandNameFromFreq(const double _n); // Should be push out of this class
 
@@ -393,24 +427,36 @@ signals:
     void queryError(QString functionFailed, QString errorCodeS, QString nativeError, QString failedQuery); // To alert about any failed query execution
 
 private:
+    //QTime startT;
+    bool isValidCall() const;
+    bool isValidBand() const;
+    bool isValidMode() const;
+    bool isValidDateTime() const;
+
     void logEvent(const QString &_func, const QString &_msg, DebugLogLevel _level);
     QString getAddQueryString();
     QString getModifyQueryString();
     QSqlQuery getPreparedQuery(const QString &_s);
     int getBandIdFromBandName(bool _rxBand=false);   // if rxBand = true, it will chec the bandRX
-    int getModeIdFromModeName();
+    QString getBandNameFromBandId(int bandId);
+    int getModeIdFromModeName();                // It really returns submode
+    QString getModeNameFromModeId(int _modeId, bool _submode=true);
     void setBandFromFreq(const double _fr, bool TX = true);
-    DataBase *db;
+    //enum QSOStatus {unknown, ATNO, needed, worked, confirmed, dupe};
+    //DataBase *db;
 
 
     int qsoId, logId, dxcc, a_index, k_index, cqz, fists, fists_cc, my_fists, iota_ID, itu_zone, nr_bursts, max_bursts, nr_pings, my_cqz, my_itu_zone, my_dxcc, my_iota_ID, srx, stx, uksmg;
     int ten_ten, sfi;
-    double freq_tx, freq_rx, pwr_rx, pwr_tx, age, ant_el, ant_az, distance;
+    double freq_tx, freq_rx, pwr_rx, pwr_tx, age, ant_el, ant_az, distance, altitude, my_altitude;
 
-    QString satName, satMode, callsign, stationCallsign, operatorCall, propMode, band, band_rx, mode, gridsquare, my_gridsquare, qth, name, RST_tx, RST_rx;
+    QString satName, satMode, callsign, stationCallsign, operatorCall, propMode, band, band_rx, mode, gridsquare, my_gridsquare, gridsquare_ext, my_gridsquare_ext, qth, name, RST_tx, RST_rx;
     QString qsl_rcvd, qsl_sent, qslSenVia, qslRecVia, qslVia, check, clase;
     QString lotw_qsl_sent, lotw_qsl_rcvd, sota_ref, my_sota_ref, my_rig, my_antenna, my_arrl_sect, vucc_grids, my_vucc_grids;
+    QString pota_ref,  my_pota_ref;
     QString clublog_status, hrdlog_status, QRZCom_status;
+    QString hamlogeu_status, hamqth_status;
+
     QString eqsl_qsl_sent, eqsl_qsl_rcvd;
     QString comment, address, ant_path, arrl_sect, continent, rig, country, award_granted, award_submitted, county, contacted_op, contacted_owner, contest_id;
     QString credit_granted, credit_submitted,darc_dok, email, qso_complete, usaca_counties, ve_prov, web, wwff_ref;
@@ -421,7 +467,9 @@ private:
     QDateTime qso_dateTime;
 
     QDate QSLRDate, QSLSDate, QSLLoTWRDate, QSLLoTWSDate, qso_date_off;
-    QDate eQSLRDate, eQSLSDate, clublogDate,clublogQSOUpdateDate, hrdlogUploadDate;
+    QDate eQSLRDate, eQSLSDate, clublogQSOUpdateDate, hrdlogUploadDate;
+    QDate hamlogeuUpdateDate, hamqthUpdateDate;
+
     QDate QRZComDate;
 
     bool backup, lotwUpdating, realTime, manualMode, silent_key;
@@ -439,6 +487,7 @@ private:
 
     //Overloaded helper functions to accept string data for nonstring functions
     bool setAge(const QString &data);
+    bool setAltitude(const QString &data);
     bool setA_Index(const QString &data);
     bool setAnt_az(const QString &data);
     bool setAnt_el(const QString &data);
@@ -452,6 +501,7 @@ private:
     bool setItuZone(const QString &data);
     bool setK_Index(const QString &data);
     bool setMaxBursts(const QString &data);
+    bool setMyAltitude(const QString &data);
     bool setMyCQZone(const QString &data);
     bool setMyDXCC(const QString &data);
     bool setMyIotaID(const QString &data);
@@ -469,11 +519,12 @@ private:
     bool setRXPwr(const QString& data);
     bool setTXPwr(const QString& data);
 
-    bool setClublogQSOUpdateDate(const QString& data);
     bool setEQSLQSLRDate(const QString& data);
     bool setEQSLQSLSDate(const QString& data);
     bool setForceInit(const QString& data);
     bool setHRDUpdateDate(const QString& data);
+    bool setHamLogEUUpdateDate(const QString& data);
+    bool setHamQTHUpdateDate(const QString& data);
     bool setLoTWQSLRDate(const QString& data);
     bool setLoTWQSLSDate(const QString& data);
     bool setQRZCOMDate(const QString& data);
@@ -490,6 +541,8 @@ private:
     bool setLoTWQSLRDate2(const QString& data);
     bool setLoTWQSLSDate1(const QString& data);
     bool setLoTWQSLSDate2(const QString& data);
+
+    int getLastInsertedQSO();   // just a query to get the latest inserted QSO
 };
 
 #endif // QSO_H
