@@ -26,10 +26,12 @@
 
 #include "searchmodel.h"
 
-SearchModel::SearchModel(DataProxy_SQLite *dp, QObject *parent):QSqlRelationalTableModel(parent)
+SearchModel::SearchModel(Awards *awards, QObject *parent):
+    QSqlRelationalTableModel(parent),
+    award(awards) // Correctly initialize 'award' instead of 'awards'
 {
     //qDebug() << "SearchModel::SearchModel " ;
-    dataProxy = dp;
+    dataProxy = awards->dataProxy;
     stationCallsignInHeader = true;
     setTable("log");
     setEditStrategy(QSqlTableModel::OnFieldChange);
@@ -38,7 +40,7 @@ SearchModel::SearchModel(DataProxy_SQLite *dp, QObject *parent):QSqlRelationalTa
     modeid = -1;
     logn = -1;
 
-    award = new Awards(dataProxy, Q_FUNC_INFO);
+    //award = new Awards(dataProxy, Q_FUNC_INFO);
 
     //qDebug() << "SearchModel::SearchModel: Rows obtained: " << QString::number(rowCount()) ;
     //qDebug() << "SearchModel::SearchModel - END" ;
@@ -46,8 +48,8 @@ SearchModel::SearchModel(DataProxy_SQLite *dp, QObject *parent):QSqlRelationalTa
 
 SearchModel::~SearchModel()
 {
-    delete(dataProxy);
-    delete(award);
+    //delete(dataProxy);
+    //delete(award);
 }
 
 void SearchModel::setDXCCColumn(const int _i)
@@ -105,9 +107,8 @@ This should be coherent with the treeview
     setFilter(stringQuery);
     //setColumnsToDX();
     select();
-
-
 }
+
 void SearchModel::setStationCallsignInHeader(const bool _s)
 {
     stationCallsignInHeader = _s;
@@ -173,13 +174,13 @@ void SearchModel::setStationCallsignInHeader(const bool _s)
      setSort(nameCol, Qt::AscendingOrder);
  }
 */
- void SearchModel::setFilterString(const QString &_st)
+
+void SearchModel::setFilterString(const QString &_st)
  {
     //qDebug() << "SearchModel::setFilterString: " << _st;
     setFilter(_st);
     select();
     //qDebug() << "SearchModel::setFilterString: SelectStatement: " << selectStatement ();
-
  }
 
  void SearchModel::update()
@@ -187,7 +188,7 @@ void SearchModel::setStationCallsignInHeader(const bool _s)
      select();
  }
 
- void SearchModel::setColors (const QString &_newOne, const QString &_needed, const QString &_worked, const QString &_confirmed, const QString &_default)
+ void SearchModel::setColors (const QColor &_newOne, const QColor &_needed, const QColor &_worked, const QColor &_confirmed, const QColor &_default)
  {
         //qDebug() << "DXClusterWidget::setColors: " << _newOne << "/" << _needed << "/" << _worked << "/" << _confirmed << "/" << _default;
      // Just to pass the colors to the awards class
@@ -200,22 +201,13 @@ QVariant SearchModel::data( const QModelIndex &index, int role ) const
      {
          if ( index.column() == 2 )
          {
-             //QString _qrz = data(index, Qt::DisplayRole).toString();
-             //From Search QSO to QSL: q << _call << bandid << _mode << QString::number(currentLog);
+             EntityStatus _entityStatus;
+            _entityStatus.dxcc  = index.siblingAtColumn(dxcc).data().toInt();
+            _entityStatus.bandId    = index.siblingAtColumn(bandid).data().toInt();
+            _entityStatus.modeId    = index.siblingAtColumn(modeid).data().toInt();
+            _entityStatus.logId       = index.siblingAtColumn(logn).data().toInt();
 
-             QString _dxcc = index.siblingAtColumn(dxcc).data().toString();
-             QString _bandid = index.siblingAtColumn(bandid).data().toString();
-             QString _modeid = index.siblingAtColumn(modeid).data().toString();
-             QString _log = index.siblingAtColumn(logn).data().toString();
-
-             QStringList qs;
-             qs.clear();
-             qs << _dxcc << QString::number(dataProxy->getIdFromBandName(_bandid)) << "-1" << _log ;
-
-             //spotBand = QString::number(world->getBandIdFromFreq(  dxFrequency  ) );
-             //qs << QString::number(dxEntity) << spotBand << "-1" << QString::number(currentLog) ;
-
-            return QVariant( award->getQRZDXStatusColor(qs) );
+            return QVariant( award->getQRZDXStatusColor(_entityStatus) );
             // return QVariant( QColor( Qt::red ) );
          }
          return QVariant( QColor( Qt::black ) );
