@@ -25,20 +25,23 @@
  *****************************************************************************/
 
 #include "searchwidget.h"
+#include "callsign.h"
 
-SearchWidget::SearchWidget(DataProxy_SQLite *dp, QWidget *parent) :
-    QWidget(parent)
+SearchWidget::SearchWidget(Awards *awards, QWidget *parent) :
+    QWidget(parent),
+    awards(awards) // Initialize Awards reference
 {
     //qDebug() << "SearchWidget::SearchWidget"  ;
     searchBoxLineEdit = new QLineEdit;
-    dataProxy = dp;
+    dataProxy = awards->dataProxy;
     delayInputTimer = new QTimer;
-    searchWindow = new SearchWindow(dataProxy, this);
+    searchWindow = std::make_unique<SearchWindow>(awards, this);
+    //searchWindow = new SearchWindow(dataProxy, this);
 
-    awards = new Awards(dataProxy, Q_FUNC_INFO);
+    //awards = new Awards(dataProxy, Q_FUNC_INFO);
     util = new Utilities(Q_FUNC_INFO);
-    util->setLongPrefixes(dataProxy->getLongPrefixes());
-    util->setSpecialCalls(dataProxy->getSpecialCallsigns());
+    //util->setLongPrefixes(dataProxy->getLongPrefixes());
+    //util->setSpecialCalls(dataProxy->getSpecialCallsigns());
     filemanager = new FileManager(dataProxy);
     filemanager->init();
 
@@ -65,9 +68,9 @@ SearchWidget::SearchWidget(DataProxy_SQLite *dp, QWidget *parent) :
 
 SearchWidget::~SearchWidget()
 {
-    delete(dataProxy);
-    delete(searchWindow);
-    delete(awards);
+    //delete(dataProxy);
+    //delete(searchWindow);
+    //delete(awards);
     delete(util);
     delete(filemanager);
     delete(world);
@@ -138,13 +141,13 @@ void SearchWidget::showQSOs(QList<int> qsoIdList)
     //qDebug() << "SearchWidget::showQSOs filter: " << filter;
 
     searchWindow->setFilterString(filter);
-
 }
 
 
 void SearchWidget::setStationCallsign(const QString &_st)
 {
-    if (util->isValidCall(_st))
+    Callsign callsign(_st);
+    if (callsign.isValid())
     {
         mainStationCallsign = _st;
         selectStationCallSign();
@@ -198,7 +201,7 @@ void SearchWidget::createUI()
     dxUpRightSearchTabLayout->addLayout(dxUpRightSearchTopLayout);
     dxUpRightSearchTabLayout->addLayout(dxUpRightButtonsLayout);
     //dxUpRightSearchTabLayout->addWidget(searchResultsTreeWidget);
-    dxUpRightSearchTabLayout->addWidget(searchWindow);
+    dxUpRightSearchTabLayout->addWidget(searchWindow.get());
 
     setLayout(dxUpRightSearchTabLayout);
 
@@ -217,11 +220,10 @@ void SearchWidget::createUI()
     connect(stationCallsignComboBox, SIGNAL(currentIndexChanged (int)), this, SLOT(slotStationCallsignChanged() ) ) ;
     connect(searchAllQCheckbox, SIGNAL(toggled(bool)), this, SLOT(slotQCheckboxToggled() ) ) ;
 
-    connect(searchWindow, SIGNAL( actionQSODoubleClicked(int)), this, SLOT(slotQSOToEditFromSearch(int)));
-    connect(searchWindow, SIGNAL( actionDeleteQSO(int)), this, SLOT( slotQsoDeleteFromSearch(int) ));
-    connect(searchWindow, SIGNAL( updateSearchLineEdit()), this, SLOT( slotSearchBoxTextChanged() ));
-    connect(searchWindow, SIGNAL( requestFocus()), this, SLOT( slotRequestFocus() ));
-
+    connect(searchWindow.get(), SIGNAL( actionQSODoubleClicked(int)), this, SLOT(slotQSOToEditFromSearch(int)));
+    connect(searchWindow.get(), SIGNAL( actionDeleteQSO(int)), this, SLOT( slotQsoDeleteFromSearch(int) ));
+    connect(searchWindow.get(), SIGNAL( updateSearchLineEdit()), this, SLOT( slotSearchBoxTextChanged() ));
+    connect(searchWindow.get(), SIGNAL( requestFocus()), this, SLOT( slotRequestFocus() ));
 }
 
 
@@ -252,7 +254,6 @@ void SearchWidget::slotQsoDeleteFromSearch(const int _qsoId)
     QString _qrz = dataProxy->getCallFromId(QSOid);
     if (_qrz.length()>=3)
     {
-
         QString message = QString(tr("You have requested to delete the QSO with: %1").arg(_qrz));
 
         QMessageBox msgBox;
@@ -283,7 +284,6 @@ void SearchWidget::slotQsoDeleteFromSearch(const int _qsoId)
                 //dxccStatusWidget->refresh();
                 //awards->recalculateAwards();
                 emit updateAwards();
-
             }
             else
             {
@@ -298,7 +298,6 @@ void SearchWidget::slotQsoDeleteFromSearch(const int _qsoId)
               // should never be reached
             break;
         }
-
     }
     else
     {
@@ -490,7 +489,6 @@ void SearchWidget::slotQSLSentViaDirectFromSearch()
     }
 
     //qslSentViaDirect(_qsoId);
-
 }
 
 /*
@@ -593,12 +591,12 @@ void SearchWidget::slotDoubleClickSearch(QTreeWidgetItem * item, int)
     {}
 
 }
-    */
+*/
+
 void SearchWidget::setNeedingQSL(bool const _q)
 {
     qslingNeeded = _q;
     searchWindow->setNeedingQSL(qslingNeeded);
-
 }
 
 void SearchWidget::slotSearchBoxTextChanged()
@@ -697,8 +695,6 @@ void SearchWidget::slotSearchBoxTextChanged()
     }
 
     searchBoxLineEdit->setCursorPosition(cursorP);
-
-
 }
 
 void SearchWidget::setModelFilter()
@@ -706,7 +702,6 @@ void SearchWidget::setModelFilter()
     //qDebug() << "SearchWidget::setModelFilter - callFilter        = "  << callFilter ;
     //qDebug() << "SearchWidget::setModelFilter - stationCallFilter = " << stationCallsignFilter  ;
     //qDebug() << "SearchWidget::setModelFilter - currentLog        = " << currentLogFilter;
-
     QString filter;
     filter = QString();
 
@@ -768,7 +763,6 @@ void SearchWidget::slotSearchBoxSelectAllButtonClicked()
         searchSelectAllClicked = false;
         searchWindow->clearSelection();
         searchBoxSelectAllButton->setText(tr("&Select All"));
-
     }
     else
     {
@@ -776,9 +770,7 @@ void SearchWidget::slotSearchBoxSelectAllButtonClicked()
         searchSelectAllClicked = true;
         searchWindow->selectAll();
         searchBoxSelectAllButton->setText(tr("&Clear selection"));
-
     }
-
 }
 
 void SearchWidget::slotSearchBoxReSearchButtonClicked()
@@ -826,7 +818,7 @@ void SearchWidget::slotSearchExportButtonClicked()
         if (!sqlOK)
         {
             //qDebug() << "SearchWidget::slotSearchExportButtonClicked: query executed-error: " << query.lastError();
-            emit queryError(Q_FUNC_INFO, query.lastError().databaseText(), query.lastError().nativeErrorCode(), query.lastQuery());
+            emit queryError(Q_FUNC_INFO, query.lastError().databaseText(), query.lastError().text(), query.lastQuery());
         }
          //qDebug() << "SearchWidget::slotSearchExportButtonClicked: query executed: " << query.lastQuery();
         itemsSelected = true;
@@ -869,7 +861,7 @@ void SearchWidget::slotToolSearchNeededQSLRequested()
     searchWindow->slotToolSearchQSL(3);
 }
 
-void SearchWidget::setColors (const QString &_newOne, const QString &_needed, const QString &_worked, const QString &_confirmed, const QString &_default)
+void SearchWidget::setColors(const QColor &_newOne, const QColor &_needed, const QColor &_worked, const QColor &_confirmed, const QColor &_default)
 {
        //qDebug() << "DXClusterWidget::setColors: " << _newOne << "/" << _needed << "/" << _worked << "/" << _confirmed << "/" << _default;
     // Just to pass the colors to the awards class
