@@ -25,6 +25,8 @@
  *****************************************************************************/
 
 #include "setupdialog.h"
+#include "callsign.h"
+
 //#include <QDebug>
 
 /*
@@ -120,8 +122,8 @@ void SetupDialog::init(const QString &_softwareVersion, const int _page, const b
     version = QString();
     pageRequested = 0;
     //qDebug() << Q_FUNC_INFO << "00";
-    util->setLongPrefixes(dataProxy->getLongPrefixes());
-    util->setSpecialCalls(dataProxy->getSpecialCallsigns());
+    //util->setLongPrefixes(dataProxy->getLongPrefixes());
+    //util->setSpecialCalls(dataProxy->getSpecialCallsigns());
     userDataPage->setPrefixes ();
     //qDebug() << Q_FUNC_INFO << "000";
     firstTime = !_alreadyConfigured;
@@ -131,7 +133,7 @@ void SetupDialog::init(const QString &_softwareVersion, const int _page, const b
     }
     version = _softwareVersion;
     pageRequested = _page;
-
+    logViewPage->init();
     slotReadConfigData();
 
     if ((pageRequested==6) && (logsPageTabN>0))// The user is opening a new log
@@ -177,6 +179,7 @@ void SetupDialog::connectActions()
     connect (userDataPage, SIGNAL(operatorsSignal(QString)), this, SLOT(slotSetOperators(QString)));
     connect (userDataPage, SIGNAL(enterKey()), this, SLOT(slotOkButtonClicked()));
     connect (eLogPage, SIGNAL(enterKey()), this, SLOT(slotOkButtonClicked()));
+    connect (colorsPage, SIGNAL(darkModeChanged(bool)), this, SLOT(slotDarkModeChanged(bool)));
 
     logEvent(Q_FUNC_INFO, "END", Debug);
 }
@@ -185,29 +188,35 @@ void SetupDialog::connectActions()
 //{
     //emit qrzcomAuto(_b);
 //}
+void SetupDialog::slotDarkModeChanged(const bool _dm)
+{
+    emit darkModeChanged(_dm);
+}
 
 void SetupDialog::setData(const QString &_softwareVersion, const int _page, const bool _alreadyConfigured)
 {
-       //qDebug() << "SetupDialog::setData: " << _softwareVersion << "/" << QString::number(_page);
+    //qDebug() << Q_FUNC_INFO << " - " << _softwareVersion << "/" << QString::number(_page);
     logEvent(Q_FUNC_INFO, "Start", Debug);
     nolog = !(haveAtleastOneLog());
     firstTime = !_alreadyConfigured;
     if (firstTime)
     {
-         //qDebug() << Q_FUNC_INFO << " - Running for the FIRST time";
+        //qDebug() << Q_FUNC_INFO << " - Running for the FIRST time";
     }
     else
     {
-         //qDebug() << Q_FUNC_INFO << " - Running NOT for the FIRST time";
+        //qDebug() << Q_FUNC_INFO << " - Running NOT for the FIRST time";
         miscPage->setUseDefaultDBPath(miscPage->getDefaultDBPath());
     }
-
+    //qDebug() << Q_FUNC_INFO << " - 10";
     setSoftVersion(_softwareVersion);
+    //qDebug() << Q_FUNC_INFO << " - 20";
     slotReadConfigData ();
+    //qDebug() << Q_FUNC_INFO << " - 30";
     setPage(_page);
-    //removeBandModeDuplicates();
+    //qDebug() << Q_FUNC_INFO << " - 40";
     logEvent(Q_FUNC_INFO, "END", Debug);
-       //qDebug() << "SetupDialog::setData - END";
+    //qDebug() << Q_FUNC_INFO << " - END";
 }
 
 void SetupDialog::setSoftVersion(const QString &_softwareVersion)
@@ -339,19 +348,19 @@ bool SetupDialog::loadSettings()
     //qDebug() << Q_FUNC_INFO << " - Start";
     if (!QFile::exists(util->getCfgFile ()))
     {
-         //qDebug() << Q_FUNC_INFO << " - Nothing to load";
+        //qDebug() << Q_FUNC_INFO << " - Nothing to load";
         return false;
     }
     QSettings settings(util->getCfgFile (), QSettings::IniFormat);
 
-     //qDebug() << Q_FUNC_INFO << " - 10 - General";
+    //qDebug() << Q_FUNC_INFO << " - 10 - General";
     version = settings.value ("Version").toString();
     //latestBackup = settings.value ("LatestBackup").toString ();
 
-     //qDebug() << Q_FUNC_INFO << " - 20 - user";
+    //qDebug() << Q_FUNC_INFO << " - 20 - user";
     userDataPage->loadSettings();
 
-     //qDebug() << Q_FUNC_INFO << " - 30 - bands";
+    //qDebug() << Q_FUNC_INFO << " - 30 - bands";
     settings.beginGroup ("BandMode");
 
     QStringList listAux;
@@ -423,8 +432,10 @@ void SetupDialog::slotOkButtonClicked()
         emit debugLog (Q_FUNC_INFO, "END-1", logLevel);
         return;
     }
+    Callsign callsign(userDataPage->getMainCallsign());
 
-    if (!util->isValidCall(userDataPage->getMainCallsign())){ //
+    if (!callsign.isValid())
+    {
         QMessageBox msgBox;
         msgBox.setIcon(QMessageBox::Information);
         msgBox.setText(tr("You need to enter at least a valid callsign."));
@@ -477,8 +488,9 @@ void SetupDialog::slotReadConfigData()
         bandModePage->setActiveBands(bands);
         //logViewPage->setActiveFields(logViewFields);
     }
+    //qDebug() << Q_FUNC_INFO << " - 30";
     loadSettings();
-
+    //qDebug() << Q_FUNC_INFO << " - 40";
     //dxClusterPage->setDxclusterServersComboBox(dxClusterServers);
     //dxClusterPage->setSelectedDxClusterServer(dxClusterServerToUse);
 
@@ -568,7 +580,7 @@ void SetupDialog::readActiveModes (const QStringList &actives)
 
 bool SetupDialog::isValidBand (const QString &b)
 {
-        //qDebug() << "SetupDialog::isValidBand: "<< b;
+    //qDebug() << "SetupDialog::isValidBand: "<< b;
     logEvent(Q_FUNC_INFO, "Start", Debug);
     QString stringQuery = QString("SELECT id FROM band WHERE name='%1'").arg(b);
     QSqlQuery query(stringQuery);
@@ -589,7 +601,7 @@ bool SetupDialog::isValidMode (const QString &b)
 
 void SetupDialog::setDefaults()
 {
-        //qDebug() << "SetupDialog::setDefaults";
+    //qDebug() <<  Q_FUNC_INFO << " - Start";
     logEvent(Q_FUNC_INFO, "Start", Debug);
     miscPage->setRealTime("TRUE");
     miscPage->setUTCTime("TRUE");
@@ -633,6 +645,7 @@ void SetupDialog::setDefaults()
         bands << "10M" << "12M" << "15M" << "17M" << "20M" << "40M" << "80M" << "160M";
         bands.removeDuplicates();
     }
+    //qDebug() <<  Q_FUNC_INFO << " - END";
     logEvent(Q_FUNC_INFO, "END", Debug);
 }
 
