@@ -55,7 +55,6 @@ public:
     void loadSettings();
     void loadDarkMode(); // Reads the config to setup the DarkMode
 
-
 private slots:
     void slotNewOneColorButtonClicked();
     void slotConfirmedColorButtonClicked();
@@ -65,7 +64,8 @@ private slots:
     void slotWSJTXButtonClicked();
     void slotKLogButtonClicked();
     void slotSetDarkMode();
-
+signals:
+    void darkModeChanged(bool darkMode); // Signal to notify other widgets
 
 private:
     Utilities *util;
@@ -93,7 +93,6 @@ private:
         4 - Confirmed: Worked in this band.
         5 - Confirmed: Confirmed in this band.
 */
-
 };
 
 #endif // SETUPPAGECOLORS_H
