@@ -90,22 +90,13 @@ SetupPageSats::SetupPageSats(DataProxy_SQLite *dp, QWidget *parent) : QWidget(pa
 
 
     setLayout(widgetLayout);
-
-
-
-    //connect(newSatPushButton, SIGNAL(clicked ( )), this, SLOT(slotNewButtonClicked() ) );
-    //QObject::connect(manager, SIGNAL(finished(QNetworkReply*)),this, SLOT(slotDownloadFinished(QNetworkReply*)));
-    //connect(setupD, SIGNAL(newSatRequested(true)), this, slotNewButtonClicked() )
-
-
     createActions();
     updateSelectedSats();
-
-
        //qDebug() << "SetupPageSats::SetupPageSats - END";
 }
 
-SetupPageSats::~SetupPageSats(){
+SetupPageSats::~SetupPageSats()
+{
        //qDebug() << "SetupPageSats::~SetupPageSats";
     delete(util);
     delete(newSat);
@@ -193,7 +184,7 @@ void SetupPageSats::slotEditButtonClicked()
     }
     else
     {
-        emit queryError(Q_FUNC_INFO, query.lastError().databaseText(), query.lastError().nativeErrorCode(), query.lastQuery());
+        emit queryError(Q_FUNC_INFO, query.lastError().databaseText(), query.lastError().text(), query.lastQuery());
     }
     */
 }
@@ -217,40 +208,19 @@ void SetupPageSats::slotRemoveButtonClicked()
              QMessageBox::Yes | QMessageBox::No);
     if (ret == QMessageBox::Yes)
     {
-
         QString stringQuery = QString("DELETE FROM satellites WHERE id='%1'").arg(selectedSat);
         QSqlQuery query(stringQuery);
 
         bool sqlOk = query.exec();
         if (sqlOk)
         {
-
             satsModel->select();
             updateSelectedSats();
             stringQuery = QString("DELETE FROM log WHERE lognumber='%1'").arg(selectedSat);
             query.exec(stringQuery);
             sqlOk = query.exec();
                //qDebug() << "SetupPageSats::slotRemoveButtonClicked: LastQuery: " << query.lastQuery() ;
-            if (sqlOk)
-            {
-
-                stringQuery = QString("DELETE FROM awarddxcc WHERE lognumber='%2'").arg(selectedSat);
-                query.exec(stringQuery);
-                sqlOk = query.exec();
-                   //qDebug() << "SetupPageSats::slotRemoveButtonClicked: LastQuery: " << query.lastQuery() ;
-                if (sqlOk)
-                {
-                       //qDebug() << "SetupPageSats::slotRemoveButtonClicked (AWARDDXCC REMOVED: " << QString::number(selectedSat) << ")";
-                }
-                else
-                {
-                    emit queryError(Q_FUNC_INFO, query.lastError().databaseText(), query.lastError().nativeErrorCode(), query.lastQuery());
-                    showError(tr("Sat has not been removed. (#3)"));
-                       //qDebug() << "SetupPageSats::slotRemoveButtonClicked (AWARDDXCC NOT REMOVED: " << QString::number(selectedSat) << ")";
-                }
-
-            }
-            else
+            if (!sqlOk)
             {
                 showError(tr("Sat has not been removed. (#2)"));
                    //qDebug() << "SetupPageSats::slotRemoveButtonClicked (QSOS NOT REMOVED: " << QString::number(selectedSat) << ")";
@@ -258,16 +228,13 @@ void SetupPageSats::slotRemoveButtonClicked()
         }
         else
         {
-            emit queryError(Q_FUNC_INFO, query.lastError().databaseText(), query.lastError().nativeErrorCode(), query.lastQuery());
+            emit queryError(Q_FUNC_INFO, query.lastError().databaseText(), query.lastError().text(), query.lastQuery());
             showError(tr("Sat has not been removed. (#1)"));
                //qDebug() << "SetupPageSats::slotRemoveButtonClicked (NOT REMOVED: " << QString::number(selectedSat) << ")";
         }
     }
-
     //ASK FOR A CONFIRMATION
-
     //DELETE ALL THE QSO IN THE REMOVED Sat
-
 }
 
 void SetupPageSats::createSatsPanel()
@@ -301,7 +268,6 @@ void SetupPageSats::createSatsPanel()
     satsView->setSelectionBehavior(QAbstractItemView::SelectRows);
     satsView->resizeColumnsToContents();
     satsView->horizontalHeader()->setStretchLastSection(true);
-
 }
 
 void SetupPageSats::createSatsModel()
@@ -344,7 +310,6 @@ void SetupPageSats::slotSatselected(const QModelIndex & index)
      //qDebug() << "SetupPageSats::slotSatselected" ;
     int row = index.row();
     setSelectedSat((satsModel->index(row, 0)).data(0).toInt());
-
 }
 
 void SetupPageSats::slotSatDoubleClicked(const QModelIndex & index)
@@ -354,8 +319,8 @@ void SetupPageSats::slotSatDoubleClicked(const QModelIndex & index)
     int row = index.row();
     setSelectedSat((satsModel->index(row, 0)).data(0).toInt());
     slotEditButtonClicked();
-
 }
+
 void SetupPageSats::slotAnalyzeNewSatData(const QStringList _qs)
 {
     Q_UNUSED(_qs);
@@ -378,7 +343,6 @@ void SetupPageSats::createActions()
     //loadAllPushButton->setToolTip(tr("Load all the Sats"));
     //loadSelectedPushButton->setToolTip(tr("Load only the selected Sat"));
     //clearPushButton->setToolTip(tr("Clear selection"));
-
 }
 
 /*
@@ -451,7 +415,6 @@ void SetupPageSats::updateSelectedSats()
 QStringList SetupPageSats::readSats()
 {
        //qDebug() << "SetupPageSats::readSats";
-
     QString aux, aux2;
     QStringList _sats;
     QSqlQuery query;
@@ -462,7 +425,6 @@ QStringList SetupPageSats::readSats()
     aux.clear();
     _sats.clear();
 
-
     aux = "SELECT id, satarrlid, satname, uplink, downlink, satmode FROM satellites";
 
     sqlOk = query.exec(aux);
@@ -498,21 +460,14 @@ QStringList SetupPageSats::readSats()
              aux2.append((query.value(nameCol)).toString());
 
              _sats.append(aux2);
-
          }
          return _sats;
      }
      else
      {
-         emit queryError(Q_FUNC_INFO, query.lastError().databaseText(), query.lastError().nativeErrorCode(), query.lastQuery());
+         emit queryError(Q_FUNC_INFO, query.lastError().databaseText(), query.lastError().text(), query.lastQuery());
          return _sats;
      }
-
-
-     //_sats.clear();
-        //qDebug() << "SetupPageSats::readSats: " << QString::number(_sats.size())<< QT_ENDL;
-
-     //return _sats;
 }
 
 int SetupPageSats::getSelectedSat()
@@ -553,11 +508,6 @@ void SetupPageSats::setSelectedSat(const int _i)
     }
 }
 
-//void SetupPageSats::readSelectedSat(const int _i)
-//{
-
-//}
-
 void SetupPageSats::showError(const QString &_errorC)
 {
     QString text = QString(tr("An error has occurred showing the following error code:") + "\n'%1'").arg(_errorC);
@@ -566,13 +516,11 @@ void SetupPageSats::showError(const QString &_errorC)
     QMessageBox::warning(this, tr("KLog - SetupPageSats"),
                                    text,
                                    QMessageBox::Ok);
-
 }
 
 void SetupPageSats::slotImportButtonClicked()
 {
      //qDebug() << "SetupPageSats::slotImportButtonClicked";
-
     QString fileName = QFileDialog::getOpenFileName(this, tr("Open Satellites File"),
                                                      util->getHomeDir(),
                                                      "SATS (*.dat)");
@@ -584,7 +532,6 @@ void SetupPageSats::slotImportButtonClicked()
     UpdateSatsData *updateSat = new UpdateSatsData(dataProxy, this);
     if (updateSat->satDataFileRead(fileName))
     {
-
          //qDebug() << "SetupPageSats::slotImportButtonClicked IMPORTED OK";
     }
     else
@@ -609,11 +556,9 @@ void SetupPageSats::slotImportButtonClicked()
             // should never be reached
             break;
         }
-
     }
     satsModel->select();
     updateSelectedSats();
-
 }
 
 void SetupPageSats::slotExportButtonClicked()
@@ -648,12 +593,10 @@ void SetupPageSats::slotExportButtonClicked()
         {
             return;
         }
-
     }
     else
     {
-        emit queryError(Q_FUNC_INFO, query.lastError().databaseText(), query.lastError().nativeErrorCode(), query.lastQuery());
-
+        emit queryError(Q_FUNC_INFO, query.lastError().databaseText(), query.lastError().text(), query.lastQuery());
     }
     QDateTime *dateTime = new QDateTime();
     //dateTime->currentDateTime();
@@ -663,7 +606,6 @@ void SetupPageSats::slotExportButtonClicked()
 
     if (sqlOk)
     {
-
         QString fileName = QFileDialog::getSaveFileName(this, tr("Save Satellites File"),
                                    util->getHomeDir(),
                                    "SATS (*.dat)");
@@ -704,12 +646,10 @@ void SetupPageSats::slotExportButtonClicked()
             out << satText;
             //satText.clear();
         }
-
     }
     else
     {
-        emit queryError(Q_FUNC_INFO, query.lastError().databaseText(), query.lastError().nativeErrorCode(), query.lastQuery());
+        emit queryError(Q_FUNC_INFO, query.lastError().databaseText(), query.lastError().text(), query.lastQuery());
     }
-
      //qDebug() << "SetupPageSats::slotExportButtonClicked END";
 }
