@@ -148,17 +148,11 @@ void SetupPageSubdivisions::slotRemoveButtonClicked()
                 query.exec(stringQuery);
                 sqlOk = query.exec();
                    //qDebug() << "SetupPageSubdivisions::slotRemoveButtonClicked: LastQuery: " << query.lastQuery() ;
-                if (sqlOk)
+                if (!sqlOk)
                 {
-                       //qDebug() << "SetupPageSubdivisions::slotRemoveButtonClicked (AWARDDXCC REMOVED: " << QString::number(selectedLog) << ")";
-                }
-                else
-                {
-                    emit queryError(Q_FUNC_INFO, query.lastError().databaseText(), query.lastError().nativeErrorCode(), query.lastQuery());
+                    emit queryError(Q_FUNC_INFO, query.lastError().databaseText(), query.lastError().text(), query.lastQuery());
                     showError(tr("Log has not been removed. (#3)"));
-                       //qDebug() << "SetupPageSubdivisions::slotRemoveButtonClicked (AWARDDXCC NOT REMOVED: " << QString::number(selectedLog) << ")";
-                }
-
+                 }
             }
             else
             {
@@ -168,7 +162,7 @@ void SetupPageSubdivisions::slotRemoveButtonClicked()
         }
         else
         {
-            emit queryError(Q_FUNC_INFO, query.lastError().databaseText(), query.lastError().nativeErrorCode(), query.lastQuery());
+            emit queryError(Q_FUNC_INFO, query.lastError().databaseText(), query.lastError().text(), query.lastQuery());
             showError(tr("Log has not been removed. (#1)"));
                //qDebug() << "SetupPageSubdivisions::slotRemoveButtonClicked (NOT REMOVED: " << QString::number(selectedLog) << ")";
         }
@@ -177,7 +171,6 @@ void SetupPageSubdivisions::slotRemoveButtonClicked()
     //ASK FOR A CONFIRMATION
 
     //DELETE ALL THE QSO IN THE REMOVED LOG
-
 }
 
 void SetupPageSubdivisions::createLogsPanel()
@@ -202,7 +195,6 @@ void SetupPageSubdivisions::createLogsPanel()
     logsView->setSelectionBehavior(QAbstractItemView::SelectRows);
     logsView->resizeColumnsToContents();
     logsView->horizontalHeader()->setStretchLastSection(true);
-
 }
 
 void SetupPageSubdivisions::createLogsModel()
@@ -244,8 +236,6 @@ void SetupPageSubdivisions::createLogsModel()
 
         nameCol = rec.indexOf("dxcc");
         logsModel->setHeaderData(nameCol, Qt::Horizontal, tr("DXCC"));
-
-
         logsModel->select();
 }
 
@@ -254,7 +244,6 @@ void SetupPageSubdivisions::slotLogSelected(const QModelIndex & index)
        //qDebug() << "SetupPageSubdivisions::slotLogSelected" ;
     int row = index.row();
     setSelectedLog((logsModel->index(row, 0)).data(0).toInt());
-
 }
 
 void SetupPageSubdivisions::createActions()
@@ -265,13 +254,11 @@ void SetupPageSubdivisions::createActions()
 
     connect(removePushButton, SIGNAL(clicked()), this, SLOT(slotRemoveButtonClicked() ) );
     connect(logsView, SIGNAL(clicked(QModelIndex)), this, SLOT(slotLogSelected(QModelIndex) ) );
-
 }
 
 QStringList SetupPageSubdivisions::readLogs()
 {
        //qDebug() << "SetupPageSubdivisions::readLogs";
-
     QString aux, aux2;
     QStringList _logs;
     QSqlQuery query;
@@ -282,7 +269,7 @@ QStringList SetupPageSubdivisions::readLogs()
     _logs.clear();
 
     aux = "SELECT DISTINCT dxcc from primary_subdivisions";
-    int counter = 0;
+    //int counter = 0;
     sqlOk = query.exec(aux);
     if (sqlOk)
     {
@@ -290,7 +277,7 @@ QStringList SetupPageSubdivisions::readLogs()
 
         while ( (query.next()) && (query.isValid()) )
         {
-            counter ++;
+            //counter ++;
             aux2.clear();
 
             nameCol = rec.indexOf("dxcc");
@@ -299,21 +286,16 @@ QStringList SetupPageSubdivisions::readLogs()
             //aux2.append((query.value(nameCol)).toString());
 
             _logs.append(aux2);
-
         }
         return _logs;
     }
     else
     {
-        emit queryError(Q_FUNC_INFO, query.lastError().databaseText(), query.lastError().nativeErrorCode(), query.lastQuery());
+        emit queryError(Q_FUNC_INFO, query.lastError().databaseText(), query.lastError().text(), query.lastQuery());
         return _logs;
     }
-
-
 }
 
-
-
 void SetupPageSubdivisions::updateSelectedLogs()
 {
        //qDebug() << "SetupPageSubdivisions::updateSelectedLogs";
@@ -358,8 +340,6 @@ void SetupPageSubdivisions::slotCurrentLogsComboBoxChanged()
       //qDebug() << "SetupPageSubdivisions::slotCurrentLogsComboBoxChanged: a: " << a;
 
     setSelectedLog(a.toInt());
-
-
 }
 
 void SetupPageSubdivisions::setSelectedLog(const int _i)
@@ -380,7 +360,6 @@ void SetupPageSubdivisions::setSelectedLog(const int _i)
     }
 }
 
-
 void SetupPageSubdivisions::showError(const QString &_errorC)
 {
     QString text = QString(tr("An error has occurred showing the following error code:") + "\n'%1'").arg(_errorC);
@@ -389,7 +368,6 @@ void SetupPageSubdivisions::showError(const QString &_errorC)
     QMessageBox::warning(this, tr("KLog - SetupPageSubdivisions"),
                                    text,
                                    QMessageBox::Ok);
-
 }
 
 void SetupPageSubdivisions::slotImportButtonClicked()
@@ -404,6 +382,5 @@ void SetupPageSubdivisions::slotImportButtonClicked()
         //qDebug() << "SetupPageSubdivisions::slotImportButtonClicked - NOK";
     }
     //QString fileName = QFileDialog::getOpenFileName(this, tr("Open Award file"), util->getHomeDir(), tr("Award files (*.awa)"));
-
     //qDebug() << "SetupPageSubdivisions::slotImportButtonClicked - END";
 }
