@@ -159,11 +159,10 @@ private:
     World *world;
     DataProxy_SQLite *dataProxy;
 
-    bool operatorsOK;
+    //bool operatorsOK;
     bool mainCallOK;
     bool slotQRZRunning;
     Utilities *util;
-
 };
 
 
