@@ -30,8 +30,7 @@
     Anything that is not directly related with a class itself and could be used from different
     classes should be here.
 
-    This classs hould not need to query the DB neither the DataProxy Class
-
+    This class should not need to query the DB neither the DataProxy Class
 */
 #include <iostream>
 #include <QObject>
@@ -40,6 +39,7 @@
 #include <QtWidgets>
 #include <QPalette>
 #include <QtDebug>
+#include "global.h"                     // Remove when all deprecated functions are removed
 #include "locator.h"
 #include "klogdefinitions.h"
 #include "adif.h"
@@ -54,9 +54,9 @@ public:
     ~Utilities();
     //void setDarkMode(const QString &_dm);
     //bool isDarkMode();
-    void setCallValidation(const bool _b);
-    void setLongPrefixes (const QStringList &_p);
-    void setSpecialCalls (const QStringList &_p);
+
+
+    //void setSpecialCalls (const QStringList &_p);
 
     int getProgresStepForDialog(int totalSteps);
     bool trueOrFalse(const QString &_s); // reads a String and return true if s.upper()== TRUE :-)
@@ -95,19 +95,21 @@ public:
     QDate getDefaultDate();
     QString getDefaultRST(const QString &_m);
     QStringList getDefaultLogFields();
+    QString getDefaultModeForFreq(const double _f);
 
     int getNormalizedDXCCValue(const int _dxcc);
 
     // Validations
     bool isValidDate(const QDate _d);
     bool isValidDateTime(const QString &_d);
-    bool isValidCall(const QString &_c, bool _force=false);
+    //bool isValidCall(const QString &_c, bool _force=false);             // To be replaced by Callsign::isValid
 
     bool isSameFreq(const double fr1, const double fr2);
     bool isValidBandId(const int _b);
     bool isValidModeId(const int _m);
     bool isValidFreq(const QString &_b);
     bool isValidGrid(const QString &_b);
+    bool isValidGrid_ext(const QString &_b);
     bool isValidVUCCGrids(const QString &_b);
     bool isValidRST(const QString &_b);
     bool isValidPower(const QString &_b);
@@ -129,12 +131,15 @@ public:
     bool isValidPropMode(const QString &_s);
     bool isValidEmail(const QString &_s);
     QStringList getValidADIFFieldAndData(const QString &_b);
+    bool areThoseListsTheSame(const QStringList &_list1, const QStringList &_list2);
     //QString getADIFField(const QString &_fieldName, const QString &_data);
 
-    QString getMainCallFromComplexCall(const QString &_complexCall); // F from F/EA4K/p, EA4K from EA4K/p or EA4K from EA4K
+    KLOG_DEPRECATED QString getMainCallFromComplexCall(const QString &_complexCall); //TODO: To be replaced by  QString Callsign::getHostFullPrefix(bool getHomeIfEmpty=true);
     QString getAValidCall (const QString &_wrongCall);
     QString getPrefixFromCall(const QString &_c, bool withAreaNumber = false);
-    bool isAOneLetterPrefix(const QChar &_c);
+    int getAreaNumberFromCall(const QString &_c);
+
+
 
     // Write DATE/TIME to DB
     QString getDateTimeSQLiteStringFromDateTime(const QDateTime &_d);
@@ -147,7 +152,7 @@ public:
 
     // Translate the LOG table fields into human readable
     QString getLogColumnName(const QString &_column);
-
+    QString getLogColumnDBName(const QString &_column);
 
     // Creates the ADIF DATE & TIME formats
     QString getADIFDateFromQDateTime(const QDateTime &_d);  // Will produce the ADIF DATE format: "YYYYMMDD"
@@ -173,7 +178,7 @@ public:
 
     QString getOnlineServiceName(OnLineProvider _service);
 
-    bool isValidDistance(const double _d);
+    //bool isValidDistance(const double _d);
     bool isValidSponsor(const QString &_s);
 
     QString debugLevelToString(DebugLogLevel _l);
@@ -193,17 +198,18 @@ private:
     void setLogColumnNames(); // Creates the map of column Names (should be called from init() )
     QString getKLogDefaultDatabaseFile();
     //bool isCountrySuffix (const QString &_c);
-    bool isAValidOperatingSuffix (const QString &_c);
-    bool isAPrefix(const QString &_c); // Returns true if it is the country prefix or it includes the area number
-    bool isAKnownPrefix(const QString &_c);
-    bool isAKnownCall(const QString &_c);
-    bool isValidSimpleCall(const QString &_c);
+
+    //bool isAKnownCall(const QString &_c);
+
+    //QStringList getPrefixRunningTheCall(const QString &_c, bool withAreaNumber = false);
+                    //Goes char by char identifying the prefix and area Number
+
     //QPair<QString, QString> getCallParts(const QString &_c);
 
     void setARRLSect();
     void setContinent();
     void setSponsorsList();
-    QString getCheckedComplexCall(const QString &_c);
+    //QString getCheckedComplexCall(const QString &_c);
     void logEvent(const QString &_func, const QString &_msg, DebugLogLevel _level);
     //bool darkMode;
     QString getDBPath();
@@ -213,11 +219,10 @@ private:
 
     QStringList ARRL_sects, continent, sponsorsList, logLevels;
     DebugLogLevel logLevel;
-    QStringList longPrefixes, specialCalls;
+    //KLOG_DEPRECATED QStringList specialCalls;     // To be moved to World class
     QMap<QString, QString> columnNames;
     bool validateCalls;
     QHash<QString, QString> ADIFHash; // Name, type
-
 };
 
 #endif // UTILITIES_H
