@@ -23,7 +23,10 @@
  *    along with KLog.  If not, see <https://www.gnu.org/licenses/>.         *
  *                                                                           *
  *****************************************************************************/
+#include <QMessageBox>
 #include "adiflotwexportwidget.h"
+#include "../callsign.h"
+#include "../locator.h"
 
 
 AdifLoTWExportWidget::AdifLoTWExportWidget(DataProxy_SQLite *dp, const QString &_parentFunction, QWidget *parent) : QWidget(parent)
@@ -36,9 +39,9 @@ AdifLoTWExportWidget::AdifLoTWExportWidget(DataProxy_SQLite *dp, const QString &
     //qDebug() << Q_FUNC_INFO << " - Start: " + _parentFunction;
     dataProxy = dp;
     starting = true;
-    util = new Utilities(Q_FUNC_INFO);
-    util->setLongPrefixes(dataProxy->getLongPrefixes());
-    util->setSpecialCalls(dataProxy->getSpecialCallsigns());
+    //util = new Utilities(Q_FUNC_INFO);
+    //util->setLongPrefixes(dataProxy->getLongPrefixes());
+    //util->setSpecialCalls(dataProxy->getSpecialCallsigns());
     stationCallsignComboBox = new QComboBox;
     myGridSquareComboBox = new QComboBox;
     startDate = new QDateEdit;
@@ -52,8 +55,6 @@ AdifLoTWExportWidget::AdifLoTWExportWidget(DataProxy_SQLite *dp, const QString &
     defaultStationCallsign = QString();
     defaultMyGrid = QString();
     numOfQSOsInThisLog = 0;
-    util->setLongPrefixes(dataProxy->getLongPrefixes());
-    util->setSpecialCalls(dataProxy->getSpecialCallsigns());
     createUI();
     starting = false;
     qsos.clear ();
@@ -61,23 +62,26 @@ AdifLoTWExportWidget::AdifLoTWExportWidget(DataProxy_SQLite *dp, const QString &
 }
 AdifLoTWExportWidget::~AdifLoTWExportWidget()
 {
-    delete(util) ;
+    //delete(util) ;
 }
 
 void AdifLoTWExportWidget::setDefaultStationCallsign(const QString &_st)
 {
     //qDebug() << Q_FUNC_INFO << " - Start";
-    if (util->isValidCall(_st))
+    Callsign callsign(_st);
+    if (callsign.isValid())
     {
+        //qDebug() << Q_FUNC_INFO << " - Call not valid!";
         defaultStationCallsign = _st;
     }
-     //qDebug() << Q_FUNC_INFO << " - END";
+    //qDebug() << Q_FUNC_INFO << " - END";
 }
 
 void AdifLoTWExportWidget::setDefaultMyGrid(const QString &_st)
 {
     //qDebug() << Q_FUNC_INFO << " - Start";
-    if (util->isValidGrid(_st))
+    Locator locator;
+    if (locator.isValidLocator(_st))
     {
         defaultMyGrid = _st;
     }
@@ -87,14 +91,12 @@ void AdifLoTWExportWidget::setDefaultMyGrid(const QString &_st)
 void AdifLoTWExportWidget::createUI()
 {
     //qDebug() << Q_FUNC_INFO << " - Start";
-    //fillStationCallsignComboBox();
     tableWidget->setSortingEnabled (true);
     stationCallsignComboBox->setToolTip(tr("Select the Station Callsign that you want to use to upload the log."));
     startDate->setCalendarPopup (true);
     endDate->setCalendarPopup (true);
     startDate->clear();
     startDate->setToolTip(tr("Select the start date to export the QSOs. The default date is the date of the first QSO with this station callsign."));
-
     endDate->clear();
 
     //endDate->setDate(QDate::currentDate());
@@ -158,9 +160,10 @@ void AdifLoTWExportWidget::setDefaultStationComboBox()
 {
     //qDebug() << Q_FUNC_INFO << " - Start";
     //stationCallsignComboBox->blockSignals(true);
-    if (!util->isValidCall(defaultStationCallsign))
+    Callsign callsign(defaultStationCallsign);
+    if (!callsign.isValid())
     {
-        //qDebug() << Q_FUNC_INFO << " - END-1";
+        //qDebug() << Q_FUNC_INFO << " - END-1 (call not valid)";
         //stationCallsignComboBox->blockSignals(false);
         return;
     }
@@ -175,7 +178,8 @@ void AdifLoTWExportWidget::setDefaultStationComboBox()
 void AdifLoTWExportWidget::setDefaultMyGridComboBox()
 {
     //qDebug() << Q_FUNC_INFO << " - Start";
-    if (!util->isValidGrid(defaultMyGrid))
+    Locator locator;
+    if (!locator.isValidLocator(defaultMyGrid))
     {
         //qDebug() << Q_FUNC_INFO << " - END-1";
         return;
@@ -197,7 +201,7 @@ void AdifLoTWExportWidget::setDefaultMyGridComboBox()
      //qDebug() << Q_FUNC_INFO << " - END";
 }
 
-void AdifLoTWExportWidget::fillStationCallsignComboBox()
+bool AdifLoTWExportWidget::fillStationCallsignComboBox()
 {
     //qDebug() << Q_FUNC_INFO << " - Start";
     //stationCallsignComboBox->blockSignals(true);
@@ -211,21 +215,29 @@ void AdifLoTWExportWidget::fillStationCallsignComboBox()
         stationCallsignComboBox->addItem(tr("ALL"));
         //qDebug() << Q_FUNC_INFO << " -4";
     }
+    QStringList stationCallsigns;
+    stationCallsigns.clear();
 
     if (currentExportMode == ModeLotW)
     {
+        stationCallsigns.append(dataProxy->getStationCallSignsFromLogWithLoTWPendingToSend(logNumber));
         //qDebug() << Q_FUNC_INFO << " -3";
-        stationCallsignComboBox->addItems(dataProxy->getStationCallSignsFromLogWithLoTWPendingToSend(logNumber));
+        //stationCallsignComboBox->addItems();
         //qDebug() << Q_FUNC_INFO << " -4";
     }
     else
     {
         //qDebug() << Q_FUNC_INFO << " -5";
-        stationCallsignComboBox->addItems(dataProxy->getStationCallSignsFromLog(logNumber));
+        stationCallsigns.append(dataProxy->getStationCallSignsFromLog(logNumber));
         //qDebug() << Q_FUNC_INFO << " -6";
     }
-    //stationCallsignComboBox->blockSignals(false);
-    //qDebug() << QString::number(stationCallsignComboBox->count());
+    if (stationCallsigns.count()<1)
+    {
+        return false;
+    }
+    stationCallsignComboBox->addItems(stationCallsigns);
+    return true;
+
      //qDebug() << Q_FUNC_INFO << " - END";
 }
 
@@ -241,7 +253,8 @@ void AdifLoTWExportWidget::fillStationMyGridComboBox()
     QStringList grids;
     grids.clear ();
 
-    if (util->isValidCall(stationCallsignComboBox->currentText()))
+    Callsign callsign(stationCallsignComboBox->currentText());
+    if (callsign.isValid())
     {
        //qDebug() << Q_FUNC_INFO << " - ValidCall: " << stationCallsignComboBox->currentText();
         grids.append (dataProxy->getGridsToBeSent (stationCallsignComboBox->currentText(), startDate->date(), endDate->date(), currentExportMode, true, logNumber));
@@ -283,7 +296,8 @@ void AdifLoTWExportWidget::fillDates()
     //startDate->blockSignals(true);
     //endDate->blockSignals(true);
 
-    if (util->isValidCall(stationCallsignComboBox->currentText()))
+    Callsign callsign(stationCallsignComboBox->currentText());
+    if (callsign.isValid())
     {
         //qDebug() << Q_FUNC_INFO << " - Not valid Call";
         startDate->setDate(dataProxy->getFirstQSODateFromCall(stationCallsignComboBox->currentText()));
@@ -599,12 +613,21 @@ void AdifLoTWExportWidget::showEvent(QShowEvent *event)
 {
     //qDebug() << Q_FUNC_INFO << " - Start";
     starting = true;
+    event->accept();
     numOfQSOsInThisLog = dataProxy->getHowManyQSOInLog(logNumber);
-    //myGridSquareComboBox->blockSignals(true);
-    //stationCallsignComboBox->blockSignals(true);
-    //startDate->blockSignals(true);
-    //endDate->blockSignals(true);
-    fillStationCallsignComboBox();
+    if (!fillStationCallsignComboBox())
+    {
+        // Show the warning message and wait for the user to acknowledge it
+        QMessageBox::warning(this, tr("KLog Warning"), tr("There are no queued QSOs."));
+
+        // Close the widget after the user acknowledges the warning
+        starting = false;
+        QTimer::singleShot(0, this, &AdifLoTWExportWidget::close); // Schedule the widget to close
+        return;
+
+        //emit askingToClose();
+        //return;          // Exit the function to stop further execution
+    }
     //qDebug() << Q_FUNC_INFO << ": 1 - " << stationCallsignComboBox->currentText();
     setDefaultStationComboBox();
     //qDebug() << Q_FUNC_INFO << ": 2 - " << stationCallsignComboBox->currentText();
@@ -616,7 +639,7 @@ void AdifLoTWExportWidget::showEvent(QShowEvent *event)
     starting = false;
     updateIfNeeded();
     //qDebug() << Q_FUNC_INFO << ": 5 - " << stationCallsignComboBox->currentText();
-    event->accept();
+    //event->accept();
      //qDebug() << Q_FUNC_INFO << " - END";
 }
 
@@ -649,7 +672,7 @@ void AdifLoTWExportWidget::setExportMode(const ExportMode _EMode)
         setWindowTitle("KLog - QSOs to be exported to ADIF.");
         topLabel->setText(tr("This table shows the QSOs that will be exported to ADIF."));
     }
-    //fillStationCallsignComboBox();
+
     //slotStationCallsignChanged();
      //qDebug() << Q_FUNC_INFO << " - END";
 }
@@ -669,8 +692,3 @@ void AdifLoTWExportWidget::setLogNumber(const int _logN)
      //qDebug() << Q_FUNC_INFO << " - END";
 }
 
-void AdifLoTWExportWidget::setCallValidation(const bool _v)
-{
-    util->setCallValidation(_v);
-    dataProxy->setCallValidation(_v);
-}
