@@ -27,7 +27,7 @@
  *****************************************************************************/
 #include <QtWidgets>
 #include "../dataproxy_sqlite.h"
-#include "../utilities.h"
+//#include "../utilities.h"
 
 
 
@@ -35,7 +35,6 @@ class AdifLoTWExportWidget : public QWidget
 {
     Q_OBJECT
 
-
 public:
     explicit AdifLoTWExportWidget(DataProxy_SQLite *dp, const QString &_parentFunction, QWidget *parent = nullptr);
     ~AdifLoTWExportWidget();
@@ -43,7 +42,6 @@ public:
     void setLogNumber(const int _logN);
     void setDefaultStationCallsign(const QString &_st);
     void setDefaultMyGrid(const QString &_st);
-    void setCallValidation(const bool _v);
 
 protected:
     void closeEvent(QCloseEvent *event);
@@ -59,13 +57,14 @@ private slots:
 signals:
     void selection(QString _st, QString _grid, QDate _startD, QDate _endD, ExportMode _exportMode);
     void qsosToSend(QString _call, QList<int> _qsos, ExportMode _exportMode);
+    void askingToClose();
 
 private:
     void createUI();
     QList<int> fillTable();
     void setTopLabel(const QString &_t);
     void addQSO(const int _qsoID);
-    void fillStationCallsignComboBox();
+    bool fillStationCallsignComboBox();
     void fillStationMyGridComboBox();
     void fillDates();
     void setDefaultStationComboBox();
@@ -94,7 +93,6 @@ private:
     QDate currentStart, currentEnd;
     bool starting;
     QList<int> qsos;
-
 };
 
 
