@@ -45,7 +45,7 @@
 //#include "awards.h"
 
 
-class QStringList;
+//class QStringList;
 
 enum
 {
@@ -57,8 +57,9 @@ class World : public QObject
 {
     //friend class Awards;
     Q_OBJECT
+    friend class tst_World;
 
-public:
+public:            
     World(DataProxy_SQLite *dp, const QString &_parentFunction);
     //World(DataProxy_SQLite *dp, const QString &_klogDir, const QString &_parentFunction);
     //World(DataProxy_SQLite *dp, const QString &_klogVer, const QString &_parentFunction);
@@ -72,7 +73,8 @@ public:
     QString getEntityName(const int _entityN);
 
     QString getQRZEntityMainPrefix(const QString &_qrz);
-    QString getEntityMainPrefix(const int _entityN);
+    QString getEntityMainPrefix(int _dxcc);
+    EntityData getEntityDataFromDXCC(const int _dxcc);    // Returns the data of one DXCC entity
 
     QString getQRZContinentNumber(const QString &_qrz); // Returns the continent id number
     int getContinentNumber(const int _enti); // Returns the continent id number
@@ -98,10 +100,13 @@ public:
     bool isNewEntity(const int _entityN);
     //int getBandIdFromFreq(const QString fr);
     QString getEntityPrefixes(const int _enti);
+    bool isAKnownCall(const QString &_callsign);
+    bool isAKnownPrefix(const QString &_prefix);
 
     //QStringList getEntitiesNames();
     int getHowManyEntities();
     bool hasSpecialEntities();
+    bool fillEmptyDXCCInTheLog();           // Adds the DXCC to the QSOs in the log that don't have it
 
 private slots:
 
@@ -109,19 +114,29 @@ private slots:
 private:
     //void identifyOS();
     bool insertSpecialEntities();
-    int getPrefixId(const QString &_prefix);
+    bool readEntities();                        // Read all the entities and fill entities QMap
+
+    int getHowManyEmptyDXCCorCont();
+    bool updateDXCCAndContinent(const int _id, const int _dxcc, const QString &_cont);
+
     //bool readCTYDAT();
     bool readCTYCSV(const QString &_worldFile);
-    QStringList processLine(const QString &_line);
-    QStringList processLineP(const QString &_line, const int _processingEntity);
+    bool addEntity(const QString &_name, const int _cq, const int _itu, const int _contId, const double _lat, const double _lon, const double _utc, const int _dxcc, const QString &_mainpref);
+    bool addPrefix(const QString &_pref, const int _dxcc, const int _cqz, const int _ituz);
+
     //void createWorldModel();
     QStringList readZones(const QString &pref, const int _cq, const int _itu);
+    bool addPrefixes(const QString &prefixes, int entityNumber, int cqz, int ituz);
+    bool insertPrefixes(const QList<QPair<QString, QPair<int, QPair<int, int>>>> &pairPrefixes);
+    int extractEntityNumber(const QStringList &stringList);
 
-    int progressBarPosition;
+    void emitQueryError(const QSqlQuery &query) const;
+    bool executeQuery(QSqlQuery &query, const QString &queryString) const;
+    //int progressBarPosition;
 
-    bool created;
+    bool created, read;
     //QString klogVersion;
-    int cqz, ituz, numberOfEntities;
+    int cqz, ituz;//, numberOfEntities;
     QString entityName;
     QString currentPrefix; // Used in the progressBar
 
@@ -139,15 +154,14 @@ private:
     DataProxy_SQLite *dataProxy;
     Utilities *util;
     QHash<QString, int> worldPrefixes;
+    QStringList specialCalls, longPrefixes;
+
+    QMap<EntityData, int> entities;         // Static data to speed up queries
 
-    //int constrid; // Just an id for the constructor to check who is being executed at one specific time
-    //Awards *awards;
-    //FLAGS
-    //QString flagsDir;
-    //FLAGS-END
 signals:
     //void qsoFound(const QStringList _qs); // Each: QString with format: Fieldname:value
-    void queryError(QString functionFailed, QString errorCodeS, QString nativeError, QString failedQuery); // To alert about any failed query execution
+    //void queryError(QString functionFailed, QString errorCodeS, QString nativeError, QString failedQuery); // To alert about any failed query execution
+    void queryError(const char *funcInfo, const QString &databaseText, const QString &text, const QString &query) const;
 };
 
 
